shouldActivateOnLongPressOnAllPlatforms property
When true, the bubble will be activated on long press on all platforms (not just mobile).
Implementation
final bool shouldActivateOnLongPressOnAllPlatforms;
When true, the bubble will be activated on long press on all platforms (not just mobile).
final bool shouldActivateOnLongPressOnAllPlatforms;