showOnHover property
When true, the bubble will automatically show on mouse hover and dismiss on mouse exit (all platforms, not just web).
Implementation
final bool showOnHover;
When true, the bubble will automatically show on mouse hover and dismiss on mouse exit (all platforms, not just web).
final bool showOnHover;