shouldDismissOnEscapeKey property

bool shouldDismissOnEscapeKey
final

Whether pressing the Escape key should dismiss this overlay. Defaults to true. Set to false for critical confirmation dialogs that should not be dismissed via Escape.

Implementation

final bool shouldDismissOnEscapeKey;