tapRegionGroupId property

Object? tapRegionGroupId
final

Optional TapRegion.groupId for the popup content.

When provided, the popup joins that tap region group so interactions inside the popup are treated as inside that composite region.

Implementation

final Object? tapRegionGroupId;