PopOverlayStackLevelBands class

Suggested stack-level bands for consistent overlay layering.

Constructors

PopOverlayStackLevelBands()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

criticalMin → const int
normalMax → const int
normalMin → const int
priorityMax → const int
priorityMin → const int