SBounceable class
A Bounceable widget that supports both single tap and double tap
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SBounceable
- Available extensions
Constructors
- SBounceable({Key? key, required Widget child, VoidCallback? onTap, VoidCallback? onDoubleTap, VoidCallback? onLongPress, double? scaleFactor, Duration? duration, bool isBounceEnabled = true, Curve curve = Curves.easeInOut, bool enableHapticFeedback = false, bool deferTapWhenDoubleTapEnabled = true})
-
const
Properties
- child → Widget
-
final
- curve → Curve
-
The animation curve for the bounce effect.
Defaults to Curves.easeInOut.
final
- deferTapWhenDoubleTapEnabled → bool
-
When both onTap and onDoubleTap are provided, defer onTap until
Flutter's double-tap timeout has elapsed.
final
- duration → Duration?
-
final
- enableHapticFeedback → bool
-
Whether to trigger haptic feedback on tap.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBounceEnabled → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDoubleTap → VoidCallback?
-
final
- onLongPress → VoidCallback?
-
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleFactor → double?
-
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SBounceable> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited