s_connectivity/src/s_connectivity library

Classes

NoInternetSnackbar
Configuration model for the default no-internet snackbar.
NoInternetWidget
Small connectivity indicator widget that appears when internet is unavailable.
SConnectivity
Connectivity facade for listening to internet status changes across the app.
SConnectivityOverlay
A convenience wrapper that sets up the Modal overlay system so that SConnectivity's "No Internet" snackbar (and any other Modal features) work without the user having to know about Modal.appBuilder.