disabledSemanticLabel property
Semantic label announced by screen readers when the widget is disabled.
Implementation
final String? disabledSemanticLabel;
Semantic label announced by screen readers when the widget is disabled.
final String? disabledSemanticLabel;