clearButtonIcon property

Widget? clearButtonIcon
final

Optional clear button shown in the suffix area when an item is selected.

When provided or when showClearButton is true, this button replaces the normal dropdown chevron while a selection is active.

Implementation

final Widget? clearButtonIcon;