clearButtonRestoresInitialSelection property
Whether the clear button restores the initial selection instead of clearing to the hint state.
Implementation
final bool clearButtonRestoresInitialSelection;
Whether the clear button restores the initial selection instead of clearing to the hint state.
final bool clearButtonRestoresInitialSelection;