s_future_button/s_future_button library

s_future_button package

This library exports all public APIs for the s_future_button package.

Classes

MyRoundedLoadingButton
Animated button used by SFutureButton to display loading/success/error states.
SFutureButton
A customizable button widget that handles asynchronous operations with automatic loading states.
SRoundedLoadingButtonController
Controller for triggering MyRoundedLoadingButton state transitions.

Enums

SButtonState
States that your button can assume via the controller