labelStyle property

TextStyle? labelStyle
final

The style applied to label.

It is merged with the default bold, white label style, so only the properties that need to differ have to be supplied.

Implementation

final TextStyle? labelStyle;