Glow2 class
A widget that adds a glowing effect around its child.
- Inheritance
- Available extensions
Constructors
- Glow2({Key? key, required Widget child, int glowCount = 2, Color glowColor = Colors.white, BoxShape glowShape = BoxShape.circle, BorderRadius? glowBorderRadius, Duration duration = const Duration(milliseconds: 3500), Duration? startDelay, bool animate = true, bool repeat = true, Curve curve = Curves.fastOutSlowIn, double glowRadiusFactor = 0.5, double startInsetFactor = 0.1, VoidCallback? onAnimationComplete})
-
Creates an Glow2 widget.
const
Properties
- animate → bool
-
Whether to animate the glowing effect.
final
- child → Widget
-
The child widget to display inside the glowing effect.
final
- curve → Curve
-
The curve for the glowing animation.
final
- duration → Duration
-
The duration of the glowing animation.
final
- glowBorderRadius → BorderRadius?
-
The border radius for the glow effect.
final
- glowColor → Color
-
The color of the glow effect.
final
- glowCount → int
-
The number of glowing effects to show around the child.
final
- glowRadiusFactor → double
-
The factor that determines how far out the glow expands.
final
- glowShape → BoxShape
-
The shape of the glow effect.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAnimationComplete → VoidCallback?
-
Called when the glow animation completes a cycle.
final
- repeat → bool
-
Whether to repeat the glowing animation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDelay → Duration?
-
The delay before starting the glowing animation.
final
- startInsetFactor → double
-
How far inside the child borders the glow starts, as a fraction of the
shortest side. For example, 0.1 means start 10% inside the border.
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Glow2> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited