SMaintenanceButton class
Debug-only maintenance toggle button with optional confirmation dialog.
This widget is hidden in release mode and is intended for internal/testing workflows where maintenance state needs to be toggled quickly.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SMaintenanceButton
- Available extensions
Constructors
- SMaintenanceButton({Key? key, VoidCallback? onTap, bool isOnMaintenance = false, Color? activeColor, Color? nonActiveColor, Widget? icon, bool showConfirmation = false, String? confirmationMessage})
-
const
Properties
- activeColor → Color?
-
final
- confirmationMessage → String?
-
Custom message for the confirmation dialog.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
Custom icon to display instead of the default build icon.
final
- isOnMaintenance → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- nonActiveColor → Color?
-
final
- onTap → VoidCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showConfirmation → bool
-
When true, shows a confirmation dialog before toggling maintenance.
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited