ChangeForecasted class
Basic structure for significant change periods in TAF.
Constructors
- ChangeForecasted(String code, Valid valid)
Properties
- changeIndicator → TafChangeIndicator
-
Get the change indicator data of the change period.
no setter
- clouds → CloudList
-
Get the cloud groups data of the METAR.
no setterinherited
- code → String?
-
Get the code of the group.
no setterinherited
- flightRules → String?
-
Get the flight rules of the report or forecast.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- length → int
-
Get the length of the code of the group.
no setterinherited
- prevailingVisibility → MetarPrevailingVisibility
-
Get the prevailing visibility data of the report.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unparsedGroups
→ List<
String> -
Get the unparsed groups of the change period.
no setterinherited
-
weathers
→ GroupList<
MetarWeather> -
Get the weather data of the report if provided.
no setterinherited
- wind → MetarWind
-
Get the wind data of the report.
no setterinherited
Methods
-
asMap(
) → Map< String, Object?> -
Returns the object data as a map like
Map<String, dynamic>.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldBeCavok(
) → bool -
Analyses the conditions for CAVOK in the report. Returns
trueif CAVOK should be reported,falseif not or if there is no data to make a complete analysis.inherited -
toJSON(
) → String -
Returns the object data as a string in JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited