heightInKilometers property
double?
get
heightInKilometers
Get the height of the cloud base in kilometers.
Implementation
double? get heightInKilometers => _height.inKilometers;
Get the height of the cloud base in kilometers.
double? get heightInKilometers => _height.inKilometers;