FlightRulesMixin mixin

Mixin to add flight rules to the report or forecast. The class must have MetarPrevailingMixin and MetarCloudMixin implemented.

Superclass constraints
Mixin applications

Properties

clouds CloudList
Get the cloud groups data of the METAR.
no setterinherited
flightRules String?
Get the flight rules of the report or forecast.
no setter
hashCode int
The hash code for this object.
no setterinherited
prevailingVisibility MetarPrevailingVisibility
Get the prevailing visibility data of the report.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited