GroupMixin mixin

Implemented types
Mixin applications

Properties

code String?
Get the code of the group.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
length int
Get the length of the code of the group.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the object data as a map like Map<String, dynamic>.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the object data as a string in JSON format.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited