MetarPressure class

Inheritance
Mixed-in types

Constructors

MetarPressure(String? code, RegExpMatch? match)

Properties

code String?
Get the code of the group.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inAtm double?
Get the pressure in atmospheres (atm).
no setterinherited
inBar double?
Get the pressure in bars (bar).
no setterinherited
inHPa double?
Get the pressure in hecto pascals (hPa).
no setterinherited
inInHg double?
Get the pressure in mercury inches (inHg).
no setterinherited
inKPa double?
Get the pressure in kilopascals (kPa).
no setterinherited
inMbar double?
Get the pressure in millibars (mbar).
no setterinherited
inPa double?
Get the pressure in pascals (Pa).
no setterinherited
length int
Get the length of the code of the group.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double?
Get the value as a float.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the numeric value data as a map like Map<String, dynamic>.
inherited
converted({double? conversionDouble, double conversionFunction(double)?}) double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the object data as a string in JSON format.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited