MetarPrevailingMixin mixin

Mixin to add prevailing visibility attribute to the report.

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
prevailingVisibility MetarPrevailingVisibility
Get the prevailing visibility data of the report.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited