MetarPrevailingVisibility class

Basic structure for prevailing visibility in reports from land stations.

Inheritance

Constructors

MetarPrevailingVisibility(String? code, RegExpMatch? match)

Properties

cardinalDirection String?
Get the cardinal direction associated to the visibility, e.g. "NW" (north west).
no setterinherited
cavok bool
Get True if CAVOK, False if not.
getter/setter pair
code String?
Get the code of the group.
no setterinherited
directionInDegrees double?
Get the visibility direction in degrees.
no setterinherited
directionInGradians double?
Get the visibility direction in gradians.
no setterinherited
directionInRadians double?
Get the visibility direction in radians.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inFeet double?
Get the visibility in feet.
no setterinherited
inKilometers double?
Get the visibility in kilometers.
no setterinherited
inMeters double?
Get the visibility in meters.
no setterinherited
inSeaMiles double?
Get the visibility in sea miles.
no setterinherited
length int
Get the length of the code of the group.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the object data as a map like Map<String, dynamic>.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the object data as a string in JSON format.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited