heightInMeters property
double?
get
heightInMeters
Get the height of the significant wave in meters.
Implementation
double? get heightInMeters => _height.inMeters;
Get the height of the significant wave in meters.
double? get heightInMeters => _height.inMeters;