MetarWeatherTrends class

Basic structure for weather trends sections in METAR.

Inheritance

Constructors

MetarWeatherTrends()

Properties

codes List<String?>
Get the codes of every group found in the report as a List<String>.
no setterinherited
first ChangePeriod
Get the first item of the list.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
items List<ChangePeriod>
Get the groups found in report as a List<Group>.
no setterinherited
iter Iterator<ChangePeriod>
Get an iterator from the groups found in report.
no setterinherited
last ChangePeriod
Get the last item of the list.
no setterinherited
length int
Get the length of the items.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(ChangePeriod group) → void
Adds groups to the list.
inherited
asList() List<Map<String, Object?>>
Returns the items data as a List<Map<String, Object?>>.
inherited
asMap() Map<String, Object?>
Returns the items data as a map like Map<String, Object?>.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the items data as a string in JSON format.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) ChangePeriod
inherited