MetarWindshearRunway class

Basic structure for windshear runways groups in METAR.

Inheritance

Constructors

MetarWindshearRunway(String? code, RegExpMatch? match)

Properties

all bool
Get if ALL is found in the group.
no setter
code String?
Get the code of the group.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
length int
Get the length of the code of the group.
no setterinherited
name String?
Get the name of the runway with windshear.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the object data as a map like Map<String, dynamic>.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the object data as a string in JSON format.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited