ModifierMixin mixin

Superclass constraints
Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
modifier Modifier
Get the modifier type of the report.
no setter
rawCode String
Get the raw code as its received in the instance.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<String>
Get the report separated in its sections as a list of strings.
no setterinherited
station Station
Get the station data of the report.
no setterinherited
time Time
Get the time of the report.
no setterinherited
type_ ReportType
Get the type of the report.
no setterinherited
unparsedGroups List<String>
Get the unparsed groups of the report.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the report data as a map like Map<String, Object?>.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the report data as a string in JSON format.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited