setValidPeriod method

void setValidPeriod(
  1. String code,
  2. RegExpMatch match,
  3. Time initTime
)

Set the valid time period group of the change indicator.

Args: match (RegExpMatch): the match of the regular expression of valid time period. initTime (Time): the initial datetime of valid time of the forecast.

Implementation

void setValidPeriod(String code, RegExpMatch match, Time initTime) {
  _valid = Valid.fromTaf(code, match, initTime.time);

  if (_code!.startsWith('FM')) {
    _translation = '$_valid';
  } else {
    _translation = '$_translation $_valid';
    _code = '$_code ${_valid.code}';
  }
}