TafTemperature class

Basic structure for temperature groups in TAF.

Inheritance
Mixed-in types

Constructors

TafTemperature(String? code, RegExpMatch? match, DateTime time)

Properties

code String?
Get the code of the group.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inCelsius double?
Get the temperature in Celsius.
no setterinherited
inFahrenheit double?
Get the temperature in Fahrenheit.
no setterinherited
inKelvin double?
Get the temperature in Kelvin.
no setterinherited
inRankine double?
Get the temperature in Rankine.
no setterinherited
length int
Get the length of the code of the group.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time Time?
Get the datetime the temperature is expected to happen.
no setter
value double?
Get the value as a float.
no setterinherited

Methods

asMap() Map<String, Object?>
Returns the numeric value data as a map like Map<String, dynamic>.
override
converted({double? conversionDouble, double conversionFunction(double)?}) double?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() String
Returns the object data as a string in JSON format.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited