time property
Time?
get
time
Get the datetime the temperature is expected to happen.
Implementation
Time? get time => _time;
Get the datetime the temperature is expected to happen.
Time? get time => _time;