isBottomSheetDismissing property

bool get isBottomSheetDismissing

Returns true if a bottom sheet dismissal is in progress Bottom sheets use the sheet dismissing notifier

Implementation

static bool get isBottomSheetDismissing {
  if (!isSheetDismissing) return false;
  // If sheet is dismissing, check if it's actually a bottom sheet
  final position = _sheetController.state?.sheetPosition;
  return position == SheetPosition.bottom;
}