isSheetDismissing property
bool
get
isSheetDismissing
Returns true if a sheet dismissal is in progress
Implementation
static bool get isSheetDismissing => _sheetDismissingNotifier.state;
Returns true if a sheet dismissal is in progress
static bool get isSheetDismissing => _sheetDismissingNotifier.state;