isSideSheetDismissing property

bool get isSideSheetDismissing

Returns true if a side sheet dismissal is in progress Side sheets use the sheet dismissing notifier

Implementation

static bool get isSideSheetDismissing {
  if (!isSheetDismissing) return false;
  // If sheet is dismissing, check if it's actually a side sheet
  final position = _sheetController.state?.sheetPosition;
  return position == SheetPosition.left || position == SheetPosition.right;
}