isTopSheetDismissing property

bool get isTopSheetDismissing

Returns true if a top sheet dismissal is in progress Top sheets use the sheet dismissing notifier

Implementation

static bool get isTopSheetDismissing {
  if (!isSheetDismissing) return false;
  // If sheet is dismissing, check if it's actually a top sheet
  final position = _sheetController.state?.sheetPosition;
  return position == SheetPosition.top;
}