ModalStackLevels class

Default rendering stack levels for modal types.

Higher values render above lower values.

Constructors

ModalStackLevels()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

critical → const int
custom → const int
dialog → const int
sheet → const int
snackbar → const int