onSwipeDismiss property
Called when the snackbar is dismissed by swipe, with direction ('left' or 'right')
Implementation
final Function(String direction)? onSwipeDismiss;
Called when the snackbar is dismissed by swipe, with direction ('left' or 'right')
final Function(String direction)? onSwipeDismiss;