InterleavedOverlayLayer class

Immutable description of a single interleaved overlay layer.

Constructors

InterleavedOverlayLayer({required String id, required int activationOrder, required int stackLevel, required InterleavedLayerBuilder builder})
const

Properties

activationOrder int
final
builder InterleavedLayerBuilder
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackLevel int
final

Methods

copyWith({int? activationOrder, int? stackLevel, InterleavedLayerBuilder? builder}) InterleavedOverlayLayer
Creates a new instance with selective overrides (keeps immutability).
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited