isCustomActive property
bool
get
isCustomActive
Returns true if a custom modal is currently active
Implementation
static bool get isCustomActive => _customController.state != null;
Returns true if a custom modal is currently active
static bool get isCustomActive => _customController.state != null;