isSideSheetActive property

bool get isSideSheetActive

Returns true if a side sheet is currently active Side sheets use the sheet controller with left/right positions

Implementation

static bool get isSideSheetActive {
  final sheet = _sheetController.state;
  if (sheet == null) return false;
  final position = sheet.sheetPosition;
  return position == SheetPosition.left || position == SheetPosition.right;
}