isTopSheetActive property

bool get isTopSheetActive

Returns true if a top sheet is currently active Top sheets use the sheet controller with top position

Implementation

static bool get isTopSheetActive {
  final sheet = _sheetController.state;
  if (sheet == null) return false;
  final position = sheet.sheetPosition;
  return position == SheetPosition.top;
}