JsonModel class abstract

Constructors

JsonModel()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getField<T>(String key, {required T defaultValue}) → T
getFieldList<T>(String key, {required List<T> defaultValue}) List<T>
getModel<T>(String key, T fromJson(Map<String, dynamic>), {required T defaultValue}) → T
getModelList<T>(String key, T fromJson(Map<String, dynamic>), {required List<T> defaultValue}) List<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerFields({Map<String, dynamic>? fields}) → void
Automatically register all fields passed to constructor
toJson() Map<String, dynamic>
toJsonPretty() String
toJsonString() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited