emit method
Sets a new value value to the data stream stream.
If there are active subscribers, the value will be dispatched to them.
Implementation
void emit(String stream, [var value]) {
_mStorage.setValue(stream, value ?? true);
}
Sets a new value value to the data stream stream.
If there are active subscribers, the value will be dispatched to them.
void emit(String stream, [var value]) {
_mStorage.setValue(stream, value ?? true);
}