LoadingIndicator class final

A widget that displays various loading animations.

Inheritance
Available extensions

Constructors

LoadingIndicator({Key? key, required Indicator indicatorType, List<Color>? colors, Color? backgroundColor, double? strokeWidth, Color? pathBackgroundColor, bool pause = false})
const

Properties

backgroundColor Color?
The background color of the container. Defaults to transparent.
final
colors List<Color>?
The colors used to draw the shape. If not provided, uses the primary color from the current theme.
final
hashCode int
The hash code for this object.
no setterinherited
indicatorType Indicator
The type of loading animation to display.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
pathBackgroundColor Color?
The background color for shapes with cut edges.
final
pause bool
Controls the animation state. When true, the animation is paused. Defaults to false.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double?
The stroke width of lines in the animation.
final

Methods

addMaterialWidget() Material

Available on Widget, provided by the GenericExtensions extension

addTooltipWidget(String toolTip) Tooltip

Available on Widget, provided by the GenericExtensions extension

borderRadius([BorderRadiusGeometry? borderRadius]) Widget

Available on Widget, provided by the GenericExtensions extension

boxDecoration([BoxDecoration? boxDecoration]) Widget

Available on Widget, provided by the GenericExtensions extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
colorFilter([ColorFilter? colorFilter]) Widget

Available on Widget, provided by the GenericExtensions extension

set parent widget in center
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited