AllowedCharsTextInputFormatter class

AllowedCharsTextInputFormatter is a TextInputFormatter that allows only characters that match the given allowedPattern.

The pattern is matched against each grapheme cluster of the input individually, so it should describe a single character (e.g. [0-9], [a-zA-Z], [\p{L}]). For unicode property classes like \p{L} the RegExp must be created with unicode: true.

Inheritance

Constructors

AllowedCharsTextInputFormatter(RegExp allowedPattern)

Properties

allowedPattern RegExp
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatEditUpdate(TextEditingValue oldValue, TextEditingValue newValue) TextEditingValue
Called when text is being typed or cut/copy/pasted in the EditableText.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited