alignment property

Alignment alignment
final

Where each child is placed inside the animated box. Also determines the anchor point from which the box appears to grow or shrink (e.g. Alignment.center expands from the center, Alignment.topLeft expands down-right).

Implementation

final Alignment alignment;