child property
The child currently shown. Changing it triggers a transition to
the new value. A null child is valid and animates the box to
zero size.
Implementation
final Widget? child;
The child currently shown. Changing it triggers a transition to
the new value. A null child is valid and animates the box to
zero size.
final Widget? child;