clipBehavior property
How content that exceeds the current animated box size is clipped during the transition.
Implementation
final Clip clipBehavior;
How content that exceeds the current animated box size is clipped during the transition.
final Clip clipBehavior;