fadeDuration property
Duration of the cross-fade between the old child (fading out) and the new child (fading in).
This also serves as the base for the size animation's duration; see sizeDurationFactor.
Implementation
final Duration fadeDuration;
Duration of the cross-fade between the old child (fading out) and the new child (fading in).
This also serves as the base for the size animation's duration; see sizeDurationFactor.
final Duration fadeDuration;