modeLargerChild property

AnimatedBetweenMode modeLargerChild
final

How the child with the larger natural area fills the animated box during a transition. See AnimatedBetweenMode for the available modes.

When the two children have the exact same area, modeShorterChild is used for both and this parameter is ignored.

Implementation

final AnimatedBetweenMode modeLargerChild;