CapitalizationTextInputFormatter class
CapitalizationTextInputFormatter is a TextInputFormatter that capitalizes text as the user types, according to the specified Capitalize option:
- Capitalize.firstLetterUpper: Capitalizes only the first letter of the text.
- Capitalize.uppercase: Capitalizes all letters of the text.
- Capitalize.lowercase: Converts all letters of the text to lowercase.
- Capitalize.title: Capitalizes the first letter of each word in the text (approximation of English title case).
- Inheritance
-
- Object
- TextInputFormatter
- CapitalizationTextInputFormatter
Constructors
- CapitalizationTextInputFormatter(Capitalize? capitalize)
Properties
- capitalize → Capitalize?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- firstLetterUppercase → CapitalizationTextInputFormatter
-
final
- lowercase → CapitalizationTextInputFormatter
-
final
- title → CapitalizationTextInputFormatter
-
English title case (approximation).
final
- uppercase → CapitalizationTextInputFormatter
-
final