builder property

CircleButtonBuilder? builder
final

The builder can be used to animate the button when the button is tapped, or when the mouse is over it.

Implementation

final CircleButtonBuilder? builder;