ColumnSuper constructor

ColumnSuper({
  1. Key? key,
  2. required List<Widget?> children,
  3. double outerDistance = 0.0,
  4. double innerDistance = 0.0,
  5. bool invert = false,
  6. Alignment alignment = Alignment.center,
  7. Widget? separator,
  8. bool separatorOnTop = true,
  9. bool removeChildrenWithNoHeight = false,
})

Given a list of children widgets, this will arrange them in a column. It can overlap cells, add separators and more.

Note this is not a substitute for Flutter's native Column, it doesn't try to have a similar API, and it doesn't do all that Column does. In special, Expanded and Flexible widgets don't work inside of ColumnSuper, and it will overflow if the column is not big enough to fit its contents. ColumnSuper is meant only for certain use cases where Column won't work, like when you need overlapping cells or separators.

For more info, see: https://pub.dartlang.org/packages/assorted_layout_widgets

Implementation

ColumnSuper({
  Key? key,
  required List<Widget?> children,
  this.outerDistance = 0.0,
  this.innerDistance = 0.0,
  this.invert = false,
  this.alignment = Alignment.center,
  this.separator,
  this.separatorOnTop = true,
  this.removeChildrenWithNoHeight = false,
}) : super(key: key, children: _childrenPlusSeparator(children, separator));