getTime method

String? getTime()

This Method returns the Current Time of Countdown Timer i.e Time Used in terms of Forward Countdown and Time Left in terms of Reverse Countdown

Implementation

String? getTime() {
  if (_state != null && _state?._controller != null) {
    return _state?._getTime(
        _state!._controller!.duration! * _state!._controller!.value);
  }
  return "";
}