Email class

Constructors

Email(String address)
Creates an email value from raw text.

Properties

address String
The raw email address text.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid({bool allowTopLevelDomains = false, bool allowInternational = true}) bool
Returns true when address is a valid complete email address.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sanitize({bool allowInternational = true}) String
Returns address with unsupported characters removed. Use this while the user is typing an email address.
toString() String
A string representation of this object.
override
tryFix({bool allowTopLevelDomains = false, bool allowInternational = true}) String?
Tries to turn address into a valid email address.

Operators

operator ==(Object other) bool
The equality operator.
override