enableStrictCheck property

bool enableStrictCheck
final

If true, all checks must be successful to consider the internet as connected.

If false, only one successful check is required to consider the internet as connected.

Defaults to false.

Important: Use this feature only with custom-defined Uris, not with the default ones, to avoid potential issues with reliability or service outages.

Implementation

final bool enableStrictCheck;