lastTryResults property
InternetStatus?
get
lastTryResults
The result of the last attempt to check the internet status.
Implementation
InternetStatus? get lastTryResults => _lastStatus;
The result of the last attempt to check the internet status.
InternetStatus? get lastTryResults => _lastStatus;