ifDebugPrint property
Set to true to enable debug printing of height changes and shrink decisions.
Implementation
static bool ifDebugPrint = false;
Set to true to enable debug printing of height changes and shrink decisions.
static bool ifDebugPrint = false;