decimalWithComma property

NumbersTextInputFormatter decimalWithComma
final

Allows only typing numbers 0-9, plus dot or comma, but if the user types a dot it will always appear as a comma.

Implementation

static final decimalWithComma = NumbersTextInputFormatter._(_NumbersMode.decimalComma);