OtpCodeLetterSet enum

Which alphabet of characters is accepted by the OtpCodeVerificationField.

Some values are letters-portion sets that combine with OtpCodeType to add digits (aToZ, unicodeLetters, custom). Others are self-contained alphabets that imply both digits and letters and constrain OtpCodeType (binary, crockford, hexadecimal, base62, all). See the "Compatibility (asserts at construction)" section in the OtpCodeVerificationField class doc for the full rules.

Inheritance
Available extensions

Values

aToZ → const OtpCodeLetterSet

English ASCII letters: a-z and A-Z (26 letters).

unicodeLetters → const OtpCodeLetterSet

Any Unicode letter (Greek, Cyrillic, CJK, etc.).

all → const OtpCodeLetterSet

Any character accepted by Dart.

crockford → const OtpCodeLetterSet

Crockford alphabet: 'ABCDEFGHJKMNPQRSTVWXYZ0123456789' which is base32 without the easily-confused chars 0/O and 1/I/L. See: https://www.crockford.com/base32.html Note: A better way to implement this is for you to allow OtpCodeLetterSet.aToZ plus OtpCodeType.numbersAndLetters plus OtpCodeLetterCasing.uppercase, and then you'd get the resulting code and convert O to 0, and I/L to 1.

binary → const OtpCodeLetterSet

Only 0 and 1, for binary codes.

hexadecimal → const OtpCodeLetterSet

Digits 0-9 and letters A-F/a-f.

base62 → const OtpCodeLetterSet

Base62 alphabet: digits 0-9, plus letters A-Z and a-z (62 chars). Useful for short URL-safe codes. Pair with OtpCodeLetterCasing.mixed to keep both cases distinct.

custom → const OtpCodeLetterSet

Only chars specified by the OtpCodeVerificationField.customSet. If you specify this, you MUST provide a customSet string with the allowed characters, or you'll get an error.

Properties

$ Signal<T>

Available on T, provided by the SignalEnumExtensions extension

Return a signal from a Enum value
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OtpCodeLetterSet>
A constant List of the values in this enum, in order of their declaration.