OtpCodeType enum

Which characters are accepted by the OtpCodeVerificationField.

Inheritance
Available extensions

Values

numbersOnly → const OtpCodeType

Only digits 0-9.

lettersOnly → const OtpCodeType

Only letters. The exact alphabet depends on OtpCodeLetterSet, and the casing is normalized according to OtpCodeLetterCasing.

numbersAndLetters → const OtpCodeType

Digits 0-9 plus letters (subject to OtpCodeLetterSet and OtpCodeLetterCasing).

Properties

$ Signal<T>

Available on T, provided by the SignalEnumExtensions extension

Return a signal from a Enum value
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<OtpCodeType>
A constant List of the values in this enum, in order of their declaration.