buttonBackgroundColor property
Background color of the "Go back to try again" button on the expired view, also used for the "Retry" button shown after a verification failure.
Implementation
final Color? buttonBackgroundColor;
Background color of the "Go back to try again" button on the expired view, also used for the "Retry" button shown after a verification failure.
final Color? buttonBackgroundColor;