buttonBuilder property

Widget Function({required Color? backgroundColor, required String label, required VoidCallback onTap, required Color? textColor, required TextStyle? textStyle})? buttonBuilder
final

Builder for the both the expired-button (shown when the countdown expires) and the retry-button (shown if onSubmit throws).

Receives the onTap callback that must be invoked when the button is tapped, along with other parameters that can be used to customize the button's appearance.

Implementation

final Widget Function({
  required VoidCallback onTap,
  required String label,
  required TextStyle? textStyle,
  required Color? backgroundColor,
  required Color? textColor,
})?
buttonBuilder;