cursorSize property
Size of the blinking cursor drawn inside the active (next-to-fill)
digit box while the user is typing. Defaults to Size(3, 30).
Implementation
final Size? cursorSize;
Size of the blinking cursor drawn inside the active (next-to-fill)
digit box while the user is typing. Defaults to Size(3, 30).
final Size? cursorSize;