digitTextStyle property
Text style used for each typed digit displayed inside the digit boxes.
Should include the digit color (foreground) since no separate color parameter is exposed for the digit text.
Implementation
final TextStyle? digitTextStyle;