expiredMessage property
Headline shown on the expired view, above the onExpiredGoBack
button. Defaults to 'Your code expired'.
Implementation
final String expiredMessage;
Headline shown on the expired view, above the onExpiredGoBack
button. Defaults to 'Your code expired'.
final String expiredMessage;