RowSuper constructor
RowSuper({
- Key? key,
- required List<
Widget?> children, - double outerDistance = 0.0,
- double innerDistance = 0.0,
- bool invert = false,
- Alignment alignment = Alignment.center,
- Widget? separator,
- bool separatorOnTop = true,
- bool fitHorizontally = false,
- double? shrinkLimit,
- MainAxisSize mainAxisSize = MainAxisSize.min,
- bool fill = false,
Given a list of children widgets, this will arrange them in a row. It can overlap cells, add separators and more.
On contrary to ColumnSuper and the native Row (which will overflow if the
children are too large to fit the available free space), RowSuper may resize its
children proportionately to their minimum intrinsic width.
For more info, see: https://pub.dartlang.org/packages/assorted_layout_widgets
Implementation
RowSuper({
Key? key,
required List<Widget?> children,
this.outerDistance = 0.0,
this.innerDistance = 0.0,
this.invert = false,
this.alignment = Alignment.center,
this.separator,
this.separatorOnTop = true,
this.fitHorizontally = false,
this.shrinkLimit,
this.mainAxisSize = MainAxisSize.min,
this.fill = false,
}) : super(
key: key,
children: _childrenPlusSeparator(
children, separator, fitHorizontally, shrinkLimit));