bottomShadowDividerColor property
The divider color that appears along the bottom edge of the shadow.
Defaults to a semi-transparent black.
Implementation
final Color bottomShadowDividerColor;
The divider color that appears along the bottom edge of the shadow.
Defaults to a semi-transparent black.
final Color bottomShadowDividerColor;