ifHidesShadowForNegativeScroll property
If true, hides the shadow when the scroll position is negative (overscrolled).
Defaults to false.
Implementation
final bool ifHidesShadowForNegativeScroll;
If true, hides the shadow when the scroll position is negative (overscrolled).
Defaults to false.
final bool ifHidesShadowForNegativeScroll;