topShadowDividerColor property
The divider color that appears along the top edge of the shadow.
Defaults to a semi-transparent black.
Implementation
final Color topShadowDividerColor;
The divider color that appears along the top edge of the shadow.
Defaults to a semi-transparent black.
final Color topShadowDividerColor;