mainAxisSize property
Determines whether the widget will occupy the full available width (MainAxisSize.max) or only as much as it needs (MainAxisSize.min).
Implementation
final MainAxisSize mainAxisSize;
Determines whether the widget will occupy the full available width (MainAxisSize.max) or only as much as it needs (MainAxisSize.min).
final MainAxisSize mainAxisSize;