formatEditUpdate method

  1. @override
TextEditingValue formatEditUpdate(
  1. TextEditingValue oldValue,
  2. TextEditingValue newValue
)
override

Called when text is being typed or cut/copy/pasted in the EditableText.

You can override the resulting text based on the previous text value and the incoming new text value.

When formatters are chained, oldValue reflects the initial value of TextEditingValue at the beginning of the chain.

Implementation

@override
TextEditingValue formatEditUpdate(
  TextEditingValue oldValue,
  TextEditingValue newValue,
) {
  final int? maxLength = this.maxLength;

  if (maxLength == null || maxLength == -1 || (newValue.text.length <= maxLength)) {
    return newValue;
  }

  assert(maxLength > 0);

  // If already at the maximum and tried to enter even more, and has no
  // selection, keep the old value.
  if (oldValue.text.length == maxLength && oldValue.selection.isCollapsed) {
    return oldValue;
  }

  // Enforced to return a truncated value.
  return truncate(newValue, maxLength);
}