maxLength property
The limit on the number of String.length characters that this formatter will allow. The value must be null or greater than zero. If it is null or -1, then no limit is enforced.
Implementation
final int? maxLength;
The limit on the number of String.length characters that this formatter will allow. The value must be null or greater than zero. If it is null or -1, then no limit is enforced.
final int? maxLength;