string static method
Creates a new instance of xid and returns the string representation
Implementation
static String string() {
return get().toString();
}
Creates a new instance of xid and returns the string representation
static String string() {
return get().toString();
}