CombinedIterableView<T> class
A view of several iterables combined sequentially into a single iterable.
All methods and accessors treat the CombinedIterableView as if it were a single concatenated iterable, but the underlying implementation is based on lazily accessing individual iterable instances. This means that if the underlying iterables change, the CombinedIterableView will reflect those changes.
- Inheritance
-
- Object
- IterableBase<
T> - CombinedIterableView
- Available extensions
- DHUCollectionsExtensions
- DHUCollectionsExtensionsNS
- DHUFutureIterableExtension
- DHUIterableDoubleExtensionsNS
- DHUIterableIntExtensionsNS
- DHUIterableNumExtensionsNS
- DHUListDoubleStats
- DHUListIntStats
- DHUListNumStats
- EnumByName
- FutureIterable
- IterableComparableExtension
- IterableConversionX
- IterableDoubleExtension
- IterableExtension
- IterableExtensions
- IterableIntegerExtension
- IterableIterableExtension
- IterableNullableExtension
- IterableNumberExtension
- IterableQueryExtensions
- IterableToJSIterable
- JsonIterableX
- ListExtensions
- MyfindFirstWhereOrNullExt
- NullableIterableConversionX
- NullableIterableExtensions
- SignalIterableExtensions
- SignalIterableUtils
Constructors
-
CombinedIterableView(Iterable<
Iterable< _iterables)T> > -
Creates a combined view of
_iterables.const
Properties
-
$
→ Signal<
Iterable< E> > -
Available on Iterable<
Return a signal from a Iterable valueE> , provided by the SignalIterableExtensions extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.num> , provided by the IterableNumberExtension extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.int> , provided by the IterableIntegerExtension extensionno setter - encodeWithIndent → String
-
Available on Iterable<
Convenience getter mirroring the Map variant for parity.T> , provided by the JsonIterableX extensionno setter - first → T
-
The first element.
no setterinherited
- firstOrNull → T?
-
Available on Iterable<
The first element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter - firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter -
flattened
→ Iterable<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToList
→ List<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToSet
→ Set<
T> -
Available on Iterable<
The unique sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter - halfLength → int
-
Available on Iterable<
Returns half the length (floored).E> , provided by the DHUCollectionsExtensions extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setteroverride
- isEmptyOrNull → bool
-
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensiontrueif this nullable iterable is either null or empty.no setter - isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
- isNotEmptyOrNull → bool
-
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensionfalseif this nullable iterable is either null or empty.no setter -
iterator
→ Iterator<
T> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setteroverride - last → T
-
The last element.
no setterinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - lastOrNull → T?
-
Available on Iterable<
The last element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter - length → int
-
The number of elements in this Iterable.
no setteroverride
- max → int
-
Available on Iterable<
A maximal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - max → num
-
Available on Iterable<
A maximal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - max → double
-
Available on Iterable<
A maximal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - max → T
-
Available on Iterable<
A maximal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - maxOrNull → num?
-
Available on Iterable<
A maximal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullif the iterable is empty.no setter - maxOrNull → int?
-
Available on Iterable<
A maximal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullif the iterable is empty.no setter - maxOrNull → double?
-
Available on Iterable<
A maximal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullif the iterable is empty.no setter - maxOrNull → T?
-
Available on Iterable<
A maximal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullif the iterable is empty.no setter - mean → double
-
Available on Iterable<
Calculates the mean (average) of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - mean → int
-
Available on Iterable<
Calculates the mean (average) of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - mean → num
-
Available on Iterable<
Calculates the mean (average) of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - median → double
-
Available on Iterable<
Determines the median value of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - median → num
-
Available on Iterable<
Determines the median value of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - median → int
-
Available on Iterable<
Determines the median value of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - min → double
-
Available on Iterable<
A minimal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - min → int
-
Available on Iterable<
A minimal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - min → T
-
Available on Iterable<
A minimal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - min → num
-
Available on Iterable<
A minimal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - minOrNull → T?
-
Available on Iterable<
A minimal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullit the iterable is empty.no setter - minOrNull → int?
-
Available on Iterable<
A minimal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullit the iterable is empty.no setter - minOrNull → num?
-
Available on Iterable<
A minimal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullit the iterable is empty.no setter - minOrNull → double?
-
Available on Iterable<
A minimal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullit the iterable is empty.no setter -
mode
→ List<
num> -
Available on Iterable<
Finds the mode(s) of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter -
mode
→ List<
int> -
Available on Iterable<
Finds the mode(s) of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter -
mode
→ List<
double> -
Available on Iterable<
Finds the mode(s) of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter -
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- single → T
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of the iterable, orT> , provided by the IterableExtension extensionnull.no setter - singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter - standardDeviation → num
-
Available on Iterable<
Calculates the standard deviation of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - standardDeviation → int
-
Available on Iterable<
Calculates the standard deviation of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - standardDeviation → double
-
Available on Iterable<
Calculates the standard deviation of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - sum → double
-
Available on Iterable<
The sum of the elements.double> , provided by the IterableDoubleExtension extensionno setter - sum → int
-
Available on Iterable<
The sum of the elements.int> , provided by the IterableIntegerExtension extensionno setter - sum → num
-
Available on Iterable<
The sum of the elements.num> , provided by the IterableNumberExtension extensionno setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter - total → num
-
Available on Iterable<
Calculates the total sum of the numbers in the iterable.num?> ?, provided by the DHUIterableNumExtensionsNS extensionno setter - total → int
-
Available on Iterable<
Calculates the total sum of the integers in the iterable.int?> ?, provided by the DHUIterableIntExtensionsNS extensionno setter - total → double
-
Available on Iterable<
Calculates the total sum of the doubles in the iterable.double?> ?, provided by the DHUIterableDoubleExtensionsNS extensionno setter - variance → num
-
Available on Iterable<
Computes the variance of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - variance → int
-
Available on Iterable<
Computes the variance of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - variance → double
-
Available on Iterable<
Computes the variance of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
any(
bool test(T element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
associate<
K, V> (K keySelector(E), [V valueSelector(E)?]) → Map< K, V> -
Available on Iterable<
Converts the iterable to a map usingE> , provided by the DHUCollectionsExtensions extensionkeySelectorand optionalvalueSelector. -
averageBy(
num selector(T)) → double? -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → Iterable< R> -
A view of this iterable as an iterable of
Rinstances.inherited -
chunked(
int size) → List< List< T> > -
Available on Iterable<
Splits values into fixed-size chunks.T> , provided by the IterableQueryExtensions extension -
chunks(
int size) → List< List< E> > -
Available on Iterable<
Splits the iterable into chunks of sizeE> , provided by the DHUCollectionsExtensions extensionsize. -
concatWithMultipleList(
List< Iterable< iterables) → List<E> >E> -
Available on Iterable<
Returns a list that concatenates this iterable withE> , provided by the DHUCollectionsExtensions extensioniterables. -
concatWithSingleList(
Iterable< E> iterable) → List<E> -
Available on Iterable<
Returns a list that concatenates this iterable withE> , provided by the DHUCollectionsExtensions extensioniterable. -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.override -
containsAll(
Iterable< E> collection) → bool -
Available on Iterable<
Checks if all elements in the specifiedE> , provided by the DHUCollectionsExtensions extensioncollectionare contained in this collection. -
convertAll<
T> () → List< T> -
Available on Iterable<
Converts every element in this iterable toE> , provided by the IterableConversionX extensionT. -
countWhere(
bool test(T element)) → int -
Available on Iterable<
Counts elements matchingT> , provided by the IterableQueryExtensions extensiontest. -
distinctBy<
R> (R keySelector(E), {bool equals(R a, R b)?, int hashCode(R key)?, bool isValidKey(R key)?}) → List< E> -
Available on Iterable<
Returns a new list containing the first occurrence of each distinct element as determined by the key returned fromE> , provided by the DHUCollectionsExtensions extensionkeySelector. -
distinctBy<
K> (K keyOf(T element)) → List< T> -
Available on Iterable<
Returns a list with duplicates removed byT> , provided by the IterableQueryExtensions extensionkeyOf, preserving order. -
drop(
int n) → List< E> -
Available on Iterable<
Returns a list containing all elements except the firstE> , provided by the DHUCollectionsExtensions extensionnelements. -
elementAt(
int index) → T -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
TheT> , provided by the IterableExtension extensionindexth element, ornullif there is no such element. -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
every(
bool test(T element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(T element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
expandIndexed<
R> (Iterable< R> expand(int index, T element)) → Iterable<R> -
Available on Iterable<
Expands each element and index to a number of elements in a new iterable.T> , provided by the IterableExtension extension -
filter(
Predicate< E> test) → List<E> -
Available on Iterable<
Returns a list containing elements that satisfyE> , provided by the DHUCollectionsExtensions extensiontest. -
filterNot(
Predicate< E> test) → List<E> -
Available on Iterable<
Returns a list containing elements that do not satisfyE> , provided by the DHUCollectionsExtensions extensiontest. -
find(
Predicate< E> predicate) → E? -
Available on Iterable<
Returns the first element matchingE> , provided by the DHUCollectionsExtensions extensionpredicate, ornullif element was not found. -
findFirstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Finds the first element satisfying the provided condition, orT> , provided by the MyfindFirstWhereOrNullExt extensionnullif none is found. -
firstHalf(
) → List< E> -
Available on Iterable<
Returns the first half of the iterable.E> , provided by the DHUCollectionsExtensions extension -
firstOrDefault(
E defaultValue) → E -
Available on Iterable<
Returns the first element orE> ?, provided by the DHUCollectionsExtensionsNS extensiondefaultValuewhen null or empty. -
firstWhere(
bool test(T element), {T orElse()?}) → T -
The first element that satisfies the given predicate
test.inherited -
firstWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The first element whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
firstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The first element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
fold<
T> (T initialValue, T combine(T previousValue, T element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
foldIndexed<
R> (R initialValue, R combine(int index, R previous, T element)) → R -
Available on Iterable<
Combine the elements with a value and the current index.T> , provided by the IterableExtension extension -
followedBy(
Iterable< T> other) → Iterable<T> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(T element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
forEachIndexed(
void action(T element, int index)) → void -
Available on Iterable<
Generate forEach but gives index for each elementT> ?, provided by the ListExtensions extension -
forEachIndexed(
void action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element.T> , provided by the IterableExtension extension -
forEachIndexedWhile(
bool action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element and index as long as desired.T> , provided by the IterableExtension extension -
forEachWhile(
bool action(T element)) → void -
Available on Iterable<
Takes an action for each element as long as desired.T> , provided by the IterableExtension extension -
getBigInt(
int index, {dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter< BigInt> ? converter}) → BigInt -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a BigInt. -
getBool(
int index, {dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter< bool> ? converter}) → bool -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a bool. -
getDateTime(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter< DateTime> ? converter}) → DateTime -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a DateTime. -
getDouble(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter< double> ? converter}) → double -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a double. -
getEnum<
T extends Enum> (int index, {required T parser(dynamic), dynamic innerMapKey, int? innerIndex, T? defaultValue, Map< String, dynamic> ? debugInfo}) → T -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto an enum value usingparser. -
getInt(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter< int> ? converter}) → int -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto an int. -
getList<
T> (int index, {dynamic innerMapKey, int? innerIndex, List< T> ? defaultValue, ElementConverter<T> ? elementConverter}) → List<T> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a List ofT. -
getMap<
K2, V2> (int index, {dynamic innerMapKey, int? innerIndex, Map< K2, V2> ? defaultValue, ElementConverter<K2> ? keyConverter, ElementConverter<V2> ? valueConverter}) → Map<K2, V2> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Map ofK2toV2. -
getNum(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter< num> ? converter}) → num -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a num. -
getRandom(
[int? seed]) → E -
Available on Iterable<
Returns a random element.E> , provided by the DHUCollectionsExtensions extension -
getSet<
T> (int index, {dynamic innerMapKey, int? innerIndex, Set< T> ? defaultValue, ElementConverter<T> ? elementConverter}) → Set<T> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Set ofT. -
getString(
int index, {dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter< String> ? converter}) → String -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a String. -
getUri(
int index, {dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter< Uri> ? converter}) → Uri -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Uri. -
groupFoldBy<
K, G> (K keyOf(T element), G combine(G? previous, T element)) → Map< K, G> -
Available on Iterable<
Groups elements byT> , provided by the IterableExtension extensionkeyOfthen folds the elements in each group. -
groupListsBy<
K> (K keyOf(T element)) → Map< K, List< T> > -
Available on Iterable<
Groups elements into lists byT> , provided by the IterableExtension extensionkeyOf. -
groupSetsBy<
K> (K keyOf(T element)) → Map< K, Set< T> > -
Available on Iterable<
Groups elements into sets byT> , provided by the IterableExtension extensionkeyOf. -
intersect(
Iterable other, {ElementConverter< E> ? converter}) → Set<E> -
Available on Iterable<
Returns a union-like set combining this iterable andE> , provided by the IterableConversionX extensionother. -
intersperse(
E element) → Iterable< E> -
Available on Iterable<
InsertsE> , provided by the DHUCollectionsExtensions extensionelementbetween every element in the iterable. -
isEqual(
Iterable< E> ? other) → bool -
Available on Iterable<
Compares two lists for element-by-element equality.E> ?, provided by the DHUCollectionsExtensionsNS extension -
isPrimitive(
) → bool -
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensiontruewhen every element is a primitive value. -
isSorted(
Comparator< T> compare) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableExtension extensioncompareordering. -
isSorted(
[Comparator< T> ? compare]) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableComparableExtension extensioncompareordering. -
isSortedBy<
K extends Comparable< (K> >K keyOf(T element)) → bool -
Available on Iterable<
Whether the elements are sorted by theirT> , provided by the IterableExtension extensionkeyOfproperty. -
isSortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → bool -
Available on Iterable<
Whether the elements areT> , provided by the IterableExtension extensioncompare-sorted by theirkeyOfproperty. -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastBy<
K> (K key(T)) → Map< K, T> -
Available on Iterable<
Associates the elements inT> , provided by the IterableExtension extensionthisby the value returned bykey. -
lastOrDefault(
E defaultValue) → E? -
Available on Iterable<
Returns the last element orE> ?, provided by the DHUCollectionsExtensionsNS extensiondefaultValuewhen null or empty. -
lastWhere(
bool test(T element), {T orElse()?}) → T -
The last element that satisfies the given predicate
test.inherited -
lastWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The last element whose index and value satisfiesT> , provided by the IterableExtension extensiontest. -
lastWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The last element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
map<
T> (T toElement(T e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
mapConcurrent<
R> (Future< R> action(E item), {int parallelism = 1}) → Future<List< R> > -
Available on Iterable<
ExecutesE> , provided by the DHUCollectionsExtensions extensionactionon each element with at mostparallelismconcurrent tasks. -
mapIndexed<
R> (R convert(int index, T element)) → Iterable< R> -
Available on Iterable<
Maps each element and its index to a new value.T> , provided by the IterableExtension extension -
mapIndexedList<
R> (R mapper(int index, E element), {ElementConverter< R> ? converter}) → List<R> -
Available on Iterable<
Maps elements with their index and eagerly materializes the result into a List.E> , provided by the IterableConversionX extension -
mapList<
R> (R mapper(E e), {ElementConverter< R> ? converter}) → List<R> -
Available on Iterable<
Maps the elements and eagerly materializes them into a List using convert_object.E> , provided by the IterableConversionX extension -
none(
bool test(T)) → bool -
Available on Iterable<
Whether no element satisfiesT> , provided by the IterableExtension extensiontest. -
none(
bool test(T element)) → bool -
Available on Iterable<
Returns true when no element satisfiesT> , provided by the IterableQueryExtensions extensiontest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of(
int index) → E? -
Available on Iterable<
Returns the element atE> ?, provided by the DHUCollectionsExtensionsNS extensionindexornullif out of bounds or null. -
orEmpty(
) → Iterable< E> -
Available on Iterable<
Returns this iterable (as is) if it is non-null; otherwise, returns an empty iterable.E> , provided by the DHUCollectionsExtensions extension -
pairwise(
) → List< (E, E)> -
Available on Iterable<
Returns consecutive pairs from the iterable.E> , provided by the DHUCollectionsExtensions extension -
partition(
bool predicate(E)) → (List< E> , List<E> ) -
Available on Iterable<
Splits the iterable into two lists based on theE> , provided by the DHUCollectionsExtensions extensionpredicate. -
percentile(
double percentile) → num -
Available on Iterable<
Computes the specifiednum> , provided by the DHUListNumStats extensionpercentileof the numbers in the iterable. -
percentile(
double percentile) → int -
Available on Iterable<
Computes the specifiedint> , provided by the DHUListIntStats extensionpercentileof the integers in the iterable. -
percentile(
double percentile) → double -
Available on Iterable<
Computes the specifieddouble> , provided by the DHUListDoubleStats extensionpercentileof the doubles in the iterable. -
reduce(
T combine(T value, T element)) → T -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
reduceIndexed(
T combine(int index, T previous, T element)) → T -
Available on Iterable<
Combine the elements with each other and the current index.T> , provided by the IterableExtension extension -
sample(
int count, [Random? random]) → List< T> -
Available on Iterable<
SelectsT> , provided by the IterableExtension extensioncountelements at random from this iterable. -
secondHalf(
) → List< E> -
Available on Iterable<
Returns the second half of the iterable.E> , provided by the DHUCollectionsExtensions extension -
shuffled(
[Random? random]) → List< T> -
Available on Iterable<
Creates a shuffled list of the elements of the iterable.T> , provided by the IterableExtension extension -
singleWhere(
bool test(T element), {T orElse()?}) → T -
The single element that satisfies
test.inherited -
singleWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Returns the single matching element, orT> , provided by the IterableQueryExtensions extensionnullif zero or multiple match. -
skip(
int count) → Iterable< T> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(T value)) → Iterable< T> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
slices(
int length) → Iterable< List< T> > -
Available on Iterable<
Contiguous slices ofT> , provided by the IterableExtension extensionthiswith the givenlength. -
sorted(
Comparator< T> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sorted(
[Comparator< T> ? compare]) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableComparableExtension extension -
sortedBy<
K extends Comparable< (Object?> >K keyOf(T element), {bool descending = false}) → List< T> -
Available on Iterable<
Returns a sorted copy by comparableT> , provided by the IterableQueryExtensions extensionkeyOf. -
sortedBy<
K extends Comparable< (K> >K keyOf(T element)) → List< T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
splitAfter(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements.T> , provided by the IterableExtension extension -
splitAfterIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements and indices.T> , provided by the IterableExtension extension -
splitBefore(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements.T> , provided by the IterableExtension extension -
splitBeforeIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements and indices.T> , provided by the IterableExtension extension -
splitBetween(
bool test(T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements.T> , provided by the IterableExtension extension -
splitBetweenIndexed(
bool test(int index, T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements and indices.T> , provided by the IterableExtension extension -
subtract(
Iterable< E> other) → Set<E> -
Available on Iterable<
Returns a set of elements contained in this collection but not inE> , provided by the DHUCollectionsExtensions extensionother. The returned set preserves the element iteration order of the original collection. -
sumBy(
int selector(T)) → int -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
sumByDouble(
num selector(T)) → double -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
swap(
int i, int j) → List< E> -
Available on Iterable<
Returns a list with elements atE> , provided by the DHUCollectionsExtensions extensioniandjswapped. -
take(
int count) → Iterable< T> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeOnly(
int n) → List< E> -
Available on Iterable<
Returns a list containing the firstE> , provided by the DHUCollectionsExtensions extensionnelements. -
takeWhile(
bool test(T value)) → Iterable< T> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
toJsonList(
{JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) → List -
Available on Iterable<
Converts this iterable to a JSON-encodableT> , provided by the JsonIterableX extensionList. -
toJsonString(
{String? indent, JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) → String -
Available on Iterable<
Converts this iterable to a JSON string (pretty ifT> , provided by the JsonIterableX extensionindentis provided). -
toList(
{bool growable = true}) → List< T> -
Creates a List containing the elements of this Iterable.
inherited
-
toListConverted<
R> () → List< R> -
Available on Iterable<
Converts this iterable to a list of typeE> , provided by the DHUCollectionsExtensions extensionRusing convert_object logic. -
toMutableSet(
{ElementConverter< E> ? converter}) → Set<E> -
Available on Iterable<
Returns this iterable as a mutable Set using the centralized conversion logic.E> , provided by the IterableConversionX extension -
toSet(
) → Set< T> -
Creates a Set containing the same elements as this iterable.
inherited
-
toSetConverted<
R> () → Set< R> -
Available on Iterable<
Converts this iterable to a set of typeE> , provided by the DHUCollectionsExtensions extensionRusing convert_object logic. -
toSignal(
{String? debugLabel, bool autoDispose = false}) → IterableSignal< T> -
Available on Iterable<
Convert an existing list to IterableSignalT> , provided by the SignalIterableUtils extension -
toString(
) → String -
Returns a string representation of (some of) the elements of
this.inherited -
totalBy(
num? valueSelector(E)) → num -
Available on Iterable<
Returns the sum of values calculated byE> ?, provided by the DHUCollectionsExtensionsNS extensionvalueSelectorfor each element. -
tryGetBigInt(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt> ? converter}) → BigInt? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to BigInt. -
tryGetBool(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool> ? converter}) → bool? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to bool. -
tryGetDateTime(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime> ? converter}) → DateTime? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to DateTime. -
tryGetDouble(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double> ? converter}) → double? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to double. -
tryGetEnum<
T extends Enum> (int index, {required T parser(dynamic), List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic> ? debugInfo}) → T? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to an enum usingparser. -
tryGetInt(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int> ? converter}) → int? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to int. -
tryGetList<
T> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, List<T> ? defaultValue, ElementConverter<T> ? elementConverter}) → List<T> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a List ofT. -
tryGetMap<
K2, V2> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Map<K2, V2> ? defaultValue, ElementConverter<K2> ? keyConverter, ElementConverter<V2> ? valueConverter}) → Map<K2, V2> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a Map ofK2toV2. -
tryGetNum(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num> ? converter}) → num? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to num. -
tryGetRandom(
[int? seed]) → E? -
Available on Iterable<
Retrieves a random element or null if the iterable is null.E> ?, provided by the DHUCollectionsExtensionsNS extension -
tryGetSet<
T> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Set<T> ? defaultValue, ElementConverter<T> ? elementConverter}) → Set<T> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a Set ofT. -
tryGetString(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String> ? converter}) → String? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to String. -
tryGetUri(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri> ? converter}) → Uri? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to Uri. -
validate(
) → List< T> -
Available on Iterable<
Validate given List is not null and returns blank list if null. This should not be used to clear listT> ?, provided by the ListExtensions extension -
waitConcurrency(
{int concurrency = 5}) → Future< List< T> > -
Available on Iterable<
Executes the functions in this iterable, running at mostFuture< , provided by the DHUFutureIterableExtension extensionT> Function()>concurrencyfutures simultaneously. -
where(
bool test(T element)) → Iterable< T> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
whereNot(
bool test(T element)) → Iterable< T> -
Available on Iterable<
The elements that do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotNull(
) → Iterable< T> -
Available on Iterable<
The non-T?> , provided by the IterableNullableExtension extensionnullelements of thisIterable. -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited -
windowed(
int size, {int step = 1, bool partials = false}) → List< List< E> > -
Available on Iterable<
Returns a sliding window ofE> , provided by the DHUCollectionsExtensions extensionsizeover the iterable. -
windowed(
int size, {int step = 1, bool partialWindows = false}) → List< List< T> > -
Available on Iterable<
Returns sliding windows ofT> , provided by the IterableQueryExtensions extensionsize.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited