median property
double
get
median
Determines the median value of the doubles in the iterable.
Implementation
double get median => NumbersHelper.median(toList()).toDouble();
Determines the median value of the doubles in the iterable.
double get median => NumbersHelper.median(toList()).toDouble();