Mixin class that implements a throwing version of all list operations that change the List's length.
- Implemented types
-
- List<
E>
- List<
- Available extensions
- AlphaNumericSortingListOfString
- AnimateListExtensions
- BeautifiedJsonListExtension
- DHUCollectionsExtensions
- DHUCollectionsExtensionsNS
- DHUFutureIterableExtension
- DHUIterableDoubleExtensionsNS
- DHUIterableIntExtensionsNS
- DHUIterableNumExtensionsNS
- DHUListDoubleStats
- DHUListIntStats
- DHUListNumStats
- DHUNullableListExtensions
- EnumByName
- EnumValuesParsing
- FutureIterable
- IterableComparableExtension
- IterableConversionX
- IterableDoubleExtension
- IterableExtension
- IterableExtensions
- IterableIntegerExtension
- IterableIterableExtension
- IterableNullableExtension
- IterableNumberExtension
- IterableQueryExtensions
- IterableToJSIterable
- JsonIterableX
- ListChunk
- ListComparableExtensions
- ListExtension
- ListExtensions
- ListExtensions
- ListGroupByExtension
- ListJsonBeautifier
- ListOfDateTimeExtensions
- ListOfTimeOfDayExtensions
- ListToJSArray
- ListX
- MultipleStateRebuilderExtension
- MyfindFirstWhereOrNullExt
- NullableIterableConversionX
- NullableIterableExtensions
- NullableListQueries
- PageSettingsX
- ReactiveModeListX
- SignalIterableExtensions
- SignalIterableUtils
- SignalListExtensions
- SignalListObserveExtension
- SignalListUtils
Constructors
Properties
-
$
→ Signal<
Iterable< E> > -
Available on Iterable<
Return a signal from a Iterable valueE> , provided by the SignalIterableExtensions extensionno setter -
$
→ Signal<
List< E> > -
Available on List<
Return a signal from a List valueE> , provided by the SignalListExtensions extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.num> , provided by the IterableNumberExtension extensionno setter - average → double
-
Available on Iterable<
The arithmetic mean of the elements of a non-empty iterable.int> , provided by the IterableIntegerExtension extensionno setter - beautifiedJson → String
-
Available on List<
Returns a beautified JSON string representation of the list.Map< , provided by the ListJsonBeautifier extensionString, dynamic> >no setter - earliest → TimeOfDay?
-
Available on List<
Find earliest time in the listTimeOfDay> , provided by the ListOfTimeOfDayExtensions extensionno setter - encodedJsonString → String
-
Available on List<
Map< , provided by the BeautifiedJsonListExtension extensionString, dynamic> >no setter - encodeWithIndent → String
-
Available on Iterable<
Convenience getter mirroring the Map variant for parity.T> , provided by the JsonIterableX extensionno setter - first ↔ E
-
The first element.
getter/setter pairinherited
- firstOrNull → T?
-
Available on Iterable<
The first element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter - firstOrNull → T?
-
Available on List<
ReturnsT> , provided by the NullableListQueries extensionnullinstead of throwing if the list is empty.no setter - firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter -
flattened
→ Iterable<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToList
→ List<
T> -
Available on Iterable<
The sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter -
flattenedToSet
→ Set<
T> -
Available on Iterable<
The unique sequential elements of each iterable in this iterable.Iterable< , provided by the IterableIterableExtension extensionT> >no setter - halfLength → int
-
Available on Iterable<
Returns half the length (floored).E> , provided by the DHUCollectionsExtensions extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isEmptyOrNull → bool
-
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensiontrueif this nullable iterable is either null or empty.no setter - isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
- isNotEmptyOrNull → bool
-
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensionfalseif this nullable iterable is either null or empty.no setter -
iterator
→ Iterator<
E> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setterinherited - last ↔ E
-
The last element.
getter/setter pairinherited
- lastOrNull → T?
-
Available on List<
ReturnsT> , provided by the NullableListQueries extensionnullinstead of throwing if the list is empty.no setter - lastOrNull → T?
-
Available on Iterable<
The last element, orT> , provided by the IterableExtension extensionnullif the iterable is empty.no setter - lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - latest → TimeOfDay?
-
Available on List<
Find latest time in the listTimeOfDay> , provided by the ListOfTimeOfDayExtensions extensionno setter - length ↔ int
-
The number of objects in this list.
getter/setter pairinherited-getteroverride-setter
- max → num
-
Available on Iterable<
A maximal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - max → int
-
Available on Iterable<
A maximal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - max → T
-
Available on Iterable<
A maximal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - max → double
-
Available on Iterable<
A maximal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - maxOrNull → num?
-
Available on Iterable<
A maximal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullif the iterable is empty.no setter - maxOrNull → int?
-
Available on Iterable<
A maximal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullif the iterable is empty.no setter - maxOrNull → T?
-
Available on Iterable<
A maximal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullif the iterable is empty.no setter - maxOrNull → double?
-
Available on Iterable<
A maximal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullif the iterable is empty.no setter - mean → num
-
Available on Iterable<
Calculates the mean (average) of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - mean → int
-
Available on Iterable<
Calculates the mean (average) of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - mean → double
-
Available on Iterable<
Calculates the mean (average) of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - median → int
-
Available on Iterable<
Determines the median value of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - median → double
-
Available on Iterable<
Determines the median value of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - median → num
-
Available on Iterable<
Determines the median value of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - min → int
-
Available on Iterable<
A minimal element of the iterable.int> , provided by the IterableIntegerExtension extensionno setter - min → double
-
Available on Iterable<
A minimal element of the iterable.double> , provided by the IterableDoubleExtension extensionno setter - min → num
-
Available on Iterable<
A minimal element of the iterable.num> , provided by the IterableNumberExtension extensionno setter - min → T
-
Available on Iterable<
A minimal element of the iterable.T> , provided by the IterableComparableExtension extensionno setter - minOrNull → int?
-
Available on Iterable<
A minimal element of the iterable, orint> , provided by the IterableIntegerExtension extensionnullit the iterable is empty.no setter - minOrNull → num?
-
Available on Iterable<
A minimal element of the iterable, ornum> , provided by the IterableNumberExtension extensionnullit the iterable is empty.no setter - minOrNull → T?
-
Available on Iterable<
A minimal element of the iterable, orT> , provided by the IterableComparableExtension extensionnullit the iterable is empty.no setter - minOrNull → double?
-
Available on Iterable<
A minimal element of the iterable, ordouble> , provided by the IterableDoubleExtension extensionnullit the iterable is empty.no setter -
mode
→ List<
num> -
Available on Iterable<
Finds the mode(s) of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter -
mode
→ List<
int> -
Available on Iterable<
Finds the mode(s) of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter -
mode
→ List<
double> -
Available on Iterable<
Finds the mode(s) of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter -
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - parser → T Function(dynamic)
-
Available on List<
Returns a name-based parser using EnumParsers.byName.T> , provided by the EnumValuesParsing extensionno setter - parserByIndex → T Function(dynamic)
-
Available on List<
Returns an index-based parser using EnumParsers.byIndex.T> , provided by the EnumValuesParsing extensionno setter - parserCaseInsensitive → T Function(dynamic)
-
Available on List<
Returns a case-insensitive name parser using EnumParsers.byNameCaseInsensitive.T> , provided by the EnumValuesParsing extensionno setter - rebuild → _Rebuild
-
Available on List<
listen to the list of statesReactiveModel> , provided by the ReactiveModeListX extensionno setter -
reversed
→ Iterable<
E> -
An Iterable of the objects in this list in reverse order.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safe → SafeListAccessor
-
Available on List, provided by the ListExtension extension
Get the safe accessor for this list that returns null for invalid indices Usage: list.safe2// returns null if index 2 doesn't existno setter - single → E
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter - singleOrNull → T?
-
Available on Iterable<
The single element of the iterable, orT> , provided by the IterableExtension extensionnull.no setter - standardDeviation → num
-
Available on Iterable<
Calculates the standard deviation of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - standardDeviation → int
-
Available on Iterable<
Calculates the standard deviation of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - standardDeviation → double
-
Available on Iterable<
Calculates the standard deviation of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter - sum → double
-
Available on Iterable<
The sum of the elements.double> , provided by the IterableDoubleExtension extensionno setter - sum → int
-
Available on Iterable<
The sum of the elements.int> , provided by the IterableIntegerExtension extensionno setter - sum → num
-
Available on Iterable<
The sum of the elements.num> , provided by the IterableNumberExtension extensionno setter -
toJS
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or cloning the List.T> , provided by the ListToJSArray extensionno setter -
toJSIterable
→ JSIterable<
T> -
Available on Iterable<
A JSIterable wrapper that proxies to the Dart iterable API.T> , provided by the IterableToJSIterable extensionno setter -
toJSProxyOrRef
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or proxying the List.T> , provided by the ListToJSArray extensionno setter - total → num
-
Available on Iterable<
Calculates the total sum of the numbers in the iterable.num?> ?, provided by the DHUIterableNumExtensionsNS extensionno setter - total → int
-
Available on Iterable<
Calculates the total sum of the integers in the iterable.int?> ?, provided by the DHUIterableIntExtensionsNS extensionno setter - total → double
-
Available on Iterable<
Calculates the total sum of the doubles in the iterable.double?> ?, provided by the DHUIterableDoubleExtensionsNS extensionno setter - variance → num
-
Available on Iterable<
Computes the variance of the numbers in the iterable.num> , provided by the DHUListNumStats extensionno setter - variance → int
-
Available on Iterable<
Computes the variance of the integers in the iterable.int> , provided by the DHUListIntStats extensionno setter - variance → double
-
Available on Iterable<
Computes the variance of the doubles in the iterable.double> , provided by the DHUListDoubleStats extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
E value) → bool -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
addAll(
Iterable< E> iterable) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
animate(
{List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, Duration? interval}) → AnimateList<Widget> -
Available on List<
Wraps the targetWidget> , provided by the AnimateListExtensions extensionList<Widget>in an AnimateList instance, and returns the instance for chaining calls. Ex.[foo, bar].animate()is equivalent toAnimateList(children: [foo, bar]). -
any(
bool test(E element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asMap(
) → Map< int, E> -
An unmodifiable Map view of this list.
inherited
-
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
associate<
K, V> (K keySelector(E), [V valueSelector(E)?]) → Map< K, V> -
Available on Iterable<
Converts the iterable to a map usingE> , provided by the DHUCollectionsExtensions extensionkeySelectorand optionalvalueSelector. -
averageBy(
num selector(T)) → double? -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
binarySearch(
E element, [int compare(E, E)?]) → int -
Available on List<
Returns the index ofE> , provided by the ListComparableExtensions extensionelementin this sorted list. -
binarySearch(
E element, int compare(E, E)) → int -
Available on List<
Returns the index ofE> , provided by the ListExtensions extensionelementin this sorted list. -
binarySearchBy<
K extends Comparable< (K> >E element, K keyOf(E element), [int start = 0, int? end]) → int -
Available on List<
Returns the index ofE> , provided by the ListExtensions extensionelementin this sorted list. -
binarySearchByCompare<
K> (E element, K keyOf(E element), int compare(K, K), [int start = 0, int? end]) → int -
Available on List<
Returns the index ofE> , provided by the ListExtensions extensionelementin this sorted list. -
builder(
Widget builder(), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Builds a widget that listens to all injected instances in this list.Injected> , provided by the MultipleStateRebuilderExtension extension -
builderData(
Widget builder(List dataList), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
builderDataIndexed(
Widget builder(int index, dynamic data), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
builderState(
Widget builder(List< SnapState> ), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
cast<
R> () → List< R> -
Returns a view of this list as a list of
Rinstances.inherited -
chunked(
int size) → List< List< T> > -
Available on Iterable<
Splits values into fixed-size chunks.T> , provided by the IterableQueryExtensions extension -
chunks(
int size) → List< List< E> > -
Available on Iterable<
Splits the iterable into chunks of sizeE> , provided by the DHUCollectionsExtensions extensionsize. -
clear(
) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
concatWithMultipleList(
List< Iterable< iterables) → List<E> >E> -
Available on Iterable<
Returns a list that concatenates this iterable withE> , provided by the DHUCollectionsExtensions extensioniterables. -
concatWithSingleList(
Iterable< E> iterable) → List<E> -
Available on Iterable<
Returns a list that concatenates this iterable withE> , provided by the DHUCollectionsExtensions extensioniterable. -
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
containsAll(
Iterable< E> collection) → bool -
Available on Iterable<
Checks if all elements in the specifiedE> , provided by the DHUCollectionsExtensions extensioncollectionare contained in this collection. -
convertAll<
T> () → List< T> -
Available on Iterable<
Converts every element in this iterable toE> , provided by the IterableConversionX extensionT. -
convertToStringList(
{bool showSeconds = false, bool showUtcSymbol = false, bool preferUtcSymbolThanZ = false, bool showSeparatorSymbol = true, bool use24HourFormat = true}) → List< String> -
Available on List<
Convert list of TimeOfDay to list of stringsTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
convertToStringList(
) → List< String> -
Available on List<
DateTime> , provided by the ListOfDateTimeExtensions extension -
countWhere(
bool test(T element)) → int -
Available on Iterable<
Counts elements matchingT> , provided by the IterableQueryExtensions extensiontest. -
distinctBy<
K> (K keyOf(T element)) → List< T> -
Available on Iterable<
Returns a list with duplicates removed byT> , provided by the IterableQueryExtensions extensionkeyOf, preserving order. -
distinctBy<
R> (R keySelector(E), {bool equals(R a, R b)?, int hashCode(R key)?, bool isValidKey(R key)?}) → List< E> -
Available on Iterable<
Returns a new list containing the first occurrence of each distinct element as determined by the key returned fromE> , provided by the DHUCollectionsExtensions extensionkeySelector. -
doesIndexExist(
int index) → bool -
Available on List, provided by the ListExtension extension
-
drop(
int n) → List< E> -
Available on Iterable<
Returns a list containing all elements except the firstE> , provided by the DHUCollectionsExtensions extensionnelements. -
elementAt(
int index) → E -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → E? -
Available on List<
TheE> , provided by the ListExtensions extensionindexth element, ornullif there is no such element. -
elementAtOrNull(
int index) → T? -
Available on List<
Returns the element atT> , provided by the NullableListQueries extensionindexornullwhen out of bounds. -
elementAtOrNull(
int index) → T? -
Available on Iterable<
TheT> , provided by the IterableExtension extensionindexth element, ornullif there is no such element. -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
equals(
List< E> other, [Equality<E> equality = const DefaultEquality()]) → bool -
Available on List<
WhetherE> , provided by the ListExtensions extensionotherhas the same elements as this list. -
every(
bool test(E element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(E element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
expandIndexed<
R> (Iterable< R> expand(int index, T element)) → Iterable<R> -
Available on Iterable<
Expands each element and index to a number of elements in a new iterable.T> , provided by the IterableExtension extension -
expandIndexed<
R> (Iterable< R> expand(int index, E element)) → Iterable<R> -
Available on List<
Expands each element and index to a number of elements in a new iterable.E> , provided by the ListExtensions extension -
fillRange(
int start, int end, [E? fillValue]) → void -
Overwrites a range of elements with
fillValue.inherited -
filter(
Predicate< E> test) → List<E> -
Available on Iterable<
Returns a list containing elements that satisfyE> , provided by the DHUCollectionsExtensions extensiontest. -
filterNot(
Predicate< E> test) → List<E> -
Available on Iterable<
Returns a list containing elements that do not satisfyE> , provided by the DHUCollectionsExtensions extensiontest. -
find(
Predicate< E> predicate) → E? -
Available on Iterable<
Returns the first element matchingE> , provided by the DHUCollectionsExtensions extensionpredicate, ornullif element was not found. -
findFirstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Finds the first element satisfying the provided condition, orT> , provided by the MyfindFirstWhereOrNullExt extensionnullif none is found. -
firstHalf(
) → List< E> -
Available on Iterable<
Returns the first half of the iterable.E> , provided by the DHUCollectionsExtensions extension -
firstOrDefault(
E defaultValue) → E -
Available on Iterable<
Returns the first element orE> ?, provided by the DHUCollectionsExtensionsNS extensiondefaultValuewhen null or empty. -
firstWhere(
bool test(E element), {E orElse()?}) → E -
The first element that satisfies the given predicate
test.inherited -
firstWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The first element whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
firstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The first element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
firstWhereOrNull(
bool test(T element)) → T? -
Available on List<
Returns the first element matchingT> , provided by the NullableListQueries extensiontest, ornullwhen not found. -
fold<
T> (T initialValue, T combine(T previousValue, E element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
foldIndexed<
R> (R initialValue, R combine(int index, R previous, T element)) → R -
Available on Iterable<
Combine the elements with a value and the current index.T> , provided by the IterableExtension extension -
followedBy(
Iterable< E> other) → Iterable<E> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(E element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
forEachIndexed(
void action(T element, int index)) → void -
Available on Iterable<
Generate forEach but gives index for each elementT> ?, provided by the ListExtensions extension -
forEachIndexed(
void action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element.T> , provided by the IterableExtension extension -
forEachIndexed(
void action(int index, E element)) → void -
Available on List<
Takes an action for each element.E> , provided by the ListExtensions extension -
forEachIndexedWhile(
bool action(int index, T element)) → void -
Available on Iterable<
Takes an action for each element and index as long as desired.T> , provided by the IterableExtension extension -
forEachIndexedWhile(
bool action(int index, E element)) → void -
Available on List<
Takes an action for each element and index as long as desired.E> , provided by the ListExtensions extension -
forEachWhile(
bool action(T element)) → void -
Available on Iterable<
Takes an action for each element as long as desired.T> , provided by the IterableExtension extension -
forEachWhile(
bool action(E element)) → void -
Available on List<
Takes an action for each element as long as desired.E> , provided by the ListExtensions extension -
getBigInt(
int index, {dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter< BigInt> ? converter}) → BigInt -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a BigInt. -
getBool(
int index, {dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter< bool> ? converter}) → bool -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a bool. -
getDateTime(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter< DateTime> ? converter}) → DateTime -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a DateTime. -
getDouble(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter< double> ? converter}) → double -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a double. -
getEnum<
T extends Enum> (int index, {required T parser(dynamic), dynamic innerMapKey, int? innerIndex, T? defaultValue, Map< String, dynamic> ? debugInfo}) → T -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto an enum value usingparser. -
getInt(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter< int> ? converter}) → int -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto an int. -
getList<
T> (int index, {dynamic innerMapKey, int? innerIndex, List< T> ? defaultValue, ElementConverter<T> ? elementConverter}) → List<T> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a List ofT. -
getMap<
K2, V2> (int index, {dynamic innerMapKey, int? innerIndex, Map< K2, V2> ? defaultValue, ElementConverter<K2> ? keyConverter, ElementConverter<V2> ? valueConverter}) → Map<K2, V2> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Map ofK2toV2. -
getNum(
int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter< num> ? converter}) → num -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a num. -
getRandom(
[int? seed]) → E -
Available on Iterable<
Returns a random element.E> , provided by the DHUCollectionsExtensions extension -
getRange(
int start, int end) → Iterable< E> -
Creates an Iterable that iterates over a range of elements.
inherited
-
getSet<
T> (int index, {dynamic innerMapKey, int? innerIndex, Set< T> ? defaultValue, ElementConverter<T> ? elementConverter}) → Set<T> -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Set ofT. -
getString(
int index, {dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter< String> ? converter}) → String -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a String. -
getUri(
int index, {dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter< Uri> ? converter}) → Uri -
Available on Iterable<
Converts the element atE> , provided by the IterableConversionX extensionindexto a Uri. -
groupBy<
K> (K keyOf(T element)) → Map< K, List< T> > -
Available on List<
Groups elements by the value returned byT> , provided by the ListGroupByExtension extensionkeyOf. -
groupFoldBy<
K, G> (K keyOf(T element), G combine(G? previous, T element)) → Map< K, G> -
Available on Iterable<
Groups elements byT> , provided by the IterableExtension extensionkeyOfthen folds the elements in each group. -
groupListsBy<
K> (K keyOf(T element)) → Map< K, List< T> > -
Available on Iterable<
Groups elements into lists byT> , provided by the IterableExtension extensionkeyOf. -
groupSetsBy<
K> (K keyOf(T element)) → Map< K, Set< T> > -
Available on Iterable<
Groups elements into sets byT> , provided by the IterableExtension extensionkeyOf. -
indexOf(
E element, [int start = 0]) → int -
The first index of
elementin this list.inherited -
indexOfOrNull(
E? element) → int? -
Available on List<
Returns the index ofE> ?, provided by the DHUNullableListExtensions extensionelementor null if the list is null/empty orelementis null. -
indexWhere(
bool test(E element), [int start = 0]) → int -
The first index in the list that satisfies the provided
test.inherited -
indexWhereOrNull(
Predicate< E> test, [int start = 0]) → int? -
Available on List<
Searches for an element that satisfies theE> ?, provided by the DHUNullableListExtensions extensiontestpredicate, starting atstart, and returns its index. Returns null if no such element is found or if the list is null/empty. -
inj(
{bool autoDisposeWhenNotUsed = true}) → ReactiveModel< List< T> > -
Available on List<
create a ReactiveModel stateT> , provided by the ListX extension -
insert(
int index, E element) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
insertAll(
int index, Iterable< E> iterable) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
intersect(
Iterable other, {ElementConverter< E> ? converter}) → Set<E> -
Available on Iterable<
Returns a union-like set combining this iterable andE> , provided by the IterableConversionX extensionother. -
intersperse(
E element) → Iterable< E> -
Available on Iterable<
InsertsE> , provided by the DHUCollectionsExtensions extensionelementbetween every element in the iterable. -
isEqual(
Iterable< E> ? other) → bool -
Available on Iterable<
Compares two lists for element-by-element equality.E> ?, provided by the DHUCollectionsExtensionsNS extension -
isPrimitive(
) → bool -
Available on Iterable<
ReturnsE> ?, provided by the DHUCollectionsExtensionsNS extensiontruewhen every element is a primitive value. -
isSorted(
[Comparator< T> ? compare]) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableComparableExtension extensioncompareordering. -
isSorted(
Comparator< T> compare) → bool -
Available on Iterable<
Whether the elements are sorted by theT> , provided by the IterableExtension extensioncompareordering. -
isSortedBy<
K extends Comparable< (K> >K keyOf(T element)) → bool -
Available on Iterable<
Whether the elements are sorted by theirT> , provided by the IterableExtension extensionkeyOfproperty. -
isSortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → bool -
Available on Iterable<
Whether the elements areT> , provided by the IterableExtension extensioncompare-sorted by theirkeyOfproperty. -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastBy<
K> (K key(T)) → Map< K, T> -
Available on Iterable<
Associates the elements inT> , provided by the IterableExtension extensionthisby the value returned bykey. -
lastIndexOf(
E element, [int? start]) → int -
The last index of
elementin this list.inherited -
lastIndexWhere(
bool test(E element), [int? start]) → int -
The last index in the list that satisfies the provided
test.inherited -
lastOrDefault(
E defaultValue) → E? -
Available on Iterable<
Returns the last element orE> ?, provided by the DHUCollectionsExtensionsNS extensiondefaultValuewhen null or empty. -
lastWhere(
bool test(E element), {E orElse()?}) → E -
The last element that satisfies the given predicate
test.inherited -
lastWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The last element whose index and value satisfiesT> , provided by the IterableExtension extensiontest. -
lastWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The last element satisfyingT> , provided by the IterableExtension extensiontest, ornullif there are none. -
lastWhereOrNull(
bool test(T element)) → T? -
Available on List<
Returns the last element matchingT> , provided by the NullableListQueries extensiontest, ornullwhen not found. -
lowerBound(
E element, int compare(E, E)) → int -
Available on List<
Returns the index whereE> , provided by the ListExtensions extensionelementshould be in this sorted list. -
lowerBound(
E element, [int compare(E, E)?]) → int -
Available on List<
Returns the index whereE> , provided by the ListComparableExtensions extensionelementshould be in this sorted list. -
lowerBoundBy<
K extends Comparable< (K> >E element, K keyOf(E), [int start = 0, int? end]) → int -
Available on List<
Returns the index whereE> , provided by the ListExtensions extensionelementshould be in this sorted list. -
lowerBoundByCompare<
K> (E element, K keyOf(E), int compare(K, K), [int start = 0, int? end]) → int -
Available on List<
Returns the index whereE> , provided by the ListExtensions extensionelementshould be in this sorted list. -
map<
T> (T toElement(E e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
mapConcurrent<
R> (Future< R> action(E item), {int parallelism = 1}) → Future<List< R> > -
Available on Iterable<
ExecutesE> , provided by the DHUCollectionsExtensions extensionactionon each element with at mostparallelismconcurrent tasks. -
mapIndexed<
R> (R convert(int index, T element)) → Iterable< R> -
Available on Iterable<
Maps each element and its index to a new value.T> , provided by the IterableExtension extension -
mapIndexed<
R> (R convert(int index, E element)) → Iterable< R> -
Available on List<
Maps each element and its index to a new value.E> , provided by the ListExtensions extension -
mapIndexedList<
R> (R mapper(int index, E element), {ElementConverter< R> ? converter}) → List<R> -
Available on Iterable<
Maps elements with their index and eagerly materializes the result into a List.E> , provided by the IterableConversionX extension -
mapList<
R> (R mapper(E e), {ElementConverter< R> ? converter}) → List<R> -
Available on Iterable<
Maps the elements and eagerly materializes them into a List using convert_object.E> , provided by the IterableConversionX extension -
none(
bool test(T element)) → bool -
Available on Iterable<
Returns true when no element satisfiesT> , provided by the IterableQueryExtensions extensiontest. -
none(
bool test(T)) → bool -
Available on Iterable<
Whether no element satisfiesT> , provided by the IterableExtension extensiontest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
{String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
observe<
R> ({Key? key, required R combine(List), required Widget builder(R), void onInit(R value)?, Function? onValueUpdated, void onAfterBuild(R value)?, void onDispose(R value)?, bool shouldRebuild(R newValue, R oldValue)?, bool shouldNotify(R newValue, R oldValue)?, bool equals(R a, R b)?, Duration? debounce, Duration? throttle, void onError(Object error, StackTrace stack)?, Widget errorBuilder(Object error)?, Widget loadingBuilder()?, String? debugLabel, bool debugPrint = false}) → SignalsWatch< R> -
Available on List<
Observe multiple signals and rebuild when any changes.ReadonlySignal> , provided by the SignalListObserveExtension extension -
of(
int index) → E? -
Available on Iterable<
Returns the element atE> ?, provided by the DHUCollectionsExtensionsNS extensionindexornullif out of bounds or null. -
orEmpty(
) → Iterable< E> -
Available on Iterable<
Returns this iterable (as is) if it is non-null; otherwise, returns an empty iterable.E> , provided by the DHUCollectionsExtensions extension -
pairwise(
) → List< (E, E)> -
Available on Iterable<
Returns consecutive pairs from the iterable.E> , provided by the DHUCollectionsExtensions extension -
parserWithFallback(
T fallback) → T Function(dynamic) -
Available on List<
Returns a name-based parser that returnsT> , provided by the EnumValuesParsing extensionfallbackfor unknown values. -
partition(
bool predicate(E)) → (List< E> , List<E> ) -
Available on Iterable<
Splits the iterable into two lists based on theE> , provided by the DHUCollectionsExtensions extensionpredicate. -
percentile(
double percentile) → num -
Available on Iterable<
Computes the specifiednum> , provided by the DHUListNumStats extensionpercentileof the numbers in the iterable. -
percentile(
double percentile) → int -
Available on Iterable<
Computes the specifiedint> , provided by the DHUListIntStats extensionpercentileof the integers in the iterable. -
percentile(
double percentile) → double -
Available on Iterable<
Computes the specifieddouble> , provided by the DHUListDoubleStats extensionpercentileof the doubles in the iterable. -
reduce(
E combine(E value, E element)) → E -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
reduceIndexed(
T combine(int index, T previous, T element)) → T -
Available on Iterable<
Combine the elements with each other and the current index.T> , provided by the IterableExtension extension -
remove(
Object? value) → bool -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
removeAt(
int index) → E -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
removeLast(
) → E -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
removeRange(
int start, int end) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
removeWhere(
bool test(E)) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
replaceRange(
int start, int end, Iterable< E> iterable) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
retainWhere(
bool test(E)) → void -
Throws an UnsupportedError;
operations that change the length of the list are disallowed.
override
-
reverseRange(
int start, int end) → void -
Available on List<
Reverses the elements in a range of the list.E> , provided by the ListExtensions extension -
sample(
int count, [Random? random]) → List< T> -
Available on Iterable<
SelectsT> , provided by the IterableExtension extensioncountelements at random from this iterable. -
secondHalf(
) → List< E> -
Available on Iterable<
Returns the second half of the iterable.E> , provided by the DHUCollectionsExtensions extension -
setAll(
int index, Iterable< E> iterable) → void -
Overwrites elements with the objects of
iterable.inherited -
setRange(
int start, int end, Iterable< E> iterable, [int skipCount = 0]) → void -
Writes some elements of
iterableinto a range of this list.inherited -
shuffle(
[Random? random]) → void -
Shuffles the elements of this list randomly.
inherited
-
shuffled(
[Random? random]) → List< T> -
Available on Iterable<
Creates a shuffled list of the elements of the iterable.T> , provided by the IterableExtension extension -
shuffleRange(
int start, int end, [Random? random]) → void -
Available on List<
Shuffle a range of elements.E> , provided by the ListExtensions extension -
singleWhere(
bool test(E element), {E orElse()?}) → E -
The single element that satisfies
test.inherited -
singleWhereIndexedOrNull(
bool test(int index, T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Returns the single matching element, orT> , provided by the IterableQueryExtensions extensionnullif zero or multiple match. -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
The single element satisfyingT> , provided by the IterableExtension extensiontest. -
skip(
int count) → Iterable< E> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(E value)) → Iterable< E> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
slice(
int start, [int? end]) → ListSlice< E> -
Available on List<
A fixed length view of a range of this list.E> , provided by the ListExtensions extension -
slices(
int length) → Iterable< List< T> > -
Available on Iterable<
Contiguous slices ofT> , provided by the IterableExtension extensionthiswith the givenlength. -
slices(
int length) → Iterable< List< E> > -
Available on List<
Contiguous slices ofE> , provided by the ListExtensions extensionthiswith the givenlength. -
sort(
[int compare(E a, E b)?]) → void -
Sorts this list according to the order specified by the
comparefunction.inherited -
sortBy<
K extends Comparable< (K> >K keyOf(E element), [int start = 0, int? end]) → void -
Available on List<
Sorts elements by the natural order of theirE> , provided by the ListExtensions extensionkeyOfproperty. -
sortByCompare<
K> (K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → void -
Available on List<
Sorts elements by theE> , provided by the ListExtensions extensioncompareof theirkeyOfproperty. -
sortChronologically(
) → List< TimeOfDay> -
Available on List<
Sort TimeOfDay list chronologicallyTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
sorted(
Comparator< T> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sorted(
[Comparator< T> ? compare]) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableComparableExtension extension -
sortedBy<
K extends Comparable< (Object?> >K keyOf(T element), {bool descending = false}) → List< T> -
Available on Iterable<
Returns a sorted copy by comparableT> , provided by the IterableQueryExtensions extensionkeyOf. -
sortedBy<
K extends Comparable< (K> >K keyOf(T element)) → List< T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sortedByCompare<
K> (K keyOf(T element), Comparator< K> compare) → List<T> -
Available on Iterable<
Creates a sorted list of the elements of the iterable.T> , provided by the IterableExtension extension -
sortInAlphaNumericalOrder(
) → List< String> -
Available on List<
String> , provided by the AlphaNumericSortingListOfString extension -
sortRange(
int start, int end, [int compare(E a, E b)?]) → void -
Available on List<
Sort a range of elements byE> , provided by the ListComparableExtensions extensioncompare. -
sortRange(
int start, int end, int compare(E a, E b)) → void -
Available on List<
Sort a range of elements byE> , provided by the ListExtensions extensioncompare. -
splitAfter(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements.T> , provided by the IterableExtension extension -
splitAfterIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks after some elements and indices.T> , provided by the IterableExtension extension -
splitBefore(
bool test(T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements.T> , provided by the IterableExtension extension -
splitBeforeIndexed(
bool test(int index, T element)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks before some elements and indices.T> , provided by the IterableExtension extension -
splitBetween(
bool test(T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements.T> , provided by the IterableExtension extension -
splitBetweenIndexed(
bool test(int index, T first, T second)) → Iterable< List< T> > -
Available on Iterable<
Splits the elements into chunks between some elements and indices.T> , provided by the IterableExtension extension -
splitInChunks(
int chunkSize) → List< List< T> > -
sublist(
int start, [int? end]) → List< E> -
Returns a new list containing the elements between
startandend.inherited -
subtract(
Iterable< E> other) → Set<E> -
Available on Iterable<
Returns a set of elements contained in this collection but not inE> , provided by the DHUCollectionsExtensions extensionother. The returned set preserves the element iteration order of the original collection. -
sumBy(
int selector(T)) → int -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
sumByDouble(
num selector(T)) → double -
Available on Iterable<
Example:T> ?, provided by the ListExtensions extension -
swap(
int index1, int index2) → void -
Available on List<
Swaps two elements of this list.E> , provided by the ListExtensions extension -
swap(
int i, int j) → List< E> -
Available on Iterable<
Returns a list with elements atE> , provided by the DHUCollectionsExtensions extensioniandjswapped. -
take(
int count) → Iterable< E> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeOnly(
int n) → List< E> -
Available on Iterable<
Returns a list containing the firstE> , provided by the DHUCollectionsExtensions extensionnelements. -
takeWhile(
bool test(E value)) → Iterable< E> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
to(
String routeName, {Object? arguments, Map< String, String> queryParams = const {}, bool isStrictMode = false}) → List<PageSettings> -
Available on List<
Add the page of routeName to PageSettingsPageSettings> , provided by the PageSettingsX extension -
toAndRemoveUntil(
String routeName, String untilRouteName) → List< PageSettings> -
Available on List<
Add the page with the givenPageSettings> , provided by the PageSettingsX extensionrouteNameand remove all pages until the page withuntilRouteNamename. -
toDateTimeList(
DateTime date, {bool isUtc = true}) → List< DateTime> -
Available on List<
Convert all TimeOfDay to DateTime on a specific dateTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
toJsonList(
{JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) → List -
Available on Iterable<
Converts this iterable to a JSON-encodableT> , provided by the JsonIterableX extensionList. -
toJsonString(
{String? indent, JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) → String -
Available on Iterable<
Converts this iterable to a JSON string (pretty ifT> , provided by the JsonIterableX extensionindentis provided). -
toList(
{bool growable = true}) → List< E> -
Creates a List containing the elements of this Iterable.
inherited
-
toListConverted<
R> () → List< R> -
Available on Iterable<
Converts this iterable to a list of typeE> , provided by the DHUCollectionsExtensions extensionRusing convert_object logic. -
toMutableSet(
{ElementConverter< E> ? converter}) → Set<E> -
Available on Iterable<
Returns this iterable as a mutable Set using the centralized conversion logic.E> , provided by the IterableConversionX extension -
toReplacement(
String routeName) → List< PageSettings> -
Available on List<
Add the page with the givenPageSettings> , provided by the PageSettingsX extensionrouteNameand remove the last page. -
toSet(
) → Set< E> -
Creates a Set containing the same elements as this iterable.
inherited
-
toSetConverted<
R> () → Set< R> -
Available on Iterable<
Converts this iterable to a set of typeE> , provided by the DHUCollectionsExtensions extensionRusing convert_object logic. -
toSignal(
{String? debugLabel, bool autoDispose = false}) → IterableSignal< T> -
Available on Iterable<
Convert an existing list to IterableSignalT> , provided by the SignalIterableUtils extension -
toSignal(
{String? debugLabel, bool autoDispose = false}) → ListSignal< T> -
Available on List<
Convert an existing list to ListSignalT> , provided by the SignalListUtils extension -
toString(
) → String -
A string representation of this object.
inherited
-
totalBy(
num? valueSelector(E)) → num -
Available on Iterable<
Returns the sum of values calculated byE> ?, provided by the DHUCollectionsExtensionsNS extensionvalueSelectorfor each element. -
tryGetBigInt(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt> ? converter}) → BigInt? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to BigInt. -
tryGetBool(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool> ? converter}) → bool? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to bool. -
tryGetDateTime(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime> ? converter}) → DateTime? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to DateTime. -
tryGetDouble(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double> ? converter}) → double? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to double. -
tryGetEnum<
T extends Enum> (int index, {required T parser(dynamic), List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic> ? debugInfo}) → T? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to an enum usingparser. -
tryGetInt(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int> ? converter}) → int? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to int. -
tryGetList<
T> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, List<T> ? defaultValue, ElementConverter<T> ? elementConverter}) → List<T> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a List ofT. -
tryGetMap<
K2, V2> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Map<K2, V2> ? defaultValue, ElementConverter<K2> ? keyConverter, ElementConverter<V2> ? valueConverter}) → Map<K2, V2> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a Map ofK2toV2. -
tryGetNum(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num> ? converter}) → num? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to num. -
tryGetRandom(
[int? seed]) → E? -
Available on Iterable<
Retrieves a random element or null if the iterable is null.E> ?, provided by the DHUCollectionsExtensionsNS extension -
tryGetSet<
T> (int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Set<T> ? defaultValue, ElementConverter<T> ? elementConverter}) → Set<T> ? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to a Set ofT. -
tryGetString(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String> ? converter}) → String? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to String. -
tryGetUri(
int index, {List< int> ? alternativeIndices, dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri> ? converter}) → Uri? -
Available on Iterable<
Tries to convert the element atE> ?, provided by the NullableIterableConversionX extensionindex(or fallback indices) to Uri. -
tryRemoveAt(
int index) → void -
Available on List<
Safely removes the element at the specifiedE> ?, provided by the DHUNullableListExtensions extensionindexif the list is non-null and non-empty. -
tryRemoveWhere(
bool predicate(E element)) → void -
Available on List<
Safely removes elements that satisfyE> ?, provided by the DHUNullableListExtensions extensionpredicate. -
update<
R> (dynamic mutator(R state), {int index = 0, bool shouldNotify = true, String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
updateAll<
R> (dynamic mutator(R state), {bool shouldNotify = true, String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
validate(
) → List< T> -
Available on Iterable<
Validate given List is not null and returns blank list if null. This should not be used to clear listT> ?, provided by the ListExtensions extension -
waitConcurrency(
{int concurrency = 5}) → Future< List< T> > -
Available on Iterable<
Executes the functions in this iterable, running at mostFuture< , provided by the DHUFutureIterableExtension extensionT> Function()>concurrencyfutures simultaneously. -
where(
bool test(E element)) → Iterable< E> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereIndexed(
bool test(int index, E element)) → Iterable< E> -
Available on List<
The elements whose value and index satisfiesE> , provided by the ListExtensions extensiontest. -
whereIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index satisfiesT> , provided by the IterableExtension extensiontest. -
whereNot(
bool test(T element)) → Iterable< T> -
Available on Iterable<
The elements that do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotIndexed(
bool test(int index, E element)) → Iterable< E> -
Available on List<
The elements whose value and index do not satisfyE> , provided by the ListExtensions extensiontest. -
whereNotIndexed(
bool test(int index, T element)) → Iterable< T> -
Available on Iterable<
The elements whose value and index do not satisfyT> , provided by the IterableExtension extensiontest. -
whereNotNull(
) → Iterable< T> -
Available on Iterable<
The non-T?> , provided by the IterableNullableExtension extensionnullelements of thisIterable. -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited -
windowed(
int size, {int step = 1, bool partials = false}) → List< List< E> > -
Available on Iterable<
Returns a sliding window ofE> , provided by the DHUCollectionsExtensions extensionsizeover the iterable. -
windowed(
int size, {int step = 1, bool partialWindows = false}) → List< List< T> > -
Available on Iterable<
Returns sliding windows ofT> , provided by the IterableQueryExtensions extensionsize.
Operators
-
operator +(
List< E> other) → List<E> -
Returns the concatenation of this list and
other.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → E -
The object at the given
indexin the list.inherited -
operator []=(
int index, E value) → void -
Sets the value at the given
indexin the list tovalue.inherited