NonGrowableListView<E> class

A fixed-length list.

A NonGrowableListView contains a List object and ensures that its length does not change. Methods that would change the length of the list, such as add and remove, throw an UnsupportedError. All other methods work directly on the underlying list.

This class does allow changes to the contents of the wrapped list. You can, for example, sort the list. Permitted operations defer to the wrapped list.

Inheritance
Implemented types
Mixed-in types
Available extensions

Constructors

NonGrowableListView(List<E> listBase)

Properties

$ Signal<List<E>>

Available on List<E>, provided by the SignalListExtensions extension

Return a signal from a List value
no setter
$ Signal<Iterable<E>>

Available on Iterable<E>, provided by the SignalIterableExtensions extension

Return a signal from a Iterable value
no setter
average double

Available on Iterable<num>, provided by the IterableNumberExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
average double

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
beautifiedJson String

Available on List<Map<String, dynamic>>, provided by the ListJsonBeautifier extension

Returns a beautified JSON string representation of the list.
no setter
earliest TimeOfDay?

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Find earliest time in the list
no setter
encodedJsonString String

Available on List<Map<String, dynamic>>, provided by the BeautifiedJsonListExtension extension

no setter
encodeWithIndent String

Available on Iterable<T>, provided by the JsonIterableX extension

Convenience getter mirroring the Map variant for parity.
no setter
first ↔ E
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on List<T>, provided by the NullableListQueries extension

Returns null instead of throwing if the list is empty.
no setter
flattened Iterable<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToList List<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToSet Set<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The unique sequential elements of each iterable in this iterable.
no setter
halfLength int

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns half the length (floored).
no setter
hashCode int
The hash code for this object.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isEmptyOrNull bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns true if this nullable iterable is either null or empty.
no setter
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
isNotEmptyOrNull bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns false if this nullable iterable is either null or empty.
no setter
iterator Iterator<E>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ E
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on List<T>, provided by the NullableListQueries extension

Returns null instead of throwing if the list is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
latest TimeOfDay?

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Find latest time in the list
no setter
length int
The number of elements in this Iterable.
getter/setter pairinherited
max num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable.
no setter
max int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable.
no setter
max → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable.
no setter
max double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable.
no setter
maxOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
mean num

Available on Iterable<num>, provided by the DHUListNumStats extension

Calculates the mean (average) of the numbers in the iterable.
no setter
mean int

Available on Iterable<int>, provided by the DHUListIntStats extension

Calculates the mean (average) of the integers in the iterable.
no setter
mean double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Calculates the mean (average) of the doubles in the iterable.
no setter
median int

Available on Iterable<int>, provided by the DHUListIntStats extension

Determines the median value of the integers in the iterable.
no setter
median double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Determines the median value of the doubles in the iterable.
no setter
median num

Available on Iterable<num>, provided by the DHUListNumStats extension

Determines the median value of the numbers in the iterable.
no setter
min int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable.
no setter
min double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable.
no setter
min num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable.
no setter
min → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable.
no setter
minOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
mode List<num>

Available on Iterable<num>, provided by the DHUListNumStats extension

Finds the mode(s) of the numbers in the iterable.
no setter
mode List<int>

Available on Iterable<int>, provided by the DHUListIntStats extension

Finds the mode(s) of the integers in the iterable.
no setter
mode List<double>

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Finds the mode(s) of the doubles in the iterable.
no setter
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
parser → T Function(dynamic)

Available on List<T>, provided by the EnumValuesParsing extension

Returns a name-based parser using EnumParsers.byName.
no setter
parserByIndex → T Function(dynamic)

Available on List<T>, provided by the EnumValuesParsing extension

Returns an index-based parser using EnumParsers.byIndex.
no setter
parserCaseInsensitive → T Function(dynamic)

Available on List<T>, provided by the EnumValuesParsing extension

Returns a case-insensitive name parser using EnumParsers.byNameCaseInsensitive.
no setter
rebuild → _Rebuild

Available on List<ReactiveModel>, provided by the ReactiveModeListX extension

listen to the list of states
no setter
reversed Iterable<E>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safe SafeListAccessor

Available on List, provided by the ListExtension extension

Get the safe accessor for this list that returns null for invalid indices Usage: list.safe2 // returns null if index 2 doesn't exist
no setter
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element of the iterable, or null.
no setter
standardDeviation num

Available on Iterable<num>, provided by the DHUListNumStats extension

Calculates the standard deviation of the numbers in the iterable.
no setter
standardDeviation int

Available on Iterable<int>, provided by the DHUListIntStats extension

Calculates the standard deviation of the integers in the iterable.
no setter
standardDeviation double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Calculates the standard deviation of the doubles in the iterable.
no setter
sum double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

The sum of the elements.
no setter
sum int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The sum of the elements.
no setter
sum num

Available on Iterable<num>, provided by the IterableNumberExtension extension

The sum of the elements.
no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSIterable JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
total num

Available on Iterable<num?>?, provided by the DHUIterableNumExtensionsNS extension

Calculates the total sum of the numbers in the iterable.
no setter
total int

Available on Iterable<int?>?, provided by the DHUIterableIntExtensionsNS extension

Calculates the total sum of the integers in the iterable.
no setter
total double

Available on Iterable<double?>?, provided by the DHUIterableDoubleExtensionsNS extension

Calculates the total sum of the doubles in the iterable.
no setter
variance num

Available on Iterable<num>, provided by the DHUListNumStats extension

Computes the variance of the numbers in the iterable.
no setter
variance int

Available on Iterable<int>, provided by the DHUListIntStats extension

Computes the variance of the integers in the iterable.
no setter
variance double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Computes the variance of the doubles in the iterable.
no setter
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E value) bool
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
addAll(Iterable<E> iterable) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
animate({List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, Duration? interval}) AnimateList<Widget>

Available on List<Widget>, provided by the AnimateListExtensions extension

Wraps the target List<Widget> in an AnimateList instance, and returns the instance for chaining calls. Ex. [foo, bar].animate() is equivalent to AnimateList(children: [foo, bar]).
any(bool test(E)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, E>
An unmodifiable Map view of this list.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
associate<K, V>(K keySelector(E), [V valueSelector(E)?]) Map<K, V>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts the iterable to a map using keySelector and optional valueSelector.
averageBy(num selector(T)) double?

Available on Iterable<T>?, provided by the ListExtensions extension

Example:
binarySearch(E element, [int compare(E, E)?]) int

Available on List<E>, provided by the ListComparableExtensions extension

Returns the index of element in this sorted list.
binarySearch(E element, int compare(E, E)) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
binarySearchBy<K extends Comparable<K>>(E element, K keyOf(E element), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
binarySearchByCompare<K>(E element, K keyOf(E element), int compare(K, K), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index of element in this sorted list.
builder(Widget builder(), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

Builds a widget that listens to all injected instances in this list.
builderData(Widget builder(List dataList), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

builderDataIndexed(Widget builder(int index, dynamic data), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

builderState(Widget builder(List<SnapState>), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<T>() List<T>
A view of this iterable as an iterable of R instances.
inherited
chunked(int size) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Splits values into fixed-size chunks.
chunks(int size) List<List<E>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Splits the iterable into chunks of size size.
clear() → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
concatWithMultipleList(List<Iterable<E>> iterables) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list that concatenates this iterable with iterables.
concatWithSingleList(Iterable<E> iterable) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list that concatenates this iterable with iterable.
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
containsAll(Iterable<E> collection) bool

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Checks if all elements in the specified collection are contained in this collection.
convertAll<T>() List<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts every element in this iterable to T.
convertToStringList({bool showSeconds = false, bool showUtcSymbol = false, bool preferUtcSymbolThanZ = false, bool showSeparatorSymbol = true, bool use24HourFormat = true}) List<String>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Convert list of TimeOfDay to list of strings
convertToStringList() List<String>

Available on List<DateTime>, provided by the ListOfDateTimeExtensions extension

countWhere(bool test(T element)) int

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Counts elements matching test.
distinctBy<K>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a list with duplicates removed by keyOf, preserving order.
distinctBy<R>(R keySelector(E), {bool equals(R a, R b)?, int hashCode(R key)?, bool isValidKey(R key)?}) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a new list containing the first occurrence of each distinct element as determined by the key returned from keySelector.
doesIndexExist(int index) bool

Available on List, provided by the ListExtension extension

drop(int n) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing all elements except the first n elements.
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the element at index or null when out of bounds.
elementAtOrNull(int index) → E?

Available on List<E>, provided by the ListExtensions extension

The indexth element, or null if there is no such element.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The indexth element, or null if there is no such element.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
equals(List<E> other, [Equality<E> equality = const DefaultEquality()]) bool

Available on List<E>, provided by the ListExtensions extension

Whether other has the same elements as this list.
every(bool test(E)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(E)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
expandIndexed<R>(Iterable<R> expand(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Expands each element and index to a number of elements in a new iterable.
expandIndexed<R>(Iterable<R> expand(int index, E element)) Iterable<R>

Available on List<E>, provided by the ListExtensions extension

Expands each element and index to a number of elements in a new iterable.
fillRange(int start, int end, [E? fillValue]) → void
Overwrites a range of elements with fillValue.
inherited
filter(Predicate<E> test) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing elements that satisfy test.
filterNot(Predicate<E> test) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing elements that do not satisfy test.
find(Predicate<E> predicate) → E?

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the first element matching predicate, or null if element was not found.
findFirstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the MyfindFirstWhereOrNullExt extension

Finds the first element satisfying the provided condition, or null if none is found.
firstHalf() List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the first half of the iterable.
firstOrDefault(E defaultValue) → E

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the first element or defaultValue when null or empty.
firstWhere(bool test(E), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element whose value and index satisfies test.
firstWhereOrNull(bool test(T element)) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the first element matching test, or null when not found.
firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element satisfying test, or null if there are none.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
foldIndexed<R>(R initialValue, R combine(int index, R previous, T element)) → R

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with a value and the current index.
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void f(E)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element.
forEachIndexed(void action(T element, int index)) → void

Available on Iterable<T>?, provided by the ListExtensions extension

Generate forEach but gives index for each element
forEachIndexed(void action(int index, E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element.
forEachIndexedWhile(bool action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element and index as long as desired.
forEachIndexedWhile(bool action(int index, E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element and index as long as desired.
forEachWhile(bool action(E element)) → void

Available on List<E>, provided by the ListExtensions extension

Takes an action for each element as long as desired.
forEachWhile(bool action(T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element as long as desired.
getBigInt(int index, {dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt>? converter}) BigInt

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a BigInt.
getBool(int index, {dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool>? converter}) bool

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a bool.
getDateTime(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime>? converter}) DateTime

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a DateTime.
getDouble(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double>? converter}) double

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a double.
getEnum<T extends Enum>(int index, {required T parser(dynamic), dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic>? debugInfo}) → T

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to an enum value using parser.
getInt(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int>? converter}) int

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to an int.
getList<T>(int index, {dynamic innerMapKey, int? innerIndex, List<T>? defaultValue, ElementConverter<T>? elementConverter}) List<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a List of T.
getMap<K2, V2>(int index, {dynamic innerMapKey, int? innerIndex, Map<K2, V2>? defaultValue, ElementConverter<K2>? keyConverter, ElementConverter<V2>? valueConverter}) Map<K2, V2>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Map of K2 to V2.
getNum(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num>? converter}) num

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a num.
getRandom([int? seed]) → E

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a random element.
getRange(int start, int end) Iterable<E>
Creates an Iterable that iterates over a range of elements.
inherited
getSet<T>(int index, {dynamic innerMapKey, int? innerIndex, Set<T>? defaultValue, ElementConverter<T>? elementConverter}) Set<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Set of T.
getString(int index, {dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String>? converter}) String

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a String.
getUri(int index, {dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri>? converter}) Uri

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Uri.
groupBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on List<T>, provided by the ListGroupByExtension extension

Groups elements by the value returned by keyOf.
groupFoldBy<K, G>(K keyOf(T element), G combine(G? previous, T element)) Map<K, G>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements by keyOf then folds the elements in each group.
groupListsBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into lists by keyOf.
groupSetsBy<K>(K keyOf(T element)) Map<K, Set<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into sets by keyOf.
indexOf(E element, [int start = 0]) int
The first index of element in this list.
inherited
indexOfOrNull(E? element) int?

Available on List<E>?, provided by the DHUNullableListExtensions extension

Returns the index of element or null if the list is null/empty or element is null.
indexWhere(bool test(E), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
indexWhereOrNull(Predicate<E> test, [int start = 0]) int?

Available on List<E>?, provided by the DHUNullableListExtensions extension

Searches for an element that satisfies the test predicate, starting at start, and returns its index. Returns null if no such element is found or if the list is null/empty.
inj({bool autoDisposeWhenNotUsed = true}) ReactiveModel<List<T>>

Available on List<T>, provided by the ListX extension

create a ReactiveModel state
insert(int index, E element) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
insertAll(int index, Iterable<E> iterable) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
intersect(Iterable other, {ElementConverter<E>? converter}) Set<E>

Available on Iterable<E>, provided by the IterableConversionX extension

Returns a union-like set combining this iterable and other.
intersperse(E element) Iterable<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Inserts element between every element in the iterable.
isEqual(Iterable<E>? other) bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Compares two lists for element-by-element equality.
isPrimitive() bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns true when every element is a primitive value.
isSorted(Comparator<T> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by the compare ordering.
isSorted([Comparator<T>? compare]) bool

Available on Iterable<T>, provided by the IterableComparableExtension extension

Whether the elements are sorted by the compare ordering.
isSortedBy<K extends Comparable<K>>(K keyOf(T element)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by their keyOf property.
isSortedByCompare<K>(K keyOf(T element), Comparator<K> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are compare-sorted by their keyOf property.
join([String separator = '']) String
Converts each element to a String and concatenates the strings.
inherited
lastBy<K>(K key(T)) Map<K, T>

Available on Iterable<T>, provided by the IterableExtension extension

Associates the elements in this by the value returned by key.
lastIndexOf(E element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(E), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastOrDefault(E defaultValue) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the last element or defaultValue when null or empty.
lastWhere(bool test(E), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element whose index and value satisfies test.
lastWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element satisfying test, or null if there are none.
lastWhereOrNull(bool test(T element)) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the last element matching test, or null when not found.
lowerBound(E element, int compare(E, E)) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
lowerBound(E element, [int compare(E, E)?]) int

Available on List<E>, provided by the ListComparableExtensions extension

Returns the index where element should be in this sorted list.
lowerBoundBy<K extends Comparable<K>>(E element, K keyOf(E), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
lowerBoundByCompare<K>(E element, K keyOf(E), int compare(K, K), [int start = 0, int? end]) int

Available on List<E>, provided by the ListExtensions extension

Returns the index where element should be in this sorted list.
map<T>(T f(E)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapConcurrent<R>(Future<R> action(E item), {int parallelism = 1}) Future<List<R>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Executes action on each element with at most parallelism concurrent tasks.
mapIndexed<R>(R convert(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Maps each element and its index to a new value.
mapIndexed<R>(R convert(int index, E element)) Iterable<R>

Available on List<E>, provided by the ListExtensions extension

Maps each element and its index to a new value.
mapIndexedList<R>(R mapper(int index, E element), {ElementConverter<R>? converter}) List<R>

Available on Iterable<E>, provided by the IterableConversionX extension

Maps elements with their index and eagerly materializes the result into a List.
mapList<R>(R mapper(E e), {ElementConverter<R>? converter}) List<R>

Available on Iterable<E>, provided by the IterableConversionX extension

Maps the elements and eagerly materializes them into a List using convert_object.
none(bool test(T element)) bool

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns true when no element satisfies test.
none(bool test(T)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify({String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

observe<R>({Key? key, required R combine(List), required Widget builder(R), void onInit(R value)?, Function? onValueUpdated, void onAfterBuild(R value)?, void onDispose(R value)?, bool shouldRebuild(R newValue, R oldValue)?, bool shouldNotify(R newValue, R oldValue)?, bool equals(R a, R b)?, Duration? debounce, Duration? throttle, void onError(Object error, StackTrace stack)?, Widget errorBuilder(Object error)?, Widget loadingBuilder()?, String? debugLabel, bool debugPrint = false}) SignalsWatch<R>

Available on List<ReadonlySignal>, provided by the SignalListObserveExtension extension

Observe multiple signals and rebuild when any changes.
of(int index) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the element at index or null if out of bounds or null.
orEmpty() Iterable<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns this iterable (as is) if it is non-null; otherwise, returns an empty iterable.
pairwise() List<(E, E)>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns consecutive pairs from the iterable.
parserWithFallback(T fallback) → T Function(dynamic)

Available on List<T>, provided by the EnumValuesParsing extension

Returns a name-based parser that returns fallback for unknown values.
partition(bool predicate(E)) → (List<E>, List<E>)

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Splits the iterable into two lists based on the predicate.
percentile(double percentile) double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Computes the specified percentile of the doubles in the iterable.
percentile(double percentile) int

Available on Iterable<int>, provided by the DHUListIntStats extension

Computes the specified percentile of the integers in the iterable.
percentile(double percentile) num

Available on Iterable<num>, provided by the DHUListNumStats extension

Computes the specified percentile of the numbers in the iterable.
reduce(E combine(E value, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceIndexed(T combine(int index, T previous, T element)) → T

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with each other and the current index.
remove(Object? value) bool
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
removeAt(int index) → E
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
removeLast() → E
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
removeRange(int start, int end) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
removeWhere(bool test(E)) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
replaceRange(int start, int end, Iterable<E> iterable) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
retainWhere(bool test(E)) → void
Throws an UnsupportedError; operations that change the length of the list are disallowed.
inherited
retype<T>() List<T>
inherited
reverseRange(int start, int end) → void

Available on List<E>, provided by the ListExtensions extension

Reverses the elements in a range of the list.
sample(int count, [Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Selects count elements at random from this iterable.
secondHalf() List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the second half of the iterable.
setAll(int index, Iterable<E> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<E> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
inherited
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
shuffled([Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a shuffled list of the elements of the iterable.
shuffleRange(int start, int end, [Random? random]) → void

Available on List<E>, provided by the ListExtensions extension

Shuffle a range of elements.
singleWhere(bool test(E), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns the single matching element, or null if zero or multiple match.
skip(int n) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slice(int start, [int? end]) ListSlice<E>

Available on List<E>, provided by the ListExtensions extension

A fixed length view of a range of this list.
slices(int length) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Contiguous slices of this with the given length.
slices(int length) Iterable<List<E>>

Available on List<E>, provided by the ListExtensions extension

Contiguous slices of this with the given length.
sort([int compare(E, E)?]) → void
Sorts this list according to the order specified by the compare function.
inherited
sortBy<K extends Comparable<K>>(K keyOf(E element), [int start = 0, int? end]) → void

Available on List<E>, provided by the ListExtensions extension

Sorts elements by the natural order of their keyOf property.
sortByCompare<K>(K keyOf(E element), int compare(K a, K b), [int start = 0, int? end]) → void

Available on List<E>, provided by the ListExtensions extension

Sorts elements by the compare of their keyOf property.
sortChronologically() List<TimeOfDay>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Sort TimeOfDay list chronologically
sorted(Comparator<T> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sorted([Comparator<T>? compare]) List<T>

Available on Iterable<T>, provided by the IterableComparableExtension extension

Creates a sorted list of the elements of the iterable.
sortedBy<K extends Comparable<Object?>>(K keyOf(T element), {bool descending = false}) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a sorted copy by comparable keyOf.
sortedBy<K extends Comparable<K>>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedByCompare<K>(K keyOf(T element), Comparator<K> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortInAlphaNumericalOrder() List<String>

Available on List<String>, provided by the AlphaNumericSortingListOfString extension

sortRange(int start, int end, [int compare(E a, E b)?]) → void

Available on List<E>, provided by the ListComparableExtensions extension

Sort a range of elements by compare.
sortRange(int start, int end, int compare(E a, E b)) → void

Available on List<E>, provided by the ListExtensions extension

Sort a range of elements by compare.
splitAfter(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements.
splitAfterIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements and indices.
splitBefore(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements.
splitBeforeIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements and indices.
splitBetween(bool test(T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements.
splitBetweenIndexed(bool test(int index, T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements and indices.
splitInChunks(int chunkSize) List<List<T>>

Available on List<T>, provided by the ListChunk extension

sublist(int start, [int? end]) List<E>
Returns a new list containing the elements between start and end.
inherited
subtract(Iterable<E> other) Set<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a set of elements contained in this collection but not in other. The returned set preserves the element iteration order of the original collection.
sumBy(int selector(T)) int

Available on Iterable<T>?, provided by the ListExtensions extension

Example:
sumByDouble(num selector(T)) double

Available on Iterable<T>?, provided by the ListExtensions extension

Example:
swap(int index1, int index2) → void

Available on List<E>, provided by the ListExtensions extension

Swaps two elements of this list.
swap(int i, int j) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list with elements at i and j swapped.
take(int n) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeOnly(int n) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing the first n elements.
takeWhile(bool test(E)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
to(String routeName, {Object? arguments, Map<String, String> queryParams = const {}, bool isStrictMode = false}) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page of routeName to PageSettings
toAndRemoveUntil(String routeName, String untilRouteName) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page with the given routeName and remove all pages until the page with untilRouteName name.
toDateTimeList(DateTime date, {bool isUtc = true}) List<DateTime>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Convert all TimeOfDay to DateTime on a specific date
toJsonList({JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) List

Available on Iterable<T>, provided by the JsonIterableX extension

Converts this iterable to a JSON-encodable List.
toJsonString({String? indent, JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) String

Available on Iterable<T>, provided by the JsonIterableX extension

Converts this iterable to a JSON string (pretty if indent is provided).
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toListConverted<R>() List<R>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts this iterable to a list of type R using convert_object logic.
toMutableSet({ElementConverter<E>? converter}) Set<E>

Available on Iterable<E>, provided by the IterableConversionX extension

Returns this iterable as a mutable Set using the centralized conversion logic.
toReplacement(String routeName) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page with the given routeName and remove the last page.
toSet() Set<E>
Creates a Set containing the same elements as this iterable.
inherited
toSetConverted<R>() Set<R>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts this iterable to a set of type R using convert_object logic.
toSignal({String? debugLabel, bool autoDispose = false}) IterableSignal<T>

Available on Iterable<T>, provided by the SignalIterableUtils extension

Convert an existing list to IterableSignal
toSignal({String? debugLabel, bool autoDispose = false}) ListSignal<T>

Available on List<T>, provided by the SignalListUtils extension

Convert an existing list to ListSignal
toString() String
A string representation of this object.
inherited
totalBy(num? valueSelector(E)) num

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the sum of values calculated by valueSelector for each element.
tryGetBigInt(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt>? converter}) BigInt?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to BigInt.
tryGetBool(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool>? converter}) bool?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to bool.
tryGetDateTime(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime>? converter}) DateTime?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to DateTime.
tryGetDouble(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double>? converter}) double?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to double.
tryGetEnum<T extends Enum>(int index, {required T parser(dynamic), List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic>? debugInfo}) → T?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to an enum using parser.
tryGetInt(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int>? converter}) int?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to int.
tryGetList<T>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, List<T>? defaultValue, ElementConverter<T>? elementConverter}) List<T>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a List of T.
tryGetMap<K2, V2>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Map<K2, V2>? defaultValue, ElementConverter<K2>? keyConverter, ElementConverter<V2>? valueConverter}) Map<K2, V2>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a Map of K2 to V2.
tryGetNum(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num>? converter}) num?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to num.
tryGetRandom([int? seed]) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Retrieves a random element or null if the iterable is null.
tryGetSet<T>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Set<T>? defaultValue, ElementConverter<T>? elementConverter}) Set<T>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a Set of T.
tryGetString(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String>? converter}) String?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to String.
tryGetUri(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri>? converter}) Uri?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to Uri.
tryRemoveAt(int index) → void

Available on List<E>?, provided by the DHUNullableListExtensions extension

Safely removes the element at the specified index if the list is non-null and non-empty.
tryRemoveWhere(bool predicate(E element)) → void

Available on List<E>?, provided by the DHUNullableListExtensions extension

Safely removes elements that satisfy predicate.
update<R>(dynamic mutator(R state), {int index = 0, bool shouldNotify = true, String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

updateAll<R>(dynamic mutator(R state), {bool shouldNotify = true, String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

validate() List<T>

Available on Iterable<T>?, provided by the ListExtensions extension

Validate given List is not null and returns blank list if null. This should not be used to clear list
waitConcurrency({int concurrency = 5}) Future<List<T>>

Available on Iterable<Future<T> Function()>, provided by the DHUFutureIterableExtension extension

Executes the functions in this iterable, running at most concurrency futures simultaneously.
where(bool test(E)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndexed(bool test(int index, E element)) Iterable<E>

Available on List<E>, provided by the ListExtensions extension

The elements whose value and index satisfies test.
whereIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index satisfies test.
whereNot(bool test(T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements that do not satisfy test.
whereNotIndexed(bool test(int index, E element)) Iterable<E>

Available on List<E>, provided by the ListExtensions extension

The elements whose value and index do not satisfy test.
whereNotIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index do not satisfy test.
whereNotNull() Iterable<T>

Available on Iterable<T?>, provided by the IterableNullableExtension extension

The non-null elements of this Iterable.
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited
windowed(int size, {int step = 1, bool partials = false}) List<List<E>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a sliding window of size over the iterable.
windowed(int size, {int step = 1, bool partialWindows = false}) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns sliding windows of size.

Operators

operator +(List<E> other) List<E>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) → E
The object at the given index in the list.
inherited
operator []=(int index, E value) → void
Sets the value at the given index in the list to value.
inherited