SetSignalMixin<E, T extends Set<E>> mixin

Mixin to upgrade an set signal with reactive properties

Superclass constraints
Implemented types
Available extensions

Properties

$ Signal<Iterable<E>>

Available on Iterable<E>, provided by the SignalIterableExtensions extension

Return a signal from a Iterable value
no setter
$ Signal<Set<E>>

Available on Set<E>, provided by the SignalSetExtensions extension

Return a signal from a Set value
no setter
autoDispose bool
Throws and error if read after dispose and can be disposed on last unsubscribe.
getter/setter pairinherited
average double

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
average double

Available on Iterable<num>, provided by the IterableNumberExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
debugLabel String?
Debug label for Debug Mode
finalinherited
disposed bool
Check if the effect is disposed
getter/setter pairinherited
encodeWithIndent String

Available on Iterable<T>, provided by the JsonIterableX extension

Convenience getter mirroring the Map variant for parity.
no setter
equalityCheck bool Function(T a, T b)
Optional method to check if to values are the same
getter/setter pairinherited
first → E
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
flattened Iterable<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToList List<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToSet Set<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The unique sequential elements of each iterable in this iterable.
no setter
globalId int
finalinherited
halfLength int

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns half the length (floored).
no setter
hashCode int
The hash code for this object.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
internalValue → T
no setterinherited
isEmpty bool
Whether this collection has no elements.
no setterinherited
isEmptyOrNull bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns true if this nullable iterable is either null or empty.
no setter
isEmptyOrNull bool

Available on Set<E>?, provided by the DHUNullableSetExtensions extension

Checks if the iterable is either null or empty.
no setter
isInitialized bool
Check if a signal value is set (does not subscribe)
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
isNotEmptyOrNull bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns false if this nullable iterable is either null or empty.
no setter
isNotEmptyOrNull bool

Available on Set<E>?, provided by the DHUNullableSetExtensions extension

Checks if the iterable is neither null nor empty.
no setter
iterator Iterator<E>
An iterator that iterates over the elements of this set.
no setterinherited
last → E
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length int
The number of elements in this Iterable.
no setterinherited
max num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable.
no setter
max → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable.
no setter
max double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable.
no setter
max int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable.
no setter
maxOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
mean num

Available on Iterable<num>, provided by the DHUListNumStats extension

Calculates the mean (average) of the numbers in the iterable.
no setter
mean double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Calculates the mean (average) of the doubles in the iterable.
no setter
mean int

Available on Iterable<int>, provided by the DHUListIntStats extension

Calculates the mean (average) of the integers in the iterable.
no setter
median num

Available on Iterable<num>, provided by the DHUListNumStats extension

Determines the median value of the numbers in the iterable.
no setter
median double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Determines the median value of the doubles in the iterable.
no setter
median int

Available on Iterable<int>, provided by the DHUListIntStats extension

Determines the median value of the integers in the iterable.
no setter
min num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable.
no setter
min → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable.
no setter
min double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable.
no setter
min int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable.
no setter
minOrNull num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
mode List<num>

Available on Iterable<num>, provided by the DHUListNumStats extension

Finds the mode(s) of the numbers in the iterable.
no setter
mode List<double>

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Finds the mode(s) of the doubles in the iterable.
no setter
mode List<int>

Available on Iterable<int>, provided by the DHUListIntStats extension

Finds the mode(s) of the integers in the iterable.
no setter
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element of the iterable, or null.
no setter
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
standardDeviation int

Available on Iterable<int>, provided by the DHUListIntStats extension

Calculates the standard deviation of the integers in the iterable.
no setter
standardDeviation double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Calculates the standard deviation of the doubles in the iterable.
no setter
standardDeviation num

Available on Iterable<num>, provided by the DHUListNumStats extension

Calculates the standard deviation of the numbers in the iterable.
no setter
sum int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The sum of the elements.
no setter
sum num

Available on Iterable<num>, provided by the IterableNumberExtension extension

The sum of the elements.
no setter
sum double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

The sum of the elements.
no setter
total num

Available on Iterable<num?>?, provided by the DHUIterableNumExtensionsNS extension

Calculates the total sum of the numbers in the iterable.
no setter
total int

Available on Iterable<int?>?, provided by the DHUIterableIntExtensionsNS extension

Calculates the total sum of the integers in the iterable.
no setter
total double

Available on Iterable<double?>?, provided by the DHUIterableDoubleExtensionsNS extension

Calculates the total sum of the doubles in the iterable.
no setter
value ↔ T
Compute the current value
getter/setter pairinherited
variance num

Available on Iterable<num>, provided by the DHUListNumStats extension

Computes the variance of the numbers in the iterable.
no setter
variance int

Available on Iterable<int>, provided by the DHUListIntStats extension

Computes the variance of the integers in the iterable.
no setter
variance double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Computes the variance of the doubles in the iterable.
no setter
version int
Version numbers should always be >= 0, because the special value -1 is used by Nodes to signify potentially unused but recyclable nodes.
getter/setter pairinherited
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E value) bool

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

add(E value) bool
Adds value to the set.
override
addAll(Iterable<E> elements) → void
Adds all elements to this set.
override
addAll(Iterable<E> elements) → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

afterCreate(T val) → void
Internal hook for after a signal is created
inherited
any(bool test(E element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
associate<K, V>(K keySelector(E), [V valueSelector(E)?]) Map<K, V>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts the iterable to a map using keySelector and optional valueSelector.
beforeUpdate(T val) → void
Internal hook for after a signal is updated
inherited
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
call() → T
Return the value when invoked
inherited
cast<R>() Set<R>
Provides a view of this set as a set of R instances.
override
cast<R>() Set<R>

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

chunked(int size) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Splits values into fixed-size chunks.
chunks(int size) List<List<E>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Splits the iterable into chunks of size size.
clear() → void
Removes all elements from the set.
override
clear() → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

concatWithMultipleList(List<Iterable<E>> iterables) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list that concatenates this iterable with iterables.
concatWithSingleList(Iterable<E> iterable) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list that concatenates this iterable with iterable.
contains(Object? value) bool
Whether value is in the set.
inherited
containsAll(Iterable<Object?> other) bool
Whether this set contains all the elements of other.
override
containsAll(Iterable<Object?> other) bool

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

containsAll(Iterable<E> collection) bool

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Checks if all elements in the specified collection are contained in this collection.
convertAll<T>() List<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts every element in this iterable to T.
convertTo<R>() Set<R>

Available on Set<E>?, provided by the SetConvertToX extension

Converts this set into a Set of R using convert_object.
countWhere(bool test(T element)) int

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Counts elements matching test.
difference(Set<Object?> other) Set<E>
Creates a new set with the elements of this that are not in other.
override
difference(Set<Object?> other) Set<E>

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

dispose() → void
Dispose the signal
inherited
distinctBy<K>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a list with duplicates removed by keyOf, preserving order.
distinctBy<R>(R keySelector(E), {bool equals(R a, R b)?, int hashCode(R key)?, bool isValidKey(R key)?}) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a new list containing the first occurrence of each distinct element as determined by the key returned from keySelector.
drop(int n) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing all elements except the first n elements.
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The indexth element, or null if there is no such element.
every(bool test(E element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
expandIndexed<R>(Iterable<R> expand(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Expands each element and index to a number of elements in a new iterable.
filter(Predicate<E> test) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing elements that satisfy test.
filterNot(Predicate<E> test) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing elements that do not satisfy test.
find(Predicate<E> predicate) → E?

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the first element matching predicate, or null if element was not found.
findFirstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the MyfindFirstWhereOrNullExt extension

Finds the first element satisfying the provided condition, or null if none is found.
firstHalf() List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the first half of the iterable.
firstOrDefault(E defaultValue) → E

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the first element or defaultValue when null or empty.
firstWhere(bool test(E element), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element whose value and index satisfies test.
firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element satisfying test, or null if there are none.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
foldIndexed<R>(R initialValue, R combine(int index, R previous, T element)) → R

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with a value and the current index.
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element.
forEachIndexedWhile(bool action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element and index as long as desired.
forEachWhile(bool action(T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element as long as desired.
get() → T
Helper method to get the current value
inherited
getBigInt(int index, {dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt>? converter}) BigInt

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a BigInt.
getBool(int index, {dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool>? converter}) bool

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a bool.
getDateTime(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime>? converter}) DateTime

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a DateTime.
getDouble(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double>? converter}) double

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a double.
getEnum<T extends Enum>(int index, {required T parser(dynamic), dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic>? debugInfo}) → T

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to an enum value using parser.
getInt(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int>? converter}) int

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to an int.
getList<T>(int index, {dynamic innerMapKey, int? innerIndex, List<T>? defaultValue, ElementConverter<T>? elementConverter}) List<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a List of T.
getMap<K2, V2>(int index, {dynamic innerMapKey, int? innerIndex, Map<K2, V2>? defaultValue, ElementConverter<K2>? keyConverter, ElementConverter<V2>? valueConverter}) Map<K2, V2>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Map of K2 to V2.
getNum(int index, {dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num>? converter}) num

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a num.
getRandom([int? seed]) → E

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a random element.
getSet<T>(int index, {dynamic innerMapKey, int? innerIndex, Set<T>? defaultValue, ElementConverter<T>? elementConverter}) Set<T>

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Set of T.
getString(int index, {dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String>? converter}) String

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a String.
getUri(int index, {dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri>? converter}) Uri

Available on Iterable<E>, provided by the IterableConversionX extension

Converts the element at index to a Uri.
groupFoldBy<K, G>(K keyOf(T element), G combine(G? previous, T element)) Map<K, G>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements by keyOf then folds the elements in each group.
groupListsBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into lists by keyOf.
groupSetsBy<K>(K keyOf(T element)) Map<K, Set<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into sets by keyOf.
inj({bool autoDisposeWhenNotUsed = true}) ReactiveModel<Set<T>>

Available on Set<T>, provided by the SetX extension

create a ReactiveModel state
internalRefresh() bool
inherited
intersect(Iterable other, {ElementConverter<E>? converter}) Set<E>

Available on Iterable<E>, provided by the IterableConversionX extension

Returns a union-like set combining this iterable and other.
intersection(Set<Object?> other) Set<E>

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

intersection(Set<Object?> other) Set<E>
Creates a new set which is the intersection between this set and other.
override
intersperse(E element) Iterable<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Inserts element between every element in the iterable.
isEqual(Iterable<E>? other) bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Compares two lists for element-by-element equality.
isPrimitive() bool

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns true when every element is a primitive value.
isSorted([Comparator<T>? compare]) bool

Available on Iterable<T>, provided by the IterableComparableExtension extension

Whether the elements are sorted by the compare ordering.
isSorted(Comparator<T> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by the compare ordering.
isSortedBy<K extends Comparable<K>>(K keyOf(T element)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by their keyOf property.
isSortedByCompare<K>(K keyOf(T element), Comparator<K> compare) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are compare-sorted by their keyOf property.
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastBy<K>(K key(T)) Map<K, T>

Available on Iterable<T>, provided by the IterableExtension extension

Associates the elements in this by the value returned by key.
lastOrDefault(E defaultValue) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the last element or defaultValue when null or empty.
lastWhere(bool test(E element), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element whose index and value satisfies test.
lastWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element satisfying test, or null if there are none.
lookup(Object? object) → E?
If an object equal to object is in the set, return it.
override
lookup(Object? object) → E?

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

map<T>(T toElement(E e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapConcurrent<R>(Future<R> action(E item), {int parallelism = 1}) Future<List<R>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Executes action on each element with at most parallelism concurrent tasks.
mapIndexed<R>(R convert(int index, T element)) Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Maps each element and its index to a new value.
mapIndexedList<R>(R mapper(int index, E element), {ElementConverter<R>? converter}) List<R>

Available on Iterable<E>, provided by the IterableConversionX extension

Maps elements with their index and eagerly materializes the result into a List.
mapList<R>(R mapper(E e), {ElementConverter<R>? converter}) List<R>

Available on Iterable<E>, provided by the IterableConversionX extension

Maps the elements and eagerly materializes them into a List using convert_object.
none(bool test(T element)) bool

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns true when no element satisfies test.
none(bool test(T)) bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(int index) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the element at index or null if out of bounds or null.
onDispose(void cleanup()) → void Function()
Add a cleanup function to be called when the signal is disposed
inherited
orEmpty() Iterable<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns this iterable (as is) if it is non-null; otherwise, returns an empty iterable.
overrideWith(T val) Signal<T>
Override the current signal with a new value as if it was created with it
inherited
pairwise() List<(E, E)>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns consecutive pairs from the iterable.
partition(bool predicate(E)) → (List<E>, List<E>)

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Splits the iterable into two lists based on the predicate.
peek() → T
In the rare instance that you have an effect that should write to another signal based on the previous value, but you don't want the effect to be subscribed to that signal, you can read a signals's previous value via signal.peek().
inherited
percentile(double percentile) num

Available on Iterable<num>, provided by the DHUListNumStats extension

Computes the specified percentile of the numbers in the iterable.
percentile(double percentile) int

Available on Iterable<int>, provided by the DHUListIntStats extension

Computes the specified percentile of the integers in the iterable.
percentile(double percentile) double

Available on Iterable<double>, provided by the DHUListDoubleStats extension

Computes the specified percentile of the doubles in the iterable.
readonly() ReadonlySignal<T>
Returns a readonly signal
inherited
reduce(E combine(E value, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceIndexed(T combine(int index, T previous, T element)) → T

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with each other and the current index.
remove(Object? value) bool

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

remove(Object? value) bool
Removes value from the set.
override
removeAll(Iterable<Object?> elements) → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
override
removeWhere(bool test(E element)) → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

removeWhere(bool test(E element)) → void
Removes all elements of this set that satisfy test.
override
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
override
retainAll(Iterable<Object?> elements) → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

retainWhere(bool test(E element)) → void
Removes all elements of this set that fail to satisfy test.
override
retainWhere(bool test(E element)) → void

Available on Signal<Set<E>>, provided by the SetSignalExtension extension

sample(int count, [Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Selects count elements at random from this iterable.
secondHalf() List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns the second half of the iterable.
set(T val, {bool force = false}) bool
Set the current value by a method
inherited
shuffled([Random? random]) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a shuffled list of the elements of the iterable.
singleWhere(bool test(E element), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns the single matching element, or null if zero or multiple match.
skip(int count) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E value)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slices(int length) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Contiguous slices of this with the given length.
sorted([Comparator<T>? compare]) List<T>

Available on Iterable<T>, provided by the IterableComparableExtension extension

Creates a sorted list of the elements of the iterable.
sorted(Comparator<T> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedBy<K extends Comparable<Object?>>(K keyOf(T element), {bool descending = false}) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a sorted copy by comparable keyOf.
sortedBy<K extends Comparable<K>>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedByCompare<K>(K keyOf(T element), Comparator<K> compare) List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
splitAfter(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements.
splitAfterIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements and indices.
splitBefore(bool test(T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements.
splitBeforeIndexed(bool test(int index, T element)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements and indices.
splitBetween(bool test(T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements.
splitBetweenIndexed(bool test(int index, T first, T second)) Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements and indices.
subscribe(void fn(T value)) → void Function()
Subscribe to value changes with a dispose function
inherited
subscribeToNode(Node node) → void
inherited
subtract(Iterable<E> other) Set<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a set of elements contained in this collection but not in other. The returned set preserves the element iteration order of the original collection.
swap(int i, int j) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list with elements at i and j swapped.
take(int count) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeOnly(int n) List<E>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a list containing the first n elements.
takeWhile(bool test(E value)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toJson() → dynamic
Convert value to JSON
inherited
toJsonList({JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) List

Available on Iterable<T>, provided by the JsonIterableX extension

Converts this iterable to a JSON-encodable List.
toJsonString({String? indent, JsonOptions options = const JsonOptions(), Object? toEncodable(dynamic object)?}) String

Available on Iterable<T>, provided by the JsonIterableX extension

Converts this iterable to a JSON string (pretty if indent is provided).
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toListConverted<R>() List<R>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts this iterable to a list of type R using convert_object logic.
toMutableSet({ElementConverter<E>? converter}) Set<E>

Available on Iterable<E>, provided by the IterableConversionX extension

Returns this iterable as a mutable Set using the centralized conversion logic.
toSet() Set<E>
Creates a Set with the same elements and behavior as this Set.
inherited
toSetConverted<R>() Set<R>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Converts this iterable to a set of type R using convert_object logic.
toSignal({String? debugLabel, bool autoDispose = false}) IterableSignal<T>

Available on Iterable<T>, provided by the SignalIterableUtils extension

Convert an existing list to IterableSignal
toSignal({String? debugLabel, bool autoDispose = false}) SetSignal<T>

Available on Set<T>, provided by the SignalSetUtils extension

Convert an existing list to SetSignal
toString() String
A string representation of this object.
inherited
totalBy(num? valueSelector(E)) num

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Returns the sum of values calculated by valueSelector for each element.
tryGetBigInt(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, BigInt? defaultValue, ElementConverter<BigInt>? converter}) BigInt?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to BigInt.
tryGetBool(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, bool? defaultValue, ElementConverter<bool>? converter}) bool?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to bool.
tryGetDateTime(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, bool autoDetectFormat = false, bool useCurrentLocale = false, bool utc = false, DateTime? defaultValue, ElementConverter<DateTime>? converter}) DateTime?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to DateTime.
tryGetDouble(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, double? defaultValue, ElementConverter<double>? converter}) double?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to double.
tryGetEnum<T extends Enum>(int index, {required T parser(dynamic), List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, T? defaultValue, Map<String, dynamic>? debugInfo}) → T?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to an enum using parser.
tryGetInt(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, int? defaultValue, ElementConverter<int>? converter}) int?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to int.
tryGetList<T>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, List<T>? defaultValue, ElementConverter<T>? elementConverter}) List<T>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a List of T.
tryGetMap<K2, V2>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Map<K2, V2>? defaultValue, ElementConverter<K2>? keyConverter, ElementConverter<V2>? valueConverter}) Map<K2, V2>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a Map of K2 to V2.
tryGetNum(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? format, String? locale, num? defaultValue, ElementConverter<num>? converter}) num?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to num.
tryGetRandom([int? seed]) → E?

Available on Iterable<E>?, provided by the DHUCollectionsExtensionsNS extension

Retrieves a random element or null if the iterable is null.
tryGetSet<T>(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Set<T>? defaultValue, ElementConverter<T>? elementConverter}) Set<T>?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to a Set of T.
tryGetString(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, String? defaultValue, ElementConverter<String>? converter}) String?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to String.
tryGetUri(int index, {List<int>? alternativeIndices, dynamic innerMapKey, int? innerIndex, Uri? defaultValue, ElementConverter<Uri>? converter}) Uri?

Available on Iterable<E>?, provided by the NullableIterableConversionX extension

Tries to convert the element at index (or fallback indices) to Uri.
union(Set<E> other) Set<E>
Creates a new set which contains all the elements of this set and other.
override
union(Set<E> other) Set<E>

Available on ReadonlySignal<Set<E>>, provided by the ReadonlySetSignalExtension extension

unsubscribeFromNode(Node node) → void
inherited
waitConcurrency({int concurrency = 5}) Future<List<T>>

Available on Iterable<Future<T> Function()>, provided by the DHUFutureIterableExtension extension

Executes the functions in this iterable, running at most concurrency futures simultaneously.
where(bool test(E element)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index satisfies test.
whereNot(bool test(T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements that do not satisfy test.
whereNotIndexed(bool test(int index, T element)) Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index do not satisfy test.
whereNotNull() Iterable<T>

Available on Iterable<T?>, provided by the IterableNullableExtension extension

The non-null elements of this Iterable.
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited
windowed(int size, {int step = 1, bool partialWindows = false}) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns sliding windows of size.
windowed(int size, {int step = 1, bool partials = false}) List<List<E>>

Available on Iterable<E>, provided by the DHUCollectionsExtensions extension

Returns a sliding window of size over the iterable.

Operators

operator ==(Object other) bool
The equality operator.
inherited