s_sidebar/src/s_sidebar library

Classes

SideBarController
Controller for managing sidebar state and popup functionality.
SSideBar
A customizable and responsive sidebar widget for Flutter applications.
SSideBarItem

Enums

SideBarIndicatorStyle
Sidebar model contains two icon data and string for the text main Icon can't be null but unselected icon can be null and in this case it will be the main Icon Sidebar model Represents a single item in the sidebar menu.
SideBarMinimizeButtonStyle
Style of the expand/collapse toggle button.