footer property
Optional custom footer widget displayed at the bottom of the sidebar (above collapse button).
Implementation
final Widget? footer;
Optional custom footer widget displayed at the bottom of the sidebar (above collapse button).
final Widget? footer;