SSideBarItem class
Constructors
- SSideBarItem({required IconData iconSelected, required String title, IconData? iconUnselected, String? tooltip, String? badgeText, Color? badgeColor, TextStyle? badgeTextStyle, bool isHeader = false, bool isDivider = false, dynamic onTap(Offset? offset)?})
- Creates a sidebar item with optional tooltip, badge, and tap callback.
- SSideBarItem.divider({String? badgeText, Color? badgeColor, TextStyle? badgeTextStyle})
- Creates a horizontal divider item to separate sections.
- SSideBarItem.header({required String title, String? tooltip})
- Creates a section header item. Section headers display small, uppercase, muted text, are not interactive, and do not show icons.
Properties
- badgeColor → Color?
-
final
- badgeText → String?
-
final
- badgeTextStyle → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSelected → IconData
-
final
- iconUnselected → IconData?
-
final
- isDivider → bool
-
final
- isHeader → bool
-
final
- onTap → dynamic Function(Offset? offset)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
- tooltip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited