SideBarMinimizeButtonStyle enum
Style of the expand/collapse toggle button.
Values
- legacy → const SideBarMinimizeButtonStyle
-
The legacy style: a large full-width button with a giant arrow.
- bottomRow → const SideBarMinimizeButtonStyle
-
Modern style: a sleek bottom row with a small chevron and a "Collapse" label that hides when minimized.
- floating → const SideBarMinimizeButtonStyle
-
Floating style: a circular button overlapping the right border of the sidebar.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SideBarMinimizeButtonStyle> - A constant List of the values in this enum, in order of their declaration.