columnKeyBuilder property

Object Function(int columnIndex)? columnKeyBuilder
final

Optional key builder that gives each column a stable identity for selectionController. Mirrors rowKeyBuilder. If null, the raw column index is used as the identity key.

Implementation

final Object Function(int columnIndex)? columnKeyBuilder;