enableKeystrokes property

bool enableKeystrokes
final

When true, wraps the spreadsheet content in a KeystrokeListener so that keyboard shortcuts are detected and dispatched to keystrokeActionHandlers. Defaults to false (backward compatible).

Implementation

final bool enableKeystrokes;