keystrokeDebugLogs property
When true and enableKeystrokes is true, every detected keystroke is printed via debugPrint. No action handlers fire in this mode.
Implementation
final bool keystrokeDebugLogs;
When true and enableKeystrokes is true, every detected keystroke is printed via debugPrint. No action handlers fire in this mode.
final bool keystrokeDebugLogs;