shouldPauseKeystrokes property

bool Function()? shouldPauseKeystrokes
final

When provided and returns true, all keystroke intent handlers are suppressed and the auto-refocus is paused. Use this when descendant text inputs need exclusive keyboard access (e.g. a search bar inside the spreadsheet).

Implementation

final bool Function()? shouldPauseKeystrokes;