columnIndex property
The body column index at the hit position, or null if the position is
in the row-header or beyond the last column.
Implementation
final int? columnIndex;
The body column index at the hit position, or null if the position is
in the row-header or beyond the last column.
final int? columnIndex;