isFirstVisibleColumn property
Whether the hit column is the first body column visible in the viewport.
Implementation
final bool isFirstVisibleColumn;
Whether the hit column is the first body column visible in the viewport.
final bool isFirstVisibleColumn;