isInDataArea property
Whether this position maps to an actual data cell (both rowIndex and columnIndex are non-null).
Implementation
final bool isInDataArea;
Whether this position maps to an actual data cell (both rowIndex and columnIndex are non-null).
final bool isInDataArea;