isLastVisibleColumn property
Whether the hit column is the last body column visible in the viewport.
Implementation
final bool isLastVisibleColumn;
Whether the hit column is the last body column visible in the viewport.
final bool isLastVisibleColumn;