rowIndex property
The data row index at the hit position, or null if the position is
in the header, column-header, or beyond the last row.
Implementation
final int? rowIndex;
The data row index at the hit position, or null if the position is
in the header, column-header, or beyond the last row.
final int? rowIndex;