SSpreadsheetHorizontalScrollButtons class

Ready-to-use horizontal left/right scroll buttons bound to an SSpreadsheetHorizontalSyncController.

Inheritance
Available extensions

Constructors

SSpreadsheetHorizontalScrollButtons({Key? key, required SSpreadsheetHorizontalSyncController controller, EdgeInsetsGeometry padding = EdgeInsets.zero, double leadingInset = 0, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.spaceBetween, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, Duration animationDuration = const Duration(milliseconds: 800), Curve animationCurve = Curves.easeOutCubic, double activationThreshold = 100, SSpreadsheetScrollButtonBuilder? buttonBuilder})
const

Properties

activationThreshold double
final
animationCurve Curve
final
animationDuration Duration
final
buttonBuilder SSpreadsheetScrollButtonBuilder?
final
controller SSpreadsheetHorizontalSyncController
final
crossAxisAlignment CrossAxisAlignment
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingInset double
final
mainAxisAlignment MainAxisAlignment
final
padding EdgeInsetsGeometry
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMaterialWidget() Material

Available on Widget, provided by the GenericExtensions extension

addTooltipWidget(String toolTip) Tooltip

Available on Widget, provided by the GenericExtensions extension

borderRadius([BorderRadiusGeometry? borderRadius]) Widget

Available on Widget, provided by the GenericExtensions extension

boxDecoration([BoxDecoration? boxDecoration]) Widget

Available on Widget, provided by the GenericExtensions extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
colorFilter([ColorFilter? colorFilter]) Widget

Available on Widget, provided by the GenericExtensions extension

set parent widget in center
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited