externalFocusNode property

RoleFocusNode? externalFocusNode
final

Optional external focus node to manage input focus state. If provided, this focus node will be used instead of creating a new one.

Implementation

final RoleFocusNode? externalFocusNode;