MySpinnerNumericPicker class

Inheritance
Available extensions

Constructors

MySpinnerNumericPicker({required int maxValue, required double height, required double width, required double digitHeight, required TextStyle selectedTextStyle, required TextStyle nonSelectedTextStyle, required void onSelectedItemChanged(int? value), required Color spinnerBgColor, Key? key, int? initValue, BorderRadiusGeometry? borderRadius, BoxBorder? spinnerBorder, List<int> discardedValues = const [], List<int>? values, bool showNoSelectionDots = true, bool isInfiniteScroll = true})
const

Properties

borderRadius BorderRadiusGeometry?
final
digitHeight double
final
discardedValues List<int>
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
initValue int?
final
isInfiniteScroll bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxValue int
final
nonSelectedTextStyle TextStyle
final
onSelectedItemChanged → void Function(int? value)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedTextStyle TextStyle
final
showNoSelectionDots bool
final
spinnerBgColor Color
final
spinnerBorder BoxBorder?
final
values List<int>?
final
width double
final

Methods

addMaterialWidget() Material

Available on Widget, provided by the GenericExtensions extension

addTooltipWidget(String toolTip) Tooltip

Available on Widget, provided by the GenericExtensions extension

animate({Key? key, List<Effect>? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate

Available on Widget, provided by the AnimateWidgetExtensions extension

Wraps the target Widget in an Animate instance, and returns the instance for chaining calls. Ex. myWidget.animate() is equivalent to Animate(child: myWidget).
borderRadius([BorderRadiusGeometry? borderRadius]) Widget

Available on Widget, provided by the GenericExtensions extension

boxDecoration([BoxDecoration? boxDecoration]) Widget

Available on Widget, provided by the GenericExtensions extension

colorFilter([ColorFilter? colorFilter]) Widget

Available on Widget, provided by the GenericExtensions extension

set parent widget in center
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MySpinnerNumericPicker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited