endEvent constant

Static factory designed to expose end events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<SpeechSynthesisEvent> endEvent =
    EventStreamProvider<SpeechSynthesisEvent>('end');