DomParserDriver class

Parses DOM trees.

Constructors

DomParserDriver()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseDocument({required String content, required String mime, required Window window}) Document
Parses Document based on mime (e.g. 'text/html').
parseDocumentFragmentFromHtml({required Document ownerDocument, required String content, NodeValidator? validator, NodeTreeSanitizer? treeSanitizer}) DocumentFragment
parseDocumentFragmentFromSvg({required Document ownerDocument, required String content, NodeValidator? validator, NodeTreeSanitizer? treeSanitizer}) DocumentFragment
parseHtml({required Window window, required String content, String mime = 'text/html'}) HtmlDocument
parseHtmlFromAnything({required Window window, required String content, String mime = 'text/html'}) HtmlDocument
Parses HtmlDocument.
parseSvg({required Window window, required String content, String mime = 'application/svg'}) XmlDocument
parseXhtml({required Window window, required String content, String mime = 'application/xhtml+xml'}) XmlDocument
parseXml({required String content, required Window window, String mime = 'text/xml'}) XmlDocument
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited