s_universal_html/src/html_top_level_functions library

Properties

document HtmlDocument
Root node for all content in a web page.
no setter

Functions

querySelector(String s) Element?
Finds the first descendant element of this document that matches the specified group of selectors.
querySelectorAll(String s) ElementList<Element>
Finds all descendant elements of this document that match the specified group of selectors.