EventStreamDecoder class
Decodes 'application/event-stream' streams.
- Inheritance
-
- Object
- StreamTransformerBase<
List< int> , MessageEvent> - EventStreamDecoder
Constructors
- EventStreamDecoder({String? origin, void onReceivedTimeout(Duration timeout)?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onReceivedTimeout → void Function(Duration timeout)?
-
final
- origin → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bind(
Stream< List< stream) → Stream<int> >MessageEvent> -
Transforms the provided
stream.override -
cast<
RS, RT> () → StreamTransformer< RS, RT> -
Provides a
StreamTransformer<RS, RT>view of this stream transformer.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited