JsArray<E> class abstract

A List that proxies a JavaScript array.

Implemented types
Available extensions

Constructors

JsArray()
Creates a new JavaScript array.
factory
JsArray.from(Iterable<E> other)
Creates a new JavaScript array and initializes it to the contents of other.
factory

Properties

beautifiedJson String

Available on List<Map<String, dynamic>>, provided by the ListJsonBeautifier extension

Returns a beautified JSON string representation of the list.
no setter
earliest TimeOfDay?

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Find earliest time in the list
no setter
encodedJsonString String

Available on List<Map<String, dynamic>>, provided by the BeautifiedJsonListExtension extension

no setter
first ↔ E
The first element.
getter/setter pairinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on List<T>, provided by the NullableListQueries extension

Returns null instead of throwing if the list is empty.
no setter
hashCode int
The hash code for this object.
no setterinherited
indexed Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty bool
Whether this collection has no elements.
no setterinherited
isNotEmpty bool
Whether this collection has at least one element.
no setterinherited
iterator Iterator<E>
A new Iterator that allows iterating the elements of this Iterable.
no setterinherited
last ↔ E
The last element.
getter/setter pairinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on List<T>, provided by the NullableListQueries extension

Returns null instead of throwing if the list is empty.
no setter
latest TimeOfDay?

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Find latest time in the list
no setter
length int
The number of objects in this list.
getter/setter pairoverride
nonNulls Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
rebuild → _Rebuild

Available on List<ReactiveModel>, provided by the ReactiveModeListX extension

listen to the list of states
no setter
reversed Iterable<E>
An Iterable of the objects in this list in reverse order.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safe SafeListAccessor

Available on List, provided by the ListExtension extension

Get the safe accessor for this list that returns null for invalid indices Usage: list.safe2 // returns null if index 2 doesn't exist
no setter
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJS JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSProxyOrRef JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
wait Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E value) → void
Adds value to the end of this list, extending the length by one.
override
addAll(Iterable<E> iterable) → void
Appends all objects of iterable to the end of this list.
override
any(bool test(E element)) bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() Map<int, E>
An unmodifiable Map view of this list.
inherited
asNameMap() Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
builder(Widget builder(), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

Builds a widget that listens to all injected instances in this list.
builderData(Widget builder(List dataList), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

builderDataIndexed(Widget builder(int index, dynamic data), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

builderState(Widget builder(List<SnapState>), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) Widget

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
callMethod(Object method, [List? args]) → dynamic
Calls method on the JavaScript object with the arguments args and returns the result.
inherited
cast<R>() List<R>
Returns a view of this list as a list of R instances.
inherited
chunked(int size) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Splits values into fixed-size chunks.
clear() → void
Removes all objects from this list; the length of the list becomes zero.
inherited
contains(Object? element) bool
Whether the collection contains an element equal to element.
inherited
convertToStringList({bool showSeconds = false, bool showUtcSymbol = false, bool preferUtcSymbolThanZ = false, bool showSeparatorSymbol = true, bool use24HourFormat = true}) List<String>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Convert list of TimeOfDay to list of strings
convertToStringList() List<String>

Available on List<DateTime>, provided by the ListOfDateTimeExtensions extension

countWhere(bool test(T element)) int

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Counts elements matching test.
deleteProperty(dynamic property) → void
Removes property from the JavaScript object.
inherited
distinctBy<K>(K keyOf(T element)) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a list with duplicates removed by keyOf, preserving order.
doesIndexExist(int index) bool

Available on List, provided by the ListExtension extension

elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
elementAtOrNull(int index) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the element at index or null when out of bounds.
every(bool test(E element)) bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(E element)) Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [E? fillValue]) → void
Overwrites a range of elements with fillValue.
inherited
findFirstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the MyfindFirstWhereOrNullExt extension

Finds the first element satisfying the provided condition, or null if none is found.
firstWhere(bool test(E element), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereOrNull(bool test(T element)) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the first element matching test, or null when not found.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<E> other) Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getRange(int start, int end) Iterable<E>
Creates an Iterable that iterates over a range of elements.
inherited
groupBy<K>(K keyOf(T element)) Map<K, List<T>>

Available on List<T>, provided by the ListGroupByExtension extension

Groups elements by the value returned by keyOf.
hasProperty(Object property) bool
Returns true if the JavaScript object contains the specified property either directly or though its prototype chain.
inherited
indexOf(E element, [int start = 0]) int
The first index of element in this list.
inherited
indexWhere(bool test(E element), [int start = 0]) int
The first index in the list that satisfies the provided test.
inherited
inj({bool autoDisposeWhenNotUsed = true}) ReactiveModel<List<T>>

Available on List<T>, provided by the ListX extension

create a ReactiveModel state
insert(int index, E element) → void
Inserts element at position index in this list.
override
insertAll(int index, Iterable<E> iterable) → void
Inserts all objects of iterable at position index in this list.
inherited
instanceof(JsFunction type) bool
Returns true if the JavaScript object has type in its prototype chain.
inherited
join([String separator = ""]) String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(E element, [int? start]) int
The last index of element in this list.
inherited
lastIndexWhere(bool test(E element), [int? start]) int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(E element), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereOrNull(bool test(T element)) → T?

Available on List<T>, provided by the NullableListQueries extension

Returns the last element matching test, or null when not found.
map<T>(T toElement(E e)) Iterable<T>
The current elements of this iterable modified by toElement.
inherited
none(bool test(T element)) bool

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns true when no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notify({String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

observe<R>({Key? key, required R combine(List), required Widget builder(R), void onInit(R value)?, Function? onValueUpdated, void onAfterBuild(R value)?, void onDispose(R value)?, bool shouldRebuild(R newValue, R oldValue)?, bool shouldNotify(R newValue, R oldValue)?, bool equals(R a, R b)?, Duration? debounce, Duration? throttle, void onError(Object error, StackTrace stack)?, Widget errorBuilder(Object error)?, Widget loadingBuilder()?, String? debugLabel, bool debugPrint = false}) SignalsWatch<R>

Available on List<ReadonlySignal>, provided by the SignalListObserveExtension extension

Observe multiple signals and rebuild when any changes.
reduce(E combine(E value, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) bool
Removes the first occurrence of value from this list.
inherited
removeAt(int index) → E
Removes the object at position index from this list.
override
removeLast() → E
Removes and returns the last object in this list.
override
removeRange(int start, int end) → void
Removes a range of elements from the list.
override
removeWhere(bool test(E element)) → void
Removes all objects from this list that satisfy test.
inherited
replaceRange(int start, int end, Iterable<E> replacements) → void
Replaces a range of elements with the elements of replacements.
inherited
retainWhere(bool test(E element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
setAll(int index, Iterable<E> iterable) → void
Overwrites elements with the objects of iterable.
inherited
setRange(int start, int end, Iterable<E> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
override
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
inherited
singleWhere(bool test(E element), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns the single matching element, or null if zero or multiple match.
skip(int count) Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E value)) Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
sort([int compare(E a, E b)?]) → void
Sorts this list according to the order specified by the compare function.
override
sortChronologically() List<TimeOfDay>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Sort TimeOfDay list chronologically
sortedBy<K extends Comparable<Object?>>(K keyOf(T element), {bool descending = false}) List<T>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns a sorted copy by comparable keyOf.
sortInAlphaNumericalOrder() List<String>

Available on List<String>, provided by the AlphaNumericSortingListOfString extension

splitInChunks(int chunkSize) List<List<T>>

Available on List<T>, provided by the ListChunk extension

sublist(int start, [int? end]) List<E>
Returns a new list containing the elements between start and end.
inherited
take(int count) Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(E value)) Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
to(String routeName, {Object? arguments, Map<String, String> queryParams = const {}, bool isStrictMode = false}) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page of routeName to PageSettings
toAndRemoveUntil(String routeName, String untilRouteName) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page with the given routeName and remove all pages until the page with untilRouteName name.
toDateTimeList(DateTime date, {bool isUtc = true}) List<DateTime>

Available on List<TimeOfDay>, provided by the ListOfTimeOfDayExtensions extension

Convert all TimeOfDay to DateTime on a specific date
toList({bool growable = true}) List<E>
Creates a List containing the elements of this Iterable.
inherited
toReplacement(String routeName) List<PageSettings>

Available on List<PageSettings>, provided by the PageSettingsX extension

Add the page with the given routeName and remove the last page.
toSet() Set<E>
Creates a Set containing the same elements as this iterable.
inherited
toString() String
A string representation of this object.
inherited
update<R>(dynamic mutator(R state), {int index = 0, bool shouldNotify = true, String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

updateAll<R>(dynamic mutator(R state), {bool shouldNotify = true, String? tag}) → void

Available on List<Injected>, provided by the MultipleStateRebuilderExtension extension

where(bool test(E element)) Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited
windowed(int size, {int step = 1, bool partialWindows = false}) List<List<T>>

Available on Iterable<T>, provided by the IterableQueryExtensions extension

Returns sliding windows of size.

Operators

operator +(List<E> other) List<E>
Returns the concatenation of this list and other.
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](dynamic index) → E
Returns the value associated with property from the proxied JavaScript object.
override
operator []=(dynamic index, dynamic value) → void
Sets the value associated with property on the proxied JavaScript object.
override