operator [] method

E operator [](
  1. dynamic index
)
override

Returns the value associated with property from the proxied JavaScript object.

The type of property must be either String or num.

Implementation

E operator [](dynamic index) {
  throw UnsupportedError(
      'JavaScript interop is not supported in this runtime.');
}