operator []= method

  1. @override
void operator []=(
  1. dynamic index,
  2. dynamic value
)
override

Sets the value associated with property on the proxied JavaScript object.

The type of property must be either String or num.

Implementation

@override
void operator []=(dynamic index, dynamic value) {
  throw UnsupportedError(
      'JavaScript interop is not supported in this runtime.');
}