callMethod method

dynamic callMethod(
  1. Object method, [
  2. List? args
])

Calls method on the JavaScript object with the arguments args and returns the result.

The type of method must be either String or num.

Implementation

dynamic callMethod(Object method, [List? args]) {
  if (method is! String && method is! num) {
    throw ArgumentError('method is not a String or num');
  }
  throw UnsupportedError(
      'JavaScript interop is not supported in this runtime.');
}