jsify function

dynamic jsify(
  1. dynamic object
)

WARNING: performance of this method is much worse than other util methods in this library. Only use this method as a last resort.

Recursively converts a JSON-like collection of Dart objects to a collection of JavaScript objects and returns a JsObject proxy to it.

object must be a Map or Iterable, the contents of which are also converted. Maps and Iterables are copied to a new JavaScript object. Primitives and other transferable values are directly converted to their JavaScript type, and all other objects are proxied.

Implementation

dynamic jsify(dynamic object) {
  return object;
}