s_universal_html/universal_html library
Cross-platform "dart:html" library.
You can choose from the following libraries:
package:universal_html/html.dartpackage:universal_html/prefer_sdk/html.dartpackage:universal_html/prefer_universal/html.dart
Introduction
HTML elements and other resources for web-based applications that need to interact with the browser and the DOM (Document Object Model).
This library includes DOM element types, CSS styling, local storage, media, speech, events, and more. To get started, check out the Element class, the base class for many of the HTML DOM types.
For information on writing web apps with Dart, see https://webdev.dartlang.org.
Classes
- AbortPaymentEvent
- AbstractWorker
- AccessibleNode
- AccessibleNodeList
- AnchorElement
- Animation
- AnimationEffectReadOnly
- AnimationEffectTiming
- AnimationEffectTimingReadOnly
- AnimationEvent
- AnimationPlaybackEvent
- AnimationTimeline
- ApplicationCache
- AreaElement
- AudioElement
- BackgroundFetchedEvent
- BackgroundFetchEvent
- BackgroundFetchFailEvent
- BackgroundFetchFetch
- BackgroundFetchManager
- BackgroundFetchRegistration
- BackgroundFetchSettledFetch
- BarProp
- BaseElement
- BeforeInstallPromptEvent
- BeforeUnloadEvent
- Blob
- BlobEvent
- Body
- BodyElement
- BRElement
- BroadcastChannel
- BudgetService
- BudgetState
- ButtonElement
- ButtonInputElement
- CacheStorage
- CanMakePaymentEvent
- CanvasCaptureMediaStreamTrack
- CanvasElement
- CanvasGradient
- CanvasImageSource
- CanvasPattern
- CanvasRenderingContext
- CanvasRenderingContext2D
- CharacterData
- CheckboxInputElement
- ChildNode
- Client
- Clients
- Clipboard
- ClipboardEvent
- CloseEvent
- Comment
- CompositionEvent
- Console
- ContentElement
- CookieStore
- Coordinates
- Credential
- CredentialsContainer
- Crypto
- CryptoKey
- CssClassSet
- A Set that stores the CSS class names for an element.
- CssImportRule
- CssRect
- A class for representing CSS dimensions.
- CssRule
- CssStyleDeclaration
- CssStyleDeclarationBase
- CssStyleRule
- CssStyleSheet
- CssStyleValue
- CssViewportRule
- CustomElementRegistry
- CustomEvent
- DataElement
- DataListElement
- DataTransfer
- DataTransferItem
- DataTransferItemList
- DateInputElement
- DetailsElement
- DeviceAcceleration
- DeviceMotionEvent
- DeviceOrientationEvent
- DeviceRotationRate
- DialogElement
- Dimension
- Class representing a length measurement in CSS.
- DirectoryEntry
- DirectoryReader
- DivElement
- DListElement
- Document
- DocumentFragment
- DocumentOrShadowRoot
- DocumentTimeline
- DomImplementation
- DomMatrix
- DomMatrixReadOnly
- DomParser
- DomTokenList
- Element
- ElementEvents
-
ElementList<
T extends Element> - An immutable list containing HTML elements. This list contains some additional methods when compared to regular lists for ease of CSS manipulation on a group of elements.
-
ElementStream<
T extends Event> - A specialized Stream available to Elements to enable event delegation.
- EmailInputElement
- EmbedElement
- Entry
- ErrorEvent
- Event
- Events
- Base class that supports listening for and dispatching browser events.
- EventSource
- EventSourceOutsideBrowser
-
EventStreamProvider<
T extends Event> - A factory to expose DOM events as Streams.
- EventTarget
- ExtendableEvent
- External
- The external object provides access to external APIs on the web.
- FetchEvent
- FieldSetElement
- File
- FileEntry
- FileReader
- FileSystem
- FileUploadInputElement
- FileWriter
- FocusEvent
- ForeignFetchEvent
- FormData
- FormElement
- Gamepad
- GamepadButton
- GamepadPose
- Geolocation
- Geoposition
- GlobalEventHandlers
- HashChangeEvent
- HeadElement
- Headers
- HeadingElement
- HiddenInputElement
- History
- HistoryBase
- HRElement
- HtmlDocument
- HtmlElement
- HtmlHtmlElement
- HtmlHyperlinkElementUtils
- HttpRequest
- A client-side XHR request for getting data from a URL, formally known as XMLHttpRequest.
- HttpRequestEventTarget
- HttpRequestUpload
- HttpStatus
- HTTP status codes. Exported in dart:io and dart:html.
- IdleDeadline
- IFrameElement
- ImageBitmap
- ImageButtonInputElement
- ImageCapture
- ImageData
- ImageElement
- InputDeviceCapabilities
- InputElement
- InputElementBase
- InstallEvent
- InternalDocumentType
- Internal class. Not part of dart:html.
- KeyboardEvent
- KeyCode
- Defines the keycode values for keys that are returned by KeyboardEvent.keyCode.
- KeyEvent
- KeyframeEffectReadOnly
- LabelElement
- LegendElement
- LIElement
- LinkElement
- LocalDateTimeInputElement
- Location
- LocationBase
- MapElement
- MediaCapabilities
- MediaCapabilitiesInfo
- MediaDeviceInfo
- MediaDevices
- MediaElement
- MediaError
- MediaKeys
- MediaKeysPolicy
- MediaMetadata
- MediaQueryList
- MediaRecorder
- MediaSession
- MediaSettingsRange
- MediaSource
- MediaStream
- MediaStreamEvent
- MediaStreamTrack
- MediaStreamTrackEvent
- MemoryInfo
- MenuElement
- MessageEvent
- MessagePort
- Metadata
- MetaElement
- MeterElement
- MimeType
- ModElement
- MonthInputElement
- MouseEvent
- NetworkInformation
- NFC
- Node
- NodeTreeSanitizer
- Performs sanitization of a node tree after construction to ensure that it does not contain any disallowed elements or attributes.
- NodeValidator
- Interface used to validate that only accepted elements and attributes are allowed while parsing HTML strings into DOM nodes.
- NodeValidatorBuilder
- Class which helps construct standard node validation policies.
- NoncedElement
- NonDocumentTypeChildNode
- Notification
- NotificationEvent
- NumberInputElement
- ObjectElement
- OffscreenCanvas
- OffscreenCanvasRenderingContext2D
- OListElement
- OptGroupElement
- OptionElement
- OutputElement
- PageTransitionEvent
- ParagraphElement
- ParamElement
- ParentNode
- PasswordInputElement
- Path2D
- PaymentAddress
- PaymentInstruments
- PaymentManager
- PaymentRequest
- PaymentRequestEvent
- PaymentRequestUpdateEvent
- PaymentResponse
- Performance
- PerformanceEntry
- Permissions
- PermissionStatus
- PhotoCapabilities
- PictureElement
- Platform
- Plugin
-
Point<
T extends num> - A utility class for representing two-dimensional positions.
- PointerEvent
- PopStateEvent
- PositionError
- PreElement
- Presentation
- PresentationAvailability
- PresentationConnection
- PresentationConnectionAvailableEvent
- PresentationConnectionCloseEvent
- PresentationConnectionList
- PresentationReceiver
- PresentationRequest
- ProcessingInstruction
- ProgressElement
- ProgressEvent
- PushEvent
- PushManager
- PushMessageData
- PushSubscription
- PushSubscriptionOptions
- QuoteElement
- RadioButtonInputElement
- Range
- RangeInputElement
- RangeInputElementBase
- Base interface for all input element types which involve ranges.
-
Rectangle<
T extends num> - A class for representing two-dimensional rectangles whose properties are immutable.
- RelatedApplication
- RemotePlayback
- Request
- ResetButtonInputElement
- Response
- RtcCertificate
- RtcDataChannel
- RtcDataChannelEvent
- RtcDtmfSender
- RtcDtmfToneChangeEvent
- RtcIceCandidate
- RtcLegacyStatsReport
- RtcPeerConnection
- RtcPeerConnectionIceEvent
- RtcRtpContributingSource
- RtcRtpReceiver
- RtcRtpSender
- RtcSessionDescription
- RtcStatsReport
- RtcStatsResponse
- RtcTrackEvent
- Screen
- ScreenOrientation
- ScriptElement
- ScrollAlignment
- ScrollState
- ScrollTimeline
- SearchInputElement
- SecurityPolicyViolationEvent
- SelectElement
- Selection
- SensorErrorEvent
- ServiceWorker
- ServiceWorkerContainer
- ServiceWorkerGlobalScope
- ServiceWorkerRegistration
- ShadowElement
- ShadowRoot
- SlotElement
- SourceBuffer
- SourceElement
- SpanElement
- SpeechSynthesis
- SpeechSynthesisEvent
- SpeechSynthesisUtterance
- SpeechSynthesisVoice
- Storage
- The type used by the Window.localStorage and Window.sessionStorage properties. Storage is implemented as a Map<String, String>.
- StorageEvent
- StorageManager
- StyleElement
- StyleMedia
- StylePropertyMap
- StylePropertyMapReadonly
- StyleSheet
- SubmitButtonInputElement
- SyncEvent
- SyncManager
- TableCaptionElement
- TableCellElement
- TableColElement
- TableElement
- TableRowElement
- TableSectionElement
- TelephoneInputElement
- TemplateElement
- Text
- TextAreaElement
- TextEvent
- TextInputElement
- TextInputElementBase
- TextMetrics
- TextTrack
- TimeElement
- TimeInputElement
- TimeRanges
- TitleElement
- Touch
- TouchEvent
- TouchList
- TrackDefault
- TrackElement
- TrackEvent
- TransitionEvent
- UIEvent
- UListElement
- UnknownElement
- UriPolicy
- Defines the policy for what types of uris are allowed for particular attribute values.
- Url
- UrlInputElement
- ValidityState
- VideoElement
- VideoPlaybackQuality
- VideoTrack
- VisualViewport
- VR
- WebSocket
- Use the WebSocket interface to connect to a WebSocket, and to send and receive data on that WebSocket.
- WeekInputElement
- WheelEvent
- Window
- WindowClient
- WindowEventHandlers
- Worker
- WorkerGlobalScope
- WorkerPerformance
- Worklet
- WorkletAnimation
- WorkletGlobalScope
- XmlDocument
Mixins
Properties
- document → HtmlDocument
-
Root node for all content in a web page.
no setter
- window → Window
-
Global window.
no setter
Functions
-
promiseToFuture<
T> (dynamic jsPromise) → Future< T> - Converts a JavaScript Promise to a Dart Future.
-
querySelector(
String s) → Element? - Finds the first descendant element of this document that matches the specified group of selectors.
-
querySelectorAll(
String s) → ElementList< Element> - Finds all descendant elements of this document that match the specified group of selectors.
Typedefs
- BlobCallback = void Function(Blob blob)
- EventListener = dynamic Function(Event event)
- FrameRequestCallback = void Function(num highResTime)
- IdleRequestCallback = void Function(IdleDeadline deadline)
- MediaSessionActionHandler = void Function()
- RemotePlaybackAvailabilityCallback = void Function(bool available)
- RtcPeerConnectionErrorCallback = void Function(DomException exception)
- StorageErrorCallback = void Function(DomError error)
- StorageQuotaCallback = void Function(int grantedQuotaInBytes)
- StorageUsageCallback = void Function(int currentUsageInBytes, int currentQuotaInBytes)
- VoidCallback = void Function()