replaceLocation static method
Replaces the current history entry with url via location.replace().
No-op on non-web platforms.
Implementation
static void replaceLocation(String url) => impl.replaceLocation(url);
Replaces the current history entry with url via location.replace().
No-op on non-web platforms.
static void replaceLocation(String url) => impl.replaceLocation(url);