SWebViewDebug class

Shared debug logger for SWebView internals.

Logs are emitted only when enabled is true and app is in debug mode.

Constructors

SWebViewDebug()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enabled bool
getter/setter pair

Static Methods

log(Object? message) → void