darkMode property
When true, renders the WebView in dark mode. On Web, this applies a CSS invert/hue-rotate filter to the iframe container. On Desktop platforms, this sets native webview brightness to dark.
Implementation
final bool darkMode;
When true, renders the WebView in dark mode. On Web, this applies a CSS invert/hue-rotate filter to the iframe container. On Desktop platforms, this sets native webview brightness to dark.
final bool darkMode;