isUrlInProxyCache static method

bool isUrlInProxyCache(
  1. String url
)

Check if a specific URL is in the proxy cache and requires a proxy Returns true if the URL is cached and requires a proxy, false otherwise

Implementation

static bool isUrlInProxyCache(String url) {
  final key = _SWebViewState.cacheKeyFromUrl(url, cacheByHost: true);
  return _SWebViewState._restrictionCache[key]?.needsProxy ?? false;
}