autoDetectFrameRestrictions property
Automatically detect frame restrictions and apply proxy only when needed.
Implementation
final bool autoDetectFrameRestrictions;
Automatically detect frame restrictions and apply proxy only when needed.
final bool autoDetectFrameRestrictions;