getWidgetSize function
Returns the rendered size for the widget associated with context.
Implementation
Size? getWidgetSize(BuildContext context) {
RenderBox? box = context.findRenderObject() as RenderBox?;
return box?.size;
}
Returns the rendered size for the widget associated with context.
Size? getWidgetSize(BuildContext context) {
RenderBox? box = context.findRenderObject() as RenderBox?;
return box?.size;
}