Shaker class
A widget that applies a shake animation effect to its child.
The Shaker widget wraps a child widget and can trigger a shake animation when isShaking is true or via a ShakeController.
Example:
Shaker(
isShaking: true,
duration: Duration(milliseconds: 1000),
child: Text('Shake me!'),
)
With controller:
final controller = ShakeController();
Shaker(
controller: controller,
child: Text('Shake me!'),
)
// Later:
controller.shake();
- Inheritance
- Available extensions
Constructors
Properties
- child → Widget
-
The widget to apply the shake effect to.
final
- controller → ShakeController?
-
Optional controller for programmatic shake triggering.
final
- curve → Curve?
-
The curve to use for the shake animation.
final
- duration → Duration?
-
The duration of the shake animation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hz → double?
-
The frequency of the shake in hertz (cycles per second).
final
- isShaking → bool
-
Whether the shake animation should be active.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- offset → Offset?
-
The positional offset applied during the shake effect.
final
- onComplete → Function?
-
Callback function called when the shake animation completes.
final
- rotation → double?
-
The rotation angle applied during the shake effect.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Shaker> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited