addToBottom method
Adds the specified value to the existing bottom padding
Implementation
EdgeInsets addToBottom(double value) => copyWith(bottom: bottom + value);
Adds the specified value to the existing bottom padding
EdgeInsets addToBottom(double value) => copyWith(bottom: bottom + value);