isBlank property
bool
get
isBlank
Returns true if the string is empty or only whitespace.
Implementation
bool get isBlank => trim().isEmpty;
Returns true if the string is empty or only whitespace.
bool get isBlank => trim().isEmpty;