Animation class abstract

Inheritance

Constructors

Animation([AnimationEffectTimingReadOnly? effect, AnimationTimeline? timeline])
factory

Properties

finished Future<Animation>
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
on Events
no setterinherited
onCancel Stream<Event>
no setter
onFinish Stream<Event>
no setter
ready Future<Animation>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
cancel() → void
dispatchEvent(Event event) bool
inherited
finish() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
play() → void
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
reverse() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supported bool
no setter