AnimationEffectTiming class abstract

Inheritance

Properties

delay num?
getter/setter pair
direction String?
getter/setter pair
duration Object?
getter/setter pair
easing String?
getter/setter pair
endDelay num?
getter/setter pair
fill String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
iterations num?
getter/setter pair
iterationStart num?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited