ApplicationCache class

Inheritance

Constructors

ApplicationCache.internal()

Properties

hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
onCached Stream<Event>
no setter
onChecking Stream<Event>
no setter
onDownloading Stream<Event>
no setter
onError Stream<Event>
no setter
onNoUpdate Stream<Event>
no setter
onObsolete Stream<Event>
no setter
onProgress Stream<Event>
no setter
onUpdateReady Stream<Event>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
no setter

Methods

abort() → void
addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
swapCache() → void
toString() String
A string representation of this object.
inherited
update() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supported bool
no setter