fetch method
Implementation
Future<BackgroundFetchRegistration> fetch(
String id,
Object requests, [
Map? options,
]) =>
Future.error(UnsupportedError(
'Background fetch is not available outside a browser context.'));
Future<BackgroundFetchRegistration> fetch(
String id,
Object requests, [
Map? options,
]) =>
Future.error(UnsupportedError(
'Background fetch is not available outside a browser context.'));