get method
Implementation
Future<BackgroundFetchRegistration> get(String id) =>
Future.error(UnsupportedError(
'Background fetch is not available outside a browser context.'));
Future<BackgroundFetchRegistration> get(String id) =>
Future.error(UnsupportedError(
'Background fetch is not available outside a browser context.'));