Blob class abstract

Implementers

Constructors

Blob(List blobParts, [String? type, String? encoding])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setter
type String
no setter

Methods

internalBytes() Future<List<int>>
Internal method. Not part of "dart:html".
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice([int start = 0, int? end, String? contentType]) Blob
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited