Coordinates class

Constructors

Coordinates.internal({num accuracy = 0.0, num altitude = 0.0, num altitudeAccuracy = 0.0, num heading = 0.0, num latitude = 0.0, num longitude = 0.0, num speed = 0.0})
Internal constructor. Not part of dart:html.
const

Properties

accuracy num
final
altitude num
final
altitudeAccuracy num
final
hashCode int
The hash code for this object.
no setterinherited
heading num
final
latitude num
final
longitude num
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed num
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited