getPropertyValue abstract method
Returns the value of the property if the provided CSS property name is supported on this element and if the value is set. Otherwise returns an empty string.
Please note the property name uses camelCase, not-hyphens.
Implementation
@override
String getPropertyValue(String propertyName);