CssStyleRule class

Inheritance

Constructors

CssStyleRule.internal(CssStyleSheet parentStyleSheet, RuleSet node)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
parentStyleSheet CssStyleSheet
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectorText String
final
style CssStyleDeclaration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited