DataTransfer class abstract

Constructors

DataTransfer()

Properties

dropEffect String?
getter/setter pair
effectAllowed String?
getter/setter pair
files List<File>?
final
hashCode int
The hash code for this object.
no setterinherited
items List<DataTransferItem>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
types List<String>?
final

Methods

clearData([String? format]) → void
getData(String format) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setData(String format, String data) → void
setDragImage(Element image, int x, int y) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited