DataTransferItemList class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(dynamic dataOrFile, [String? type]) DataTransferItem
addData(String data, String type) DataTransferItem
addFile(File file) DataTransferItem
clear() → void
item(int index) DataTransferItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(int index) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) DataTransferItem