Dimension class
Class representing a length measurement in CSS.
Constructors
- Dimension.cm(num value)
-
Set this CSS Dimension to a centimeter
value. - Dimension.css(String cssValue)
-
Construct a Dimension object from the valid, simple CSS string
cssValuethat represents a distance measurement.factory - Dimension.em(num value)
- Set this CSS Dimension to the specified number of ems.
- Dimension.ex(num value)
- Set this CSS Dimension to the specified number of x-heights.
- Dimension.inch(num value)
-
Set this CSS Dimension to an inch
value. - Dimension.mm(num value)
-
Set this CSS Dimension to a millimeter
value. - Dimension.pc(num value)
-
Set this CSS Dimension to a pica
value. - Dimension.percent(num value)
-
Set this CSS Dimension to a percentage
value. - Dimension.pt(num value)
-
Set this CSS Dimension to a point
value. - Dimension.px(num value)
-
Set this CSS Dimension to a pixel
value.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalUnit → String
-
NOT part of 'dart:html'.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → num
-
Return a unitless, numerical value of this CSS value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Print out the CSS String representation of this value.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited