Dimension.ex constructor

Dimension.ex(
  1. num value
)

Set this CSS Dimension to the specified number of x-heights.

One ex is equal to the x-height of a font's baseline to its mean line, generally the height of the letter 'x' in the font, which is usually about half the font-size.

Implementation

Dimension.ex(this.value) : _unit = 'ex';