createFile method

Future<Entry> createFile(
  1. String path, {
  2. bool exclusive = false,
})

Create a new file with the specified path. If exclusive is true, the returned Future will complete with an error if a file already exists at the specified path.

Implementation

Future<Entry> createFile(String path, {bool exclusive = false}) {
  return (_asDirectory(this)).createFile(path, exclusive: exclusive);
}