Document class abstract

Inheritance
Implemented types
Implementers

Constructors

Document()
factory

Properties

activeElement Element?
Outside the browser, returns null.
no setter
addressSpace String?
no setter
baseUri String?
no setteroverride
childNodes List<Node>
no setterinherited
contentType String
final
getter/setter pair
currentScript ScriptElement?
no setter
documentElement Element?
no setter
domain String?
no setter
firstChild Node?
no setterinherited
fullscreenElement Element?
no setter
fullscreenEnabled bool?
no setter
hashCode int
The hash code for this object.
no setterinherited
hidden bool?
no setter
implementation DomImplementation?
no setter
internalElementData InternalElementData?
no setterinherited
isConnected bool
no setterinherited
lastChild Node?
no setterinherited
nextNode Node?
no setterinherited
nodeName String?
no setterinherited
nodes List<Node>
getter/setter pairinherited
nodeType int
no setteroverride
nodeValue String?
no setterinherited
on Events
no setterinherited
onAbort Stream<Event>
Stream of abort events handled by this Document.
no setter
onBeforeCopy Stream<Event>
Stream of beforecopy events handled by this Document.
no setter
onBeforeCut Stream<Event>
Stream of beforecut events handled by this Document.
no setter
onBeforePaste Stream<Event>
Stream of beforepaste events handled by this Document.
no setter
onBlur Stream<Event>
Stream of blur events handled by this Document.
no setter
onCanPlay Stream<Event>
no setter
onCanPlayThrough Stream<Event>
no setter
onChange Stream<Event>
Stream of change events handled by this Document.
no setter
onClick Stream<MouseEvent>
Stream of click events handled by this Document.
no setter
onContextMenu Stream<MouseEvent>
Stream of contextmenu events handled by this Document.
no setter
onCopy Stream<ClipboardEvent>
Stream of copy events handled by this Document.
no setter
onCut Stream<ClipboardEvent>
Stream of cut events handled by this Document.
no setter
onDoubleClick Stream<Event>
Stream of doubleclick events handled by this Document.
no setter
onDrag Stream<MouseEvent>
Stream of drag events handled by this Document.
no setter
onDragEnd Stream<MouseEvent>
Stream of dragend events handled by this Document.
no setter
onDragEnter Stream<MouseEvent>
Stream of dragenter events handled by this Document.
no setter
onDragLeave Stream<MouseEvent>
Stream of dragleave events handled by this Document.
no setter
onDragOver Stream<MouseEvent>
Stream of dragover events handled by this Document.
no setter
onDragStart Stream<MouseEvent>
Stream of dragstart events handled by this Document.
no setter
onDrop Stream<MouseEvent>
Stream of drop events handled by this Document.
no setter
onDurationChange Stream<Event>
no setter
onEmptied Stream<Event>
no setter
onEnded Stream<Event>
no setter
onError Stream<Event>
Stream of error events handled by this Document.
no setter
onFocus Stream<Event>
Stream of focus events handled by this Document.
no setter
onFullscreenChange Stream<Event>
Stream of fullscreenchange events handled by this Document.
no setter
onFullscreenError Stream<Event>
Stream of fullscreenerror events handled by this Document.
no setter
onInput Stream<Event>
Stream of input events handled by this Document.
no setter
onInvalid Stream<Event>
Stream of invalid events handled by this Document.
no setter
onKeyDown Stream<KeyboardEvent>
Stream of keydown events handled by this Document.
no setter
onKeyPress Stream<KeyboardEvent>
Stream of keypress events handled by this Document.
no setter
onKeyUp Stream<KeyboardEvent>
Stream of keyup events handled by this Document.
no setter
onLoad Stream<Event>
Stream of load events handled by this Document.
no setter
onLoadedData Stream<Event>
no setter
onLoadedMetadata Stream<Event>
no setter
onMouseDown Stream<MouseEvent>
Stream of mousedown events handled by this Document.
no setter
onMouseEnter Stream<MouseEvent>
Stream of mouseenter events handled by this Document.
no setter
onMouseLeave Stream<MouseEvent>
Stream of mouseleave events handled by this Document.
no setter
onMouseMove Stream<MouseEvent>
Stream of mousemove events handled by this Document.
no setter
onMouseOut Stream<MouseEvent>
Stream of mouseout events handled by this Document.
no setter
onMouseOver Stream<MouseEvent>
Stream of mouseover events handled by this Document.
no setter
onMouseUp Stream<MouseEvent>
Stream of mouseup events handled by this Document.
no setter
onMouseWheel Stream<WheelEvent>
Stream of mousewheel events handled by this Document.
no setter
onPaste Stream<ClipboardEvent>
Stream of paste events handled by this Document.
no setter
onPause Stream<Event>
no setter
onPlay Stream<Event>
no setter
onPlaying Stream<Event>
no setter
onPointerLockChange Stream<Event>
no setter
onPointerLockError Stream<Event>
no setter
onRateChange Stream<Event>
no setter
onReadyStateChange Stream<Event>
Stream of readystatechange events handled by this Document.
no setter
onReset Stream<Event>
Stream of reset events handled by this Document.
no setter
onResize Stream<Event>
no setter
onScroll Stream<Event>
Stream of scroll events handled by this Document.
no setter
onSearch Stream<Event>
Stream of search events handled by this Document.
no setter
onSecurityPolicyViolation Stream<SecurityPolicyViolationEvent>
Stream of securitypolicyviolation events handled by this Document.
no setter
onSeeked Stream<Event>
no setter
onSeeking Stream<Event>
no setter
onSelect Stream<Event>
Stream of select events handled by this Document.
no setter
onSelectionChange Stream<Event>
Stream of selectionchange events handled by this Document.
no setter
onSelectStart Stream<Event>
Stream of selectstart events handled by this Document.
no setter
onStalled Stream<Event>
no setter
onSubmit Stream<Event>
Stream of submit events handled by this Document.
no setter
onSuspend Stream<Event>
no setter
onTimeUpdate Stream<Event>
no setter
onTouchCancel Stream<TouchEvent>
Stream of touchcancel events handled by this Document.
no setter
onTouchEnd Stream<TouchEvent>
Stream of touchend events handled by this Document.
no setter
onTouchMove Stream<TouchEvent>
Stream of touchmove events handled by this Document.
no setter
onTouchStart Stream<TouchEvent>
Stream of touchstart events handled by this Document.
no setter
onVolumeChange Stream<Event>
no setter
onWaiting Stream<Event>
no setter
origin String?
final
ownerDocument Document?
Document that owns this node.
finalinherited
parent Element?
no setterinherited
parentNode Node?
no setterinherited
pointerLockElement Element?
no setter
previousNode Node?
no setterinherited
readyState String?
no setter
rootElement Element?
no setter
rootScroller Element?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollingElement Element?
no setter
suborigin String?
no setter
supportsRegister bool
no setter
supportsRegisterElement bool
no setter
text String?
getter/setter pairinherited-setteroverride-getter
timeline DocumentTimeline
no setter
visibilityState String?
no setter
window Window
final

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
adoptNode(Node node) Node
append(Node node) Node
inherited
clone(bool? deep) Node
inherited
contains(Node? node) bool
inherited
createDocumentFragment() DocumentFragment
createElement(String tagName, [String? typeExtension]) Element
createElementNS(String namespaceUri, String qualifiedName, [String? typeExtension]) Element
dispatchEvent(Event event) bool
inherited
execCommand(String commandId, [bool? showUI, String? value]) bool
exitFullscreen() → void
exitPointerLock() → void
getElementById(String id) Element?
inherited
getElementsByClassName(String classNames) List<Node>
getElementsByName(String name) List<Node>
getElementsByTagName(String tagName) List<Node>
getRootNode() Node
inherited
hasChildNodes() bool
inherited
importNode(Node node, [bool? deep]) Node
insertAllBefore(Iterable<Node> nodes, Node? before) → void
inherited
insertBefore(Node node, Node? before) → void
override
internalCloneWithOwnerDocument(Document ownerDocument, bool deep) Node
inherited
internalToString() String
Internal method. __Not part of "dart:html".
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryCommandEnabled(String commandId) bool
queryCommandIndeterm(String commandId) bool
queryCommandState(String commandId) bool
queryCommandSupported(String commandId) bool
queryCommandValue(String commandId) String
querySelector(String selectors) Element?
inherited
querySelectorAll<T extends Element>(String input) ElementList<T>
Finds all descendant elements of this document that match the specified group of selectors.
inherited
registerElement(String tag, Type customElementClass, {String? extendsTag}) → void
registerElement2(String tag, [Map? options]) Function
Register a custom subclass of Element to be instantiatable by the DOM.
remove() → void
override
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
replaceWith(Node node) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pointerLockChangeEvent → const EventStreamProvider<Event>
pointerLockErrorEvent → const EventStreamProvider<Event>
readyStateChangeEvent → const EventStreamProvider<Event>
Static factory designed to expose readystatechange events to event handlers that are not necessarily instances of Document.
securityPolicyViolationEvent → const EventStreamProvider<SecurityPolicyViolationEvent>
Static factory designed to expose securitypolicyviolation events to event handlers that are not necessarily instances of Document.
selectionChangeEvent → const EventStreamProvider<Event>
Static factory designed to expose selectionchange events to event handlers that are not necessarily instances of Document.