appendText method
Adds the specified text as a text node after the last child of this document fragment.
Implementation
void appendText(String text) {
append(Text(text));
}
Adds the specified text as a text node after the last child of this document fragment.
void appendText(String text) {
append(Text(text));
}