DomMatrixReadOnly class abstract

Implementers

Constructors

DomMatrixReadOnly()

Properties

a int
no setter
b int
no setter
c int
no setter
d int
no setter
e int
no setter
f int
no setter
hashCode int
The hash code for this object.
no setterinherited
m11 int
no setter
m12 int
no setter
m13 int
no setter
m14 int
no setter
m21 int
no setter
m22 int
no setter
m23 int
no setter
m24 int
no setter
m31 int
no setter
m32 int
no setter
m33 int
no setter
m34 int
no setter
m41 int
no setter
m42 int
no setter
m43 int
no setter
m44 int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

flipX() DomMatrix
flipY() DomMatrix
inverse() DomMatrix
multiply(DomMatrix secondDomMatrix) DomMatrix
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotate(num angle) DomMatrix
rotateFromVector(num x, num y) DomMatrix
scale([num scaleX, num scaleY, num scaleZ, num originX, num originY, num originZ]) DomMatrix
scale3d([num scaleX, num scaleY, num scaleZ, num originX, num originY, num originZ]) DomMatrix
skewX(num angle) DomMatrix
skewY(num angle) DomMatrix
toString() String
A string representation of this object.
inherited
translate(num tx, num ty, num tz) DomMatrix

Operators

operator ==(Object other) bool
The equality operator.
inherited