copyEvent constant

Static factory designed to expose copy events to event handlers that are not necessarily instances of Element.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<ClipboardEvent> copyEvent =
    EventStreamProvider<ClipboardEvent>('copy');