getDestinationInsertionPoints method
Returns a list of shadow DOM insertion points to which this element is distributed.
Other resources
- Shadow DOM specification from W3C.
Implementation
List<Node> getDestinationInsertionPoints() => [];
Returns a list of shadow DOM insertion points to which this element is distributed.
List<Node> getDestinationInsertionPoints() => [];