innerHtml property
String?
get
innerHtml
Implementation
String? get innerHtml {
final sb = StringBuffer();
final flags = _getPrintingFlags(this);
var next = firstChild;
while (next != null) {
_printNode(sb, flags, next);
next = next.nextNode;
}
return sb.toString();
}
set
innerHtml
(String? html)
Parses the HTML fragment and sets it as the contents of this element.
This uses the default sanitization behavior to sanitize the HTML fragment, use setInnerHtml to override the default behavior.
Implementation
set innerHtml(String? html) {
setInnerHtml(html);
}