keyUpEvent constant

Static factory designed to expose keyup events to event handlers that are not necessarily instances of Element.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<KeyboardEvent> keyUpEvent =
    EventStreamProvider<KeyboardEvent>('keyup');