pasteEvent constant

Static factory designed to expose paste events to event handlers that are not necessarily instances of Element.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<ClipboardEvent> pasteEvent =
    EventStreamProvider<ClipboardEvent>('paste');