Event class

Implementers

Constructors

Event(String type, {bool canBubble = true, bool cancelable = true})
factory
Event.eventType(String type, String name, {bool canBubble = true, bool cancelable = true})
Creates a new Event object of the specified type.
factory
Event.internal(String type, {EventTarget? target, bool? composed = false, bool canBubble = true, bool? cancelable = true})

Properties

bubbles bool?
final
cancelable bool?
final
composed bool?
final
currentTarget EventTarget?
no setter
defaultPrevented bool
no setter
eventPhase int
no setter
hashCode int
The hash code for this object.
no setterinherited
isTrusted bool?
no setter
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setter
path List<EventTarget>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target EventTarget?
no setter
timeStamp num?
final
type String
final

Methods

composedPath() List<EventTarget>
internalSetTarget(EventTarget? target) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
stopImmediatePropagation() → void
stopPropagation() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

AT_TARGET → const int
This event is being handled by the event target.
BUBBLING_PHASE → const int
This event is bubbling up through the target's ancestors.
CAPTURING_PHASE → const int
This event is propagating through the target's ancestors, starting from the document.