matchingTarget property

Element get matchingTarget

A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.

Implementation

Element get matchingTarget {
  throw UnsupportedError('No matchingTarget');
}