File class

Implemented types

Constructors

File(List<Object> fileBits, String fileName, [Map? options])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastModified int
no setter
lastModifiedDate DateTime
no setter
name String
no setter
relativePath String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setteroverride
type String
no setteroverride

Methods

internalBytes() Future<List<int>>
Internal method. Not part of "dart:html".
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
slice([int? start, int? end, String? contentType]) Blob
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited