FileEntry class

Inheritance

Constructors

FileEntry.internal()

Properties

filesystem FileSystem?
no setterinherited
fullPath String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
no setterinherited
isFile bool
no setteroverride
name String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyTo(DirectoryEntry parent, {String? name}) Future<Entry>
inherited
createWriter() Future<FileWriter>
file() Future<File>
getMetadata() Future<Metadata>
inherited
getParent() Future<Entry>
inherited
moveTo(DirectoryEntry parent, {String? name}) Future<Entry>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() Future
override
toString() String
A string representation of this object.
inherited
toUrl() String
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited