abortEvent constant

Static factory designed to expose abort events to event handlers that are not necessarily instances of FileReader.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<ProgressEvent> abortEvent =
    EventStreamProvider<ProgressEvent>('abort');