Geoposition class

Constructors

Geoposition.internal({required Coordinates? coords, required int? timestamp})
Internal constructor. Not part of dart:html.

Properties

coords Coordinates?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited