getAllResponseHeaders method

  1. @Unstable()
String getAllResponseHeaders()

Retrieve all the response headers from a request.

null if no headers have been received. For multipart requests, getAllResponseHeaders will return the response headers for the current part of the request.

See also HTTP response headers for a list of common response headers.

Implementation

@Unstable()
String getAllResponseHeaders() => _responseHeaders.entries
    .map((entry) => '${entry.key}: ${entry.value}')
    .join('\r\n');