loadEvent constant

Static factory designed to expose load events to event handlers that are not necessarily instances of HttpRequestEventTarget.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<ProgressEvent> loadEvent =
    EventStreamProvider<ProgressEvent>('load');