SEMICOLON constant
int
const SEMICOLON
CAUTION: This constant requires localization for other locales and keyboard layouts.
Implementation
static const int SEMICOLON = 186;
CAUTION: This constant requires localization for other locales and keyboard layouts.
static const int SEMICOLON = 186;