UNKNOWN constant
int
const UNKNOWN
A sentinel value if the keycode could not be determined.
Implementation
static const int UNKNOWN = -1;
A sentinel value if the keycode could not be determined.
static const int UNKNOWN = -1;