KeyEvent class

Inheritance

Constructors

KeyEvent(String type, {required EventTarget currentTarget, int? charCode, bool altKey = false, bool canBubble = true, bool cancelable = true, bool ctrlKey = false, int? keyCode, int? location, bool metaKey = false, bool shiftKey = false, Window? view})

Properties

altKey bool
finalinherited
bubbles bool?
finalinherited
cancelable bool?
finalinherited
charCode int
finalinherited
code String?
finalinherited
composed bool?
finalinherited
ctrlKey bool
finalinherited
currentTarget EventTarget
final
defaultPrevented bool
no setterinherited
detail int?
finalinherited
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isComposing bool?
finalinherited
isTrusted bool?
no setterinherited
key String?
no setterinherited
keyCode int
finalinherited
location int?
finalinherited
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
metaKey bool
finalinherited
path List<EventTarget>
no setterinherited
repeat bool?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftKey bool
finalinherited
sourceCapabilities InputDeviceCapabilities?
finalinherited
target EventTarget?
no setterinherited
timeStamp num?
finalinherited
type String
finalinherited
view Object?
finalinherited
which int?
no setterinherited

Methods

composedPath() List<EventTarget>
inherited
getModifierState(String keyArg) bool
inherited
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

keyDownEvent EventStreamProvider<KeyEvent>
Accessor to provide a stream of KeyEvents on the desired target.
no setter
keyPressEvent EventStreamProvider<KeyEvent>
Accessor to provide a stream of KeyEvents on the desired target.
no setter
keyUpEvent EventStreamProvider<KeyEvent>
Accessor to provide a stream of KeyEvents on the desired target.
no setter