KeyboardEvent class

Inheritance
Implementers

Constructors

KeyboardEvent(String type, {Window? view, bool altKey = false, int? charCode, String? code, bool ctrlKey = false, bool? isComposing = false, int? keyCode, int? location, bool metaKey = false, bool? repeat = false, bool shiftKey = false, bool canBubble = true, bool cancelable = true})

Properties

altKey bool
final
bubbles bool?
finalinherited
cancelable bool?
finalinherited
charCode int
final
code String?
final
composed bool?
finalinherited
ctrlKey bool
final
currentTarget EventTarget?
no setterinherited
defaultPrevented bool
no setterinherited
detail int?
finalinherited
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isComposing bool?
final
isTrusted bool?
no setterinherited
key String?
no setter
keyCode int
final
location int?
final
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
metaKey bool
final
path List<EventTarget>
no setterinherited
repeat bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftKey bool
final
sourceCapabilities InputDeviceCapabilities?
finalinherited
target EventTarget?
no setterinherited
timeStamp num?
finalinherited
type String
finalinherited
view Object?
finalinherited
which int?
no setter

Methods

composedPath() List<EventTarget>
inherited
getModifierState(String keyArg) bool
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited