Location class

Inheritance

Constructors

Location.internal({required String href})

Properties

ancestorOrigins List<String>
no setter
hash String
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
host String
no setterinherited
hostname String?
no setterinherited
href String
getter/setter pairoverride-setter
origin String?
no setterinherited
pathname String?
getter/setter pairinherited
port String
getter/setter pairinherited
protocol String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
getter/setter pairinherited

Methods

assign([String? url]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload() → void
replace(String url) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

configureBrowserBindings({bool reload()?, bool replace(String url)?, bool assign(String url)?, String? currentHref()?}) → void