MediaDevices class

Inheritance
Annotations

Constructors

MediaDevices.fallback()
factory
MediaDevices.internal()

Properties

hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
enumerateDevices() Future<List>
getSupportedConstraints() Map
getUserMedia([Map? constraints]) Future<MediaStream>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited