play method
Implementation
Future play() => Future.error(UnsupportedError(
'Media playback is not available outside a browser context.'));
Future play() => Future.error(UnsupportedError(
'Media playback is not available outside a browser context.'));