MediaSource class

Inheritance
Annotations

Constructors

MediaSource()
factory
MediaSource.internal()

Properties

activeSourceBuffers List<SourceBuffer>?
no setter
duration num?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
readyState String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceBuffers List<SourceBuffer>?
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
addSourceBuffer(String type) SourceBuffer
clearLiveSeekableRange() → void
dispatchEvent(Event event) bool
inherited
endOfStream([String? error]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
removeSourceBuffer(SourceBuffer buffer) → void
setLiveSeekableRange(num start, num end) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supported bool
no setter

Static Methods

isTypeSupported(String type) bool