MediaStreamTrackEvent class abstract

Inheritance

Constructors

MediaStreamTrackEvent(String type, Map eventInitDict)
factory

Properties

bubbles bool?
finalinherited
cancelable bool?
finalinherited
composed bool?
finalinherited
currentTarget EventTarget?
no setterinherited
defaultPrevented bool
no setterinherited
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isTrusted bool?
no setterinherited
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
path List<EventTarget>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target EventTarget?
no setterinherited
timeStamp num?
finalinherited
track MediaStreamTrack
no setter
type String
finalinherited

Methods

composedPath() List<EventTarget>
inherited
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited