MessagePort class abstract

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
onMessage Stream<MessageEvent>
Stream of message events handled by this MessagePort.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
close() → void
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postMessage(dynamic message, [List<Object> transfer]) → void
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited