MouseEvent class

Inheritance
Implementers

Constructors

MouseEvent(String type, {Window? view, int detail = 0, int screenX = 0, int screenY = 0, int clientX = 0, int clientY = 0, int button = 0, bool canBubble = true, bool cancelable = true, bool ctrlKey = false, bool altKey = false, bool shiftKey = false, bool metaKey = false, EventTarget? relatedTarget})
factory

Properties

altKey bool?
final
bubbles bool?
finalinherited
button int?
final
buttons int?
final
cancelable bool?
finalinherited
client Point<num>
no setter
composed bool?
finalinherited
ctrlKey bool?
final
currentTarget EventTarget?
no setterinherited
dataTransfer DataTransfer
no setter
defaultPrevented bool
no setterinherited
detail int?
finalinherited
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isTrusted bool?
no setterinherited
layer Point<num>
no setter
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
metaKey bool?
final
movement Point<num>
no setter
offset Point<num>
The coordinates of the mouse pointer in target node coordinates.
no setter
page Point<num>
no setter
path List<EventTarget>
no setterinherited
region String?
final
relatedTarget EventTarget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen Point<num>
no setter
shiftKey bool?
final
sourceCapabilities InputDeviceCapabilities?
finalinherited
target EventTarget?
no setterinherited
timeStamp num?
finalinherited
type String
finalinherited
view Object?
finalinherited

Methods

composedPath() List<EventTarget>
inherited
getModifierState(String keyArg) bool
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited