Navigator class

Inheritance
Implemented types

Constructors

Internal constructor. NOT part of "dart:html".

Properties

appCodeName String
final
appName String
final
appVersion String
final
budget BudgetService?
no setter
clipboard Clipboard?
no setter
connection NetworkInformation?
no setter
cookieEnabled bool?
no setteroverride
credentials CredentialsContainer?
no setter
dartEnabled bool
no setteroverride
deviceMemory num?
final
doNotTrack String?
no setter
geolocation Geolocation
getter/setter pair
hardwareConcurrency int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
internalWindow Window
final
language String?
no setteroverride
languages List<String>
no setteroverride
maxTouchPoints int?
no setter
mediaCapabilities MediaCapabilities?
no setter
mediaDevices MediaDevices?
no setter
mediaSession MediaSession?
no setter
mimeTypes List<MimeType>?
no setter
nfc NFC?
no setter
onLine bool
no setteroverride
permissions Permissions?
no setter
platform String
final
presentation Presentation?
no setter
product String
final
productSub String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceWorker ServiceWorkerContainer?
no setter
storage StorageManager?
no setter
userAgent String
no setteroverride
vendor String
no setter
vendorSub String
no setter
vr VR?
no setter
webdriver bool?
no setteroverride

Methods

cancelKeyboardLock() → void
getBattery() Future
getGamepads() List<Gamepad>
getInstalledRelatedApps() Future<RelatedApplication>
getUserMedia({dynamic audio = false, dynamic video = false}) Future<MediaStream>
Gets a stream (video and or audio) from the local computer.
getVRDisplays() Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerProtocolHandler(String scheme, String url, String title) → void
requestKeyboardLock([List<String>? keyCodes]) Future
requestMediaKeySystemAccess(String keySystem, List<Map> supportedConfigurations) Future
requestMidiAccess([Map? options]) Future
sendBeacon(String url, Object data) bool
share([Map? data]) Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited