NetworkInformation class abstract

Implemented types

Properties

no setter
downlinkMax num?
no setter
effectiveType String?
no setter
hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
onChange Stream<Event>
no setter
rtt int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

changeEvent → const EventStreamProvider<Event>