Node class abstract

Inheritance
Implementers

Properties

baseUri String?
no setter
childNodes List<Node>
no setter
firstChild Node?
no setter
hashCode int
The hash code for this object.
no setterinherited
internalElementData InternalElementData?
no setter
isConnected bool
no setter
lastChild Node?
no setter
nextNode Node?
no setter
nodeName String?
no setter
nodes List<Node>
getter/setter pair
nodeType int
no setter
nodeValue String?
no setter
on Events
no setterinherited
ownerDocument Document?
Document that owns this node.
final
parent Element?
no setter
parentNode Node?
no setter
previousNode Node?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
getter/setter pair

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
append(Node node) Node
clone(bool? deep) Node
contains(Node? node) bool
dispatchEvent(Event event) bool
inherited
getRootNode() Node
hasChildNodes() bool
insertAllBefore(Iterable<Node> nodes, Node? before) → void
insertBefore(Node node, Node? before) → void
internalCloneWithOwnerDocument(Document ownerDocument, bool deep) Node
internalToString() String
Internal method. __Not part of "dart:html".
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
replaceWith(Node node) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ATTRIBUTE_NODE → const int
CDATA_SECTION_NODE → const int
COMMENT_NODE → const int
DOCUMENT_FRAGMENT_NODE → const int
DOCUMENT_NODE → const int
DOCUMENT_TYPE_NODE → const int
ELEMENT_NODE → const int
ENTITY_NODE → const int
ENTITY_REFERENCE_NODE → const int
NOTATION_NODE → const int
PROCESSING_INSTRUCTION_NODE → const int
TEXT_NODE → const int