Notification class

Inheritance

Constructors

Notification(String title, {String? dir, String? body, String? lang, String? tag, String? icon})

Properties

actions List?
final
badge String?
final
body String?
final
data Object?
final
dir String?
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
image String?
final
lang String?
final
on Events
no setterinherited
onClick Stream<Event>
Stream of click events handled by this Notification.
no setter
onClose Stream<Event>
Stream of close events handled by this Notification.
no setter
onError Stream<Event>
Stream of error events handled by this Notification.
no setter
onShow Stream<Event>
Stream of show events handled by this Notification.
no setter
renotify bool?
final
requireInteraction bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
silent bool?
final
tag String?
final
timestamp int?
final
title String?
final
vibrate List<int>?
final

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
close() → void
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

maxActions int
no setter
permission String
no setter
supported bool
Checks if this type is supported on the current platform.
no setter

Static Methods

requestPermission() Future<String>

Constants

clickEvent → const EventStreamProvider<Event>
Static factory designed to expose click events to event handlers that are not necessarily instances of Notification.
closeEvent → const EventStreamProvider<Event>
Static factory designed to expose close events to event handlers that are not necessarily instances of Notification.
errorEvent → const EventStreamProvider<Event>
Static factory designed to expose error events to event handlers that are not necessarily instances of Notification.
showEvent → const EventStreamProvider<Event>
Static factory designed to expose show events to event handlers that are not necessarily instances of Notification.