OffscreenCanvas class abstract

Inheritance

Constructors

OffscreenCanvas(int width, int height)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
getter/setter pair
on Events
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
getter/setter pair

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
convertToBlob([Map options]) Future
dispatchEvent(Event event) bool
inherited
getContext(String contextType, [Map attributes]) Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited
transferToImageBitmap() ImageBitmap

Operators

operator ==(Object other) bool
The equality operator.
inherited