Plugin class abstract

Properties

description String?
no setter
filename String?
no setter
hashCode int
The hash code for this object.
no setterinherited
length int?
no setter
name String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

item(int index) MimeType
namedItem(String name) MimeType
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited