RemotePlayback class abstract

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
cancelWatchAvailability([int id]) Future
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prompt() Future
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited
watchAvailability(RemotePlaybackAvailabilityCallback callback) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited