RtcDtmfSender class abstract

Inheritance
Annotations

Properties

canInsertDtmf bool?
no setter
duration int?
no setter
hashCode int
The hash code for this object.
no setterinherited
interToneGap int?
no setter
on Events
no setterinherited
onToneChange Stream<RtcDtmfToneChangeEvent>
Stream of tonechange events handled by this RtcDtmfSender.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toneBuffer String?
no setter
track MediaStreamTrack?
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
insertDtmf(String tones, [int? duration, int? interToneGap]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

toneChangeEvent → const EventStreamProvider<RtcDtmfToneChangeEvent>
Static factory designed to expose tonechange events to event handlers that are not necessarily instances of RtcDtmfSender.