supported property
bool
get
supported
Checks if Real Time Communication (RTC) APIs are supported and enabled on the current platform.
Implementation
static bool get supported => false;
Checks if Real Time Communication (RTC) APIs are supported and enabled on the current platform.
static bool get supported => false;