ScreenOrientation class

Inheritance

Constructors

ScreenOrientation.constructor({int angle = 1, String type = 'vertical'})

Properties

angle int
final
hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
onChange Stream<Event>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
lock(String orientation) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited
unlock() → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

changeEvent → const EventStreamProvider<Event>