SecurityPolicyViolationEvent class

Inheritance

Constructors

SecurityPolicyViolationEvent.constructor(String type, {String? blockedUri, int? columnNumber, String? disposition, String? documentUri, String? effectiveDirective, int? lineNumber, String? originalPolicy, String? referrer, String? sample, String? sourceFile, int? statusCode, String? violatedDirective})

Properties

blockedUri String?
final
bubbles bool?
finalinherited
cancelable bool?
finalinherited
columnNumber int?
final
composed bool?
finalinherited
currentTarget EventTarget?
no setterinherited
defaultPrevented bool
no setterinherited
disposition String?
final
documentUri String?
final
effectiveDirective String?
final
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isTrusted bool?
no setterinherited
lineNumber int?
final
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
originalPolicy String?
final
path List<EventTarget>
no setterinherited
referrer String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sample String?
final
sourceFile String?
final
statusCode int?
final
target EventTarget?
no setterinherited
timeStamp num?
finalinherited
type String
finalinherited
violatedDirective String?
final

Methods

composedPath() List<EventTarget>
inherited
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited