Selection class abstract

Constructors

Selection.constructor({Node? anchorNode, int? anchorOffset, Node? baseNode, int? baseOffset, Node? extentNode, int? extentOffset, Node? focusNode, int? focusOffset, bool? isCollapsed, int? rangeCount, String? type})

Properties

anchorNode Node?
final
anchorOffset int?
final
baseNode Node?
final
baseOffset int?
final
extentNode Node?
final
extentOffset int?
final
focusNode Node?
final
focusOffset int?
final
hashCode int
The hash code for this object.
no setterinherited
isCollapsed bool?
final
rangeCount int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
final

Methods

addRange(Range range) → void
collapse(Node node, [int? offset]) → void
collapseToEnd() → void
collapseToStart() → void
containsNode(Node node, [bool? allowPartialContainment]) bool
deleteFromDocument() → void
empty() → void
extend(Node node, [int? offset]) → void
getRangeAt(int index) Range
modify(String alter, String direction, String granularity) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllRanges() → void
removeRange(Range range) → void
selectAllChildren(Node node) → void
setBaseAndExtent(Node baseNode, int baseOffset, Node extentNode, int extentOffset) → void
setPosition(Node node, [int? offset]) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited