getRegistration method
Implementation
Future<ServiceWorkerRegistration> getRegistration([String? documentURL]) =>
Future.error(UnsupportedError(
'Service workers are not available outside a browser context.'));
Future<ServiceWorkerRegistration> getRegistration([String? documentURL]) =>
Future.error(UnsupportedError(
'Service workers are not available outside a browser context.'));