register method
Implementation
Future<ServiceWorkerRegistration> register(String url, [Map? options]) =>
Future.error(UnsupportedError(
'Service workers are not available outside a browser context.'));
Future<ServiceWorkerRegistration> register(String url, [Map? options]) =>
Future.error(UnsupportedError(
'Service workers are not available outside a browser context.'));