ShadowRoot class abstract

Inheritance

Properties

activeElement Element?
no setter
baseUri String?
no setterinherited
childNodes List<Node>
no setterinherited
children List<Element>
getter/setter pairinherited
delegatesFocus bool?
no setter
firstChild Node?
no setterinherited
fullscreenElement Element?
no setter
hashCode int
The hash code for this object.
no setterinherited
host Element?
no setter
innerHtml String?
getter/setter pairinherited
internalElementData InternalElementData?
no setterinherited
isConnected bool
no setterinherited
lastChild Node?
no setterinherited
mode String?
no setter
nextNode Node?
no setterinherited
nodeName String?
no setterinherited
nodes List<Node>
getter/setter pairinherited
nodeType int
no setterinherited
nodeValue String?
no setterinherited
olderShadowRoot ShadowRoot?
no setter
on Events
no setterinherited
ownerDocument Document?
Document that owns this node.
finalinherited
parent Element?
no setterinherited
parentNode Node?
no setterinherited
pointerLockElement Element?
no setter
previousNode Node?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleSheets List<StyleSheet>?
no setter
text String?
getter/setter pairinherited

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
append(Node node) Node
inherited
appendHtml(String html, {NodeValidator? validator, NodeTreeSanitizer? treeSanitizer}) → void
Parses the specified text as HTML and adds the resulting node after the last child of this document fragment.
inherited
appendText(String text) → void
Adds the specified text as a text node after the last child of this document fragment.
inherited
clone(bool? deep) Node
inherited
contains(Node? node) bool
inherited
dispatchEvent(Event event) bool
inherited
elementFromPoint(int x, int y) Element
elementsFromPoint(int x, int y) List<Element>
getElementById(String id) Element?
inherited
getRootNode() Node
inherited
getSelection() Selection
hasChildNodes() bool
inherited
insertAllBefore(Iterable<Node> nodes, Node? before) → void
inherited
insertBefore(Node node, Node? before) → void
inherited
internalCloneWithOwnerDocument(Document ownerDocument, bool? deep) Node
inherited
internalToString() String
Internal method. __Not part of "dart:html".
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
querySelector(String selectors) Element?
inherited
querySelectorAll<T extends Element>(String input) ElementList<T>
Finds all descendant elements of this document that match the specified group of selectors.
inherited
remove() → void
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
replaceWith(Node node) → void
inherited
setInnerHtml(String? html, {NodeValidator? validator, NodeTreeSanitizer? treeSanitizer}) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supported bool
no setter