SpeechSynthesisUtterance class abstract

Inheritance

Constructors

SpeechSynthesisUtterance([String? text])
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lang String?
no setter
on Events
no setterinherited
onBoundary Stream<SpeechSynthesisEvent>
Stream of boundary events handled by this SpeechSynthesisUtterance.
no setter
onEnd Stream<SpeechSynthesisEvent>
Stream of end events handled by this SpeechSynthesisUtterance.
no setter
onError Stream<Event>
Stream of error events handled by this SpeechSynthesisUtterance.
no setter
onMark Stream<SpeechSynthesisEvent>
Stream of mark events handled by this SpeechSynthesisUtterance.
no setter
onPause Stream<Event>
Stream of pause events handled by this SpeechSynthesisUtterance.
no setter
onResume Stream<SpeechSynthesisEvent>
Stream of resume events handled by this SpeechSynthesisUtterance.
no setter
onStart Stream<SpeechSynthesisEvent>
Stream of start events handled by this SpeechSynthesisUtterance.
no setter
pitch num?
no setter
rate num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
no setter
voice SpeechSynthesisVoice?
no setter
volume num?
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

boundaryEvent → const EventStreamProvider<SpeechSynthesisEvent>
Static factory designed to expose boundary events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
endEvent → const EventStreamProvider<SpeechSynthesisEvent>
Static factory designed to expose end events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
errorEvent → const EventStreamProvider<Event>
Static factory designed to expose error events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
markEvent → const EventStreamProvider<SpeechSynthesisEvent>
Static factory designed to expose mark events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
pauseEvent → const EventStreamProvider<Event>
Static factory designed to expose pause events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
resumeEvent → const EventStreamProvider<SpeechSynthesisEvent>
Static factory designed to expose resume events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.
startEvent → const EventStreamProvider<SpeechSynthesisEvent>
Static factory designed to expose start events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.