markEvent constant

Static factory designed to expose mark events to event handlers that are not necessarily instances of SpeechSynthesisUtterance.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<SpeechSynthesisEvent> markEvent =
    EventStreamProvider<SpeechSynthesisEvent>('mark');