TouchEvent class

Inheritance

Constructors

TouchEvent.constructor(String type, {bool altKey = false, TouchList? changedTouches, bool ctrlKey = false, bool metaKey = false, bool shiftKey = false, TouchList? targetTouches, TouchList? touches})

Properties

altKey bool
final
bubbles bool?
finalinherited
cancelable bool?
finalinherited
changedTouches TouchList?
final
composed bool?
finalinherited
ctrlKey bool
final
currentTarget EventTarget?
no setterinherited
defaultPrevented bool
no setterinherited
detail int?
finalinherited
eventPhase int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isTrusted bool?
no setterinherited
matchingTarget Element
A pointer to the element whose CSS selector matched within which an event was fired. If this Event was not associated with any Event delegation, accessing this value will throw an UnsupportedError.
no setterinherited
metaKey bool
final
path List<EventTarget>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftKey bool
final
sourceCapabilities InputDeviceCapabilities?
finalinherited
target EventTarget?
no setterinherited
targetTouches TouchList?
final
timeStamp num?
finalinherited
touches TouchList?
final
type String
finalinherited
view Object?
finalinherited

Methods

composedPath() List<EventTarget>
inherited
internalSetTarget(EventTarget? target) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preventDefault() → void
inherited
stopImmediatePropagation() → void
inherited
stopPropagation() → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

supported bool
no setter