supported property
bool
get
supported
Checks if this type is supported on the current platform.
Implementation
static bool get supported => false;
Checks if this type is supported on the current platform.
static bool get supported => false;