ValidityState class

Constructors

ValidityState.constructor({bool? badInput, bool? customError, bool? patternMismatch, bool? rangeOverflow, bool? rangeUnderflow, bool? stepMismatch, bool? tooLong, bool? tooShort, bool? typeMismatch, bool? valid, bool? valueMissing})

Properties

badInput bool?
final
customError bool?
final
hashCode int
The hash code for this object.
no setterinherited
patternMismatch bool?
final
rangeOverflow bool?
final
rangeUnderflow bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepMismatch bool?
final
tooLong bool?
final
tooShort bool?
final
typeMismatch bool?
final
valid bool?
final
valueMissing bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited