animationIterationEvent constant

EventStreamProvider<AnimationEvent> const animationIterationEvent

Static factory designed to expose animationiteration events to event handlers that are not necessarily instances of Window.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<AnimationEvent> animationIterationEvent =
    EventStreamProvider<AnimationEvent>('webkitAnimationIteration');