animationStartEvent constant

EventStreamProvider<AnimationEvent> const animationStartEvent

Static factory designed to expose animationstart events to event handlers that are not necessarily instances of Window.

See EventStreamProvider for usage information.

Implementation

static const EventStreamProvider<AnimationEvent> animationStartEvent =
    EventStreamProvider<AnimationEvent>('webkitAnimationStart');