outerHeight property
The height of this window including all user interface elements.
Other resources
- Window.outerHeight from MDN.
Implementation
final int outerHeight;
The height of this window including all user interface elements.
final int outerHeight;