outerWidth property
The width of the window including all user interface elements.
Other resources
- Window.outerWidth from MDN.
Implementation
final int outerWidth;
The width of the window including all user interface elements.
final int outerWidth;