screenX property
int?
get
screenX
The distance from the left side of the screen to the mouse pointer.
Other resources
- The Screen interface specification from W3C.
Implementation
int? get screenX => null;
The distance from the left side of the screen to the mouse pointer.
int? get screenX => null;