screenY property
int?
get
screenY
The distance from the top of the screen to the mouse pointer.
Other resources
- The Screen interface specification from W3C.
Implementation
int? get screenY => null;
The distance from the top of the screen to the mouse pointer.
int? get screenY => null;