WindowEventHandlers class abstract

Inheritance
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
on Events
no setterinherited
onHashChange Stream<Event>
no setter
onMessage Stream<MessageEvent>
no setter
onOffline Stream<Event>
no setter
onOnline Stream<Event>
no setter
onPopState Stream<PopStateEvent>
no setter
onStorage Stream<StorageEvent>
no setter
onUnload Stream<Event>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
dispatchEvent(Event event) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited