WorkerGlobalScope class

Inheritance
Implementers
Annotations
  • @Native('WorkerGlobalScope')

Properties

addressSpace String?
no setter
caches CacheStorage?
no setter
crypto Crypto?
no setter
hashCode int
The hash code for this object.
no setterinherited
indexedDB IdbFactory?
no setter
isSecureContext bool?
no setter
location Location
no setter
no setter
on Events
no setterinherited
onError Stream<Event>
Stream of error events handled by this WorkerGlobalScope.
no setter
origin String?
no setter
performance WorkerPerformance?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self WorkerGlobalScope
no setter

Methods

addEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
atob(String atob) String
btoa(String btoa) String
dispatchEvent(Event event) bool
inherited
fetch(dynamic input, [Map? init]) Future
importScripts(String urls) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeEventListener(String type, EventListener listener, [bool? useCapture]) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WorkerGlobalScope
no setter

Constants

errorEvent → const EventStreamProvider<Event>
Static factory designed to expose error events to event handlers that are not necessarily instances of WorkerGlobalScope.