WorkerNavigator class abstract

Inheritance
Implemented types
Annotations

Properties

appCodeName String
no setterinherited
appName String
no setterinherited
appVersion String
no setterinherited
dartEnabled bool?
no setterinherited
hardwareConcurrency int?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
onLine bool?
no setterinherited
platform String?
no setterinherited
product String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited