dismissPop static method
Dismisses a popup respecting its shouldMakeInvisibleOnDismiss setting
This method automatically checks if the popup should be made invisible or completely removed based on its shouldMakeInvisibleOnDismiss flag.
Parameters:
id: The unique identifier of the overlay to dismiss
Implementation
static void dismissPop(String id) {
final popContent = getActiveById(id);
if (popContent != null) {
if (popContent.shouldMakeInvisibleOnDismiss) {
_makePopOverlayInvisible(popContent);
} else {
removePop(id);
}
}
}