Glow1 class
- Inheritance
- Available extensions
Constructors
- Glow1({Key? key, required Widget child, bool isEnabled = true, double opacity = 0.4, Color? color, AlignmentGeometry alignment = Alignment.center, BorderRadiusGeometry? borderRadius, bool repeatAnimation = true, Duration animationDuration = const Duration(milliseconds: 1500), Curve animationCurve = Curves.fastEaseInToSlowEaseOut, double startScaleRadius = 1.08, double endScaleRadius = 1.1, VoidCallback? onAnimationComplete, Gradient? gradient})
-
const
Properties
- alignment → AlignmentGeometry
-
Alignment of the stack
final
- animationCurve → Curve
-
Animation curve for the glow effect
final
- animationDuration → Duration
-
Duration of the glow animation
final
- borderRadius → BorderRadiusGeometry?
-
Border radius for the glow effect
final
- child → Widget
-
The child widget that will have the glow effect
final
- color → Color?
-
Color of the glow effect
final
- endScaleRadius → double
-
Blur radius for the glow effect
final
- gradient → Gradient?
-
Optional gradient to use instead of solid color for the glow.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether the glow effect is enabled
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onAnimationComplete → VoidCallback?
-
Called when the glow animation completes a cycle.
final
- opacity → double
-
Maximum opacity of the glow effect (0.0 to 1.0)
final
- repeatAnimation → bool
-
Whether the animation should repeat continuously
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startScaleRadius → double
-
Blur radius for the glow effect
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< Glow1> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited