Cloud class
Properties
-
cloudType
→ String?
-
Get the type of cloud translation of the cloud layer.
no setter
-
cloudTypeCode
→ String?
-
Get the raw ICAO cloud-type code (e.g. 'CB', 'TCU').
no setter
-
code
→ String?
-
Get the code of the group.
no setterinherited
-
cover
→ String?
-
Get the cover description of the cloud layer.
no setter
-
coverCode
→ String?
-
Get the raw ICAO sky-cover code (e.g. 'BKN', 'OVC', 'FEW').
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
heightInFeet
→ double?
-
Get the height of the cloud base in feet.
no setter
-
heightInKilometers
→ double?
-
Get the height of the cloud base in kilometers.
no setter
-
heightInMeters
→ double?
-
Get the height of the cloud base in meters.
no setter
-
heightInSeaMiles
→ double?
-
Get the height of the cloud base in sea miles.
no setter
-
length
→ int
-
Get the length of the code of the group.
no setterinherited
-
oktas
→ String?
-
Get the oktas amount of the cloud layer.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
asMap()
→ Map<String, Object?>
-
Returns the object data as a map like
Map<String, dynamic>.
override
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON()
→ String
-
Returns the object data as a string in JSON format.
inherited
-
toString()
→ String
-
A string representation of this object.
override