MetarPressure class
- Inheritance
-
- Mixed-in types
-
Properties
-
code
→ String?
-
Get the code of the group.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
inAtm
→ double?
-
Get the pressure in atmospheres (atm).
no setterinherited
-
inBar
→ double?
-
Get the pressure in bars (bar).
no setterinherited
-
inHPa
→ double?
-
Get the pressure in hecto pascals (hPa).
no setterinherited
-
inInHg
→ double?
-
Get the pressure in mercury inches (inHg).
no setterinherited
-
inKPa
→ double?
-
Get the pressure in kilopascals (kPa).
no setterinherited
-
inMbar
→ double?
-
Get the pressure in millibars (mbar).
no setterinherited
-
inPa
→ double?
-
Get the pressure in pascals (Pa).
no setterinherited
-
length
→ int
-
Get the length of the code of the group.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ double?
-
Get the value as a float.
no setterinherited