MetarRunwayRange class
Basic structure of a groups list from groups found in a aeronautical report from land stations.
Constructors
- MetarRunwayRange(String? code, RegExpMatch? match)
Properties
- code → String?
-
Get the code of the group.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- highInFeet → double?
-
Get the runway high range in feet.
no setter
- highInKilometers → double?
-
Get the runway high range in kilometers.
no setter
- highInMeters → double?
-
Get the runway high range in meters.
no setter
- highInSeaMiles → double?
-
Get the runway high range in sea miles.
no setter
- highRange → String
-
Get the runway high range as a String.
no setter
- length → int
-
Get the length of the code of the group.
no setterinherited
- lowInFeet → double?
-
Get the runway low range in feet.
no setter
- lowInKilometers → double?
-
Get the runway low range in kilometers.
no setter
- lowInMeters → double?
-
Get the runway low range in meters.
no setter
- lowInSeaMiles → double?
-
Get the runway low range in sea miles.
no setter
- lowRange → String
-
Get the runway low range as a String.
no setter
- name → String?
-
Get the runway name.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trend → String?
-
Get the runway range trend.
no setter
Methods
-
asMap(
) → Map< String, Object?> -
Returns the object data as a map like
Map<String, dynamic>.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Returns the object data as a string in JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited