MetarTemperatures class
Basic structure for temperatures in reports from land stations.
Constructors
- MetarTemperatures(String? code, RegExpMatch? match)
Properties
- code → String?
-
Get the code of the group.
no setterinherited
- dewpointInCelsius → double?
-
Get the dewpoint in °Celsius.
no setter
- dewpointInFahrenheit → double?
-
Get the dewpoint in °Fahrenheit.
no setter
- dewpointInKelvin → double?
-
Get the dewpoint in °Kelvin.
no setter
- dewpointInRankine → double?
-
Get the dewpoint in Rankine.
no setter
- dewpointSpread → double?
-
Get the dewpoint spread (temperature − dewpoint) in °Celsius.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- heatIndex → double?
-
Get the NOAA heat index in °Celsius, or
nullif conditions are outside the valid range (temperature ≥ 27 °C, RH ≥ 40 %).no setter - length → int
-
Get the length of the code of the group.
no setterinherited
- relativeHumidity → double?
-
Get the relative humidity as a percentage (0–100) using the
Magnus-Tetens approximation, or
nullif either value is unavailable.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperatureInCelsius → double?
-
Get the temperature in °Celsius.
no setter
- temperatureInFahrenheit → double?
-
Get the temperature in °Fahrenheit.
no setter
- temperatureInKelvin → double?
-
Get the temperature in °Kelvin.
no setter
- temperatureInRankine → double?
-
Get the temperature in Rankine.
no setter
Methods
-
asMap(
) → Map< String, Object?> -
Returns the object data as a map like
Map<String, dynamic>.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Returns the object data as a string in JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
windChill(
double? windSpeedKph) → double? -
Get the wind chill temperature in °Celsius, or
nullif conditions are outside the valid range (temperature ≤ 10 °C, wind speed ≥ 4.8 km/h).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited