Pressure class
Basic structure for pressure attributes.
- Inheritance
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inAtm → double?
-
Get the pressure in atmospheres (atm).
no setter
- inBar → double?
-
Get the pressure in bars (bar).
no setter
- inHPa → double?
-
Get the pressure in hecto pascals (hPa).
no setter
- inInHg → double?
-
Get the pressure in mercury inches (inHg).
no setter
- inKPa → double?
-
Get the pressure in kilopascals (kPa).
no setter
- inMbar → double?
-
Get the pressure in millibars (mbar).
no setter
- inPa → double?
-
Get the pressure in pascals (Pa).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double?
-
Get the value as a float.
no setterinherited
Methods
-
asMap(
) → Map< String, Object?> -
Returns the numeric value data as a map like
Map<String, dynamic>.override -
converted(
{double? conversionDouble, double conversionFunction(double)?}) → double? -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Returns the object data as a string in JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited