Station class
Basic structure for station code groups in reports from land stations.
Args: code (str): the land station code from the report (MROC, SJO, 78762). type (str): the type of land station code (ICAO, IATA, SYNOP).
Properties
- code → String?
-
Get the code of the group.
no setterinherited
- country → String?
-
Get the country to which the land station belongs.
no setter
- elevation → String?
-
Get the elevation of the station.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iata → String?
-
Get the IATA code of the station.
no setter
- icao → String?
-
Get the ICAO code of the station.
no setter
- latitude → String?
-
Get the latitude of the station.
no setter
- length → int
-
Get the length of the code of the group.
no setterinherited
- longitude → String?
-
Get the longitude of the station.
no setter
- name → String?
-
Get the name of the station.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- synop → String?
-
Get the SYNOP code of the station.
no setter
Methods
-
asMap(
) → Map< String, String?> -
Returns the object data as a map like
Map<String, dynamic>.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Returns the object data as a string in JSON format.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited