ModOverlayLifecycleEvent class
Lightweight public metadata for global overlay/modal lifecycle hooks.
id is the effective ID used by the underlying subsystem. For modals this is the same value accepted by dismissal APIs when a caller-provided ID was supplied, otherwise it is the generated modal ID.
Constructors
- ModOverlayLifecycleEvent({required String id, required ModOverlayLifecycleSource source, String? semanticId, Object? modalType, Alignment? modalPosition, int? stackLevel, int? activationOrder, bool? isVisible})
-
const
Properties
- activationOrder → int?
-
Activation order at the time of the event, when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Effective ID for the pop or modal instance.
final
- isVisible → bool?
-
Pop-overlay visibility metadata when available.
final
- modalPosition → Alignment?
-
Modal position metadata when available.
final
- modalType → Object?
-
Modal type metadata when source is ModOverlayLifecycleSource.modal.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticId → String?
-
Optional caller-provided/semantic ID when it differs from the effective ID.
final
- source → ModOverlayLifecycleSource
-
Subsystem that emitted this event.
final
- stackLevel → int?
-
Rendering stack level at the time of the event, when available.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited