EmailTextInputFormatter class
While the user types an email address, this input formatter removes some obviously invalid characters from the input. It does not check if the email address is complete or valid. Note, you should not use this input formatter if you want to allow the user to type anything just to check the validity of the email address only when they finish typing.
TextField(
inputFormatters: [EmailTextInputFormatter()],
);
See also: Email.isValid, which checks if an email address is valid.
- Inheritance
-
- Object
- TextInputFormatter
- EmailTextInputFormatter
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
formatEditUpdate(
TextEditingValue oldValue, TextEditingValue newValue) → TextEditingValue -
Called when text is being typed or cut/copy/pasted in the EditableText.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited