uri property
URI to check for connectivity. A HEAD request will be made to this URI.
Make sure that the cache-control header is set to no-cache on the server
side. Otherwise, the HEAD request will be cached and the result will be
incorrect.
For web platform, make sure that the URI is CORS enabled. To check if
requests are being blocked, open the Network tab in your browser's
developer tools and see if the request is being blocked by CORS.
Implementation
final Uri uri;