customConnectivityCheck property
Function to check reachability of a single network endpoint.
This can be customized to allow for different ways of checking connectivity.
Implementation
final ConnectivityCheckCallback? customConnectivityCheck;
Function to check reachability of a single network endpoint.
This can be customized to allow for different ways of checking connectivity.
final ConnectivityCheckCallback? customConnectivityCheck;