KeyboardSwitch constructor
Renders open when the keyboard is open, and closed when it is closed. Both are
optional, and a missing slot renders nothing.
Implementation
const KeyboardSwitch({super.key, this.open, this.closed}) : builder = null;
Renders open when the keyboard is open, and closed when it is closed. Both are
optional, and a missing slot renders nothing.
const KeyboardSwitch({super.key, this.open, this.closed}) : builder = null;