decimal property
Allows only typing numbers 0-9, plus dot or comma, but if the user types a dot or a comma it will always be converted to the current decimal separator (depending on the locale).
Implementation
static final decimal = NumbersTextInputFormatter._(_NumbersMode.decimalLocale);