decimalWithDot property
Allows only typing numbers 0-9, plus dot or comma, but if the user types a comma it will always appear as a dot.
Implementation
static final decimalWithDot = NumbersTextInputFormatter._(_NumbersMode.decimalDot);
Allows only typing numbers 0-9, plus dot or comma, but if the user types a comma it will always appear as a dot.
static final decimalWithDot = NumbersTextInputFormatter._(_NumbersMode.decimalDot);