OtpCodeLetterCasing enum
How letters typed into the OtpCodeVerificationField are normalized.
A no-op for digits (digits are case-invariant), so picking a casing
alongside OtpCodeType.numbersOnly / OtpCodeLetterSet.binary has no visible
effect. When codeLetterCasing is the only param set on the widget, an
effective OtpCodeLetterSet.all is assumed (any character allowed).
- Inheritance
- Available extensions
Values
- uppercase → const OtpCodeLetterCasing
-
Letters are forced to uppercase, regardless of how they were typed.
- lowercase → const OtpCodeLetterCasing
-
Letters are forced to lowercase, regardless of how they were typed.
- mixed → const OtpCodeLetterCasing
-
Letters are kept exactly as typed (both cases allowed).
Properties
-
$
→ Signal<
T> -
Available on T, provided by the SignalEnumExtensions extension
Return a signal from a Enum valueno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OtpCodeLetterCasing> - A constant List of the values in this enum, in order of their declaration.