onKeystrokeEvent property
Raw KeyDownEvent callback for custom handling beyond the Intent system. Fires for every key event that reaches the internal KeystrokeListener.
Implementation
final void Function(KeyDownEvent)? onKeystrokeEvent;
Raw KeyDownEvent callback for custom handling beyond the Intent system. Fires for every key event that reaches the internal KeystrokeListener.
final void Function(KeyDownEvent)? onKeystrokeEvent;