SSpreadsheetHorizontalMetrics class

Immutable snapshot of horizontal scroll state for a spreadsheet.

Constructors

SSpreadsheetHorizontalMetrics({double offset = 0, double maxScrollExtent = 0, ScrollController? controller})
const

Properties

controller ScrollController?
final
hashCode int
The hash code for this object.
no setterinherited
maxScrollExtent double
final
offset double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canScrollLeft({double threshold = 100}) bool
canScrollRight({double threshold = 100}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited