SSpreadsheetHorizontalSyncController class
Shared horizontal synchronization state for SSpreadsheet.
Pass one instance to SSpreadsheet.horizontalSyncController and to SSpreadsheetHorizontalScrollButtons to control scrolling externally.
- Inheritance
-
- Object
- ChangeNotifier
- ValueNotifier<
SSpreadsheetHorizontalMetrics> - SSpreadsheetHorizontalSyncController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ SSpreadsheetHorizontalMetrics
-
The current value stored in this notifier.
getter/setter pairinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
animateToEnd(
{Duration duration = const Duration(milliseconds: 800), Curve curve = Curves.easeOutCubic}) → Future< void> -
animateToStart(
{Duration duration = const Duration(milliseconds: 800), Curve curve = Curves.easeOutCubic}) → Future< void> -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
double offset, double maxScrollExtent, ScrollController controller) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited