TimeSpinner class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- TimeSpinner
- Available extensions
Constructors
-
TimeSpinner({required void onChangedSelectedTime(TimeOfDay? selected), Key? key, TimeOfDay? initTime, bool is24HourFormat = false, double spinnerHeight = 120, double spinnerWidth = 60, double elementsSpace = 8, double digitHeight = 40, Color spinnerBgColor = const Color(0xFFF5F5F5), TextStyle selectedTextStyle = const TextStyle(fontSize: 24, fontWeight: FontWeight.bold, color: Colors.blue), TextStyle nonSelectedTextStyle = const TextStyle(fontSize: 18, color: Color(0xFFBDBDBD)), List<
int> ? hrValues, List<int> ? minValues, List<int> discardedHrValues = const [], List<int> discardedMinValues = const [], BorderRadiusGeometry? borderRadius, BoxBorder? spinnerBorder, Function? onKeyboardEditing, bool showNoSelectionDots = true, AmPmButtonStyle? amPmButtonStyle, bool isInfiniteScroll = true}) -
const
Properties
- amPmButtonStyle → AmPmButtonStyle?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- digitHeight → double
-
final
-
discardedHrValues
→ List<
int> -
final
-
discardedMinValues
→ List<
int> -
final
- elementsSpace → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hrValues
→ List<
int> ? -
final
- initTime → TimeOfDay?
-
final
- is24HourFormat → bool
-
final
- isInfiniteScroll → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
minValues
→ List<
int> ? -
final
- nonSelectedTextStyle → TextStyle
-
final
- onChangedSelectedTime → void Function(TimeOfDay? selected)
-
final
- onKeyboardEditing → Function?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedTextStyle → TextStyle
-
final
- showNoSelectionDots → bool
-
final
- spinnerBgColor → Color
-
final
- spinnerBorder → BoxBorder?
-
final
- spinnerHeight → double
-
final
- spinnerWidth → double
-
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< TimeSpinner> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited