SToggle class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SToggle
- Available extensions
Constructors
- SToggle({Key? key, double size = 60.0, Color onColor = Colors.white, Color offColor = Colors.black87, bool value = false, Duration? animationDuration, dynamic onChange(bool value)?, double dragSensitivity = 0.85, double dragSmoothing = 0.1, bool debugShowPointers = false, bool animateBackground = true, double backgroundOpacity = 0.15, double borderWidth = 1.0, Color? borderColor, double littleBorderWidth = 0.0, Color? littleBorderColor, double littleShadowBlurSigma = 6.0, Offset littleShadowOffset = const Offset(0, 2), Color littleShadowColor = const Color(0x40000000)})
-
const
Properties
- animateBackground → bool
-
Animate a faint background tint that blends between offColor and onColor.
When true, a rounded-rect background is drawn behind circles, smoothly
lerping from offColor to onColor following the toggle's visual state.
final
- animationDuration → Duration?
-
final
- backgroundOpacity → double
-
Opacity of the animated background tint (0.0..1.0). Default 0.15 for a faint look.
final
- borderColor → Color?
-
final
- borderWidth → double
-
Outer border around the whole widget (rounded rectangle). Width 0 disables.
final
- debugShowPointers → bool
-
Show debug overlay showing pointer and smoothed small circle positions. Only used in debug builds.
final
- dragSensitivity → double
-
Sensitivity factor for drag to visual mapping (0.0..1.0). Lower = less sensitive
final
- dragSmoothing → double
-
Smoothing (viscosity) for drag pointer to visual mapping: 0.0 = no smoothing, 1.0 = fully sticky
Applies when user drags to make the small circle feel heavy/smooth. Default 0.1.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- littleBorderColor → Color?
-
final
- littleBorderWidth → double
-
Border around the little circle. Width 0 disables.
final
- littleShadowBlurSigma → double
-
Shadow for the little circle.
Set blurSigma to 0 to disable shadow.
final
- littleShadowColor → Color
-
final
- littleShadowOffset → Offset
-
final
- offColor → Color
-
onColor is color when widget switched on,
default value is: Colors.white.
offColor is color when widget switched off,
default value is: Colors.black.
final
- onChange → dynamic Function(bool value)?
-
when change status of widget like switch off or switch on onChange will
call and passed new value
final
- onColor → Color
-
onColor is color when widget switched on,
default value is: Colors.white.
offColor is color when widget switched off,
default value is: Colors.black.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
size of widget.
final
- value → bool
-
status of widget, if value == true widget will switched on else
switched off
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → SToggleState -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited