s_universal_html/src/html/dom/shared_with_dart2js/metadata library
Classes
- DocsEditable
- Metadata that specifies that that member is editable through generated files.
- DomName
- Annotation that specifies that a member is editable through generate files.
- Experimental
- An annotation used to mark an API as being experimental.
- JSName
- A metadata annotation placed on native methods and fields of native classes to specify the JavaScript name.
- Native
- Marks a class as native and defines its JavaScript name(s).
- SupportedBrowser
- An annotation used to mark a feature as only being supported by a subset of the browsers that Dart supports by default.
- Unstable
- Annotation that indicates that an API is not expected to change but has not undergone enough testing to be considered stable.