JsArray<E> class
abstract
A List that proxies a JavaScript array.
- Implemented types
- Available extensions
- AlphaNumericSortingListOfString
- BeautifiedJsonListExtension
- EnumByName
- FutureIterable
- IterableExtensions
- IterableQueryExtensions
- ListChunk
- ListExtension
- ListGroupByExtension
- ListJsonBeautifier
- ListOfDateTimeExtensions
- ListOfTimeOfDayExtensions
- ListToJSArray
- ListX
- MultipleStateRebuilderExtension
- MyfindFirstWhereOrNullExt
- NullableIterableExtensions
- NullableListQueries
- PageSettingsX
- ReactiveModeListX
- SignalListObserveExtension
Constructors
- JsArray()
-
Creates a new JavaScript array.
factory
-
JsArray.from(Iterable<
E> other) -
Creates a new JavaScript array and initializes it to the contents of
other.factory
Properties
- beautifiedJson → String
-
Available on List<
Returns a beautified JSON string representation of the list.Map< , provided by the ListJsonBeautifier extensionString, dynamic> >no setter - earliest → TimeOfDay?
-
Available on List<
Find earliest time in the listTimeOfDay> , provided by the ListOfTimeOfDayExtensions extensionno setter - encodedJsonString → String
-
Available on List<
Map< , provided by the BeautifiedJsonListExtension extensionString, dynamic> >no setter - first ↔ E
-
The first element.
getter/setter pairinherited
- firstOrNull → T?
-
Available on Iterable<
The first element of this iterator, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - firstOrNull → T?
-
Available on List<
ReturnsT> , provided by the NullableListQueries extensionnullinstead of throwing if the list is empty.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
indexed
→ Iterable<
(int, T)> -
Available on Iterable<
Pairs of elements of the indices and elements of this iterable.T> , provided by the IterableExtensions extensionno setter - isEmpty → bool
-
Whether this collection has no elements.
no setterinherited
- isNotEmpty → bool
-
Whether this collection has at least one element.
no setterinherited
-
iterator
→ Iterator<
E> -
A new
Iteratorthat allows iterating the elements of thisIterable.no setterinherited - last ↔ E
-
The last element.
getter/setter pairinherited
- lastOrNull → T?
-
Available on Iterable<
The last element of this iterable, orT> , provided by the IterableExtensions extensionnullif the iterable is empty.no setter - lastOrNull → T?
-
Available on List<
ReturnsT> , provided by the NullableListQueries extensionnullinstead of throwing if the list is empty.no setter - latest → TimeOfDay?
-
Available on List<
Find latest time in the listTimeOfDay> , provided by the ListOfTimeOfDayExtensions extensionno setter - length ↔ int
-
The number of objects in this list.
getter/setter pairoverride
-
nonNulls
→ Iterable<
T> -
Available on Iterable<
The non-T?> , provided by the NullableIterableExtensions extensionnullelements of this iterable.no setter - rebuild → _Rebuild
-
Available on List<
listen to the list of statesReactiveModel> , provided by the ReactiveModeListX extensionno setter -
reversed
→ Iterable<
E> -
An Iterable of the objects in this list in reverse order.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- safe → SafeListAccessor
-
Available on List, provided by the ListExtension extension
Get the safe accessor for this list that returns null for invalid indices Usage: list.safe2// returns null if index 2 doesn't existno setter - single → E
-
Checks that this iterable has only one element, and returns that element.
no setterinherited
- singleOrNull → T?
-
Available on Iterable<
The single element of this iterator, orT> , provided by the IterableExtensions extensionnull.no setter -
toJS
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or cloning the List.T> , provided by the ListToJSArray extensionno setter -
toJSProxyOrRef
→ JSArray<
T> -
Available on List<
Converts this List to a JSArray by either casting, unwrapping, or proxying the List.T> , provided by the ListToJSArray extensionno setter -
wait
→ Future<
List< T> > -
Available on Iterable<
Waits for futures in parallel.Future< , provided by the FutureIterable extensionT> >no setter
Methods
-
add(
E value) → void -
Adds
valueto the end of this list, extending the length by one.override -
addAll(
Iterable< E> iterable) → void -
Appends all objects of
iterableto the end of this list.override -
any(
bool test(E element)) → bool -
Checks whether any element of this iterable satisfies
test.inherited -
asMap(
) → Map< int, E> -
An unmodifiable Map view of this list.
inherited
-
asNameMap(
) → Map< String, T> -
Available on Iterable<
Creates a map from the names of enum values to the values.T> , provided by the EnumByName extension -
builder(
Widget builder(), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Builds a widget that listens to all injected instances in this list.Injected> , provided by the MultipleStateRebuilderExtension extension -
builderData(
Widget builder(List dataList), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
builderDataIndexed(
Widget builder(int index, dynamic data), {Widget onWaiting()?, Widget onError(dynamic error)?, void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
builderState(
Widget builder(List< SnapState> ), {void initState()?, void onAfterBuild()?, void dispose()?, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild, String? tag}) → Widget -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
byName(
String name) → T -
Available on Iterable<
Finds the enum value in this list with nameT> , provided by the EnumByName extensionname. -
callMethod(
Object method, [List? args]) → dynamic -
Calls
methodon the JavaScript object with the argumentsargsand returns the result.inherited -
cast<
R> () → List< R> -
Returns a view of this list as a list of
Rinstances.inherited -
chunked(
int size) → List< List< T> > -
Available on Iterable<
Splits values into fixed-size chunks.T> , provided by the IterableQueryExtensions extension -
clear(
) → void -
Removes all objects from this list; the length of the list becomes zero.
inherited
-
contains(
Object? element) → bool -
Whether the collection contains an element equal to
element.inherited -
convertToStringList(
{bool showSeconds = false, bool showUtcSymbol = false, bool preferUtcSymbolThanZ = false, bool showSeparatorSymbol = true, bool use24HourFormat = true}) → List< String> -
Available on List<
Convert list of TimeOfDay to list of stringsTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
convertToStringList(
) → List< String> -
Available on List<
DateTime> , provided by the ListOfDateTimeExtensions extension -
countWhere(
bool test(T element)) → int -
Available on Iterable<
Counts elements matchingT> , provided by the IterableQueryExtensions extensiontest. -
deleteProperty(
dynamic property) → void -
Removes
propertyfrom the JavaScript object.inherited -
distinctBy<
K> (K keyOf(T element)) → List< T> -
Available on Iterable<
Returns a list with duplicates removed byT> , provided by the IterableQueryExtensions extensionkeyOf, preserving order. -
doesIndexExist(
int index) → bool -
Available on List, provided by the ListExtension extension
-
elementAt(
int index) → E -
Returns the
indexth element.inherited -
elementAtOrNull(
int index) → T? -
Available on Iterable<
The element at positionT> , provided by the IterableExtensions extensionindexof this iterable, ornull. -
elementAtOrNull(
int index) → T? -
Available on List<
Returns the element atT> , provided by the NullableListQueries extensionindexornullwhen out of bounds. -
every(
bool test(E element)) → bool -
Checks whether every element of this iterable satisfies
test.inherited -
expand<
T> (Iterable< T> toElements(E element)) → Iterable<T> -
Expands each element of this Iterable into zero or more elements.
inherited
-
fillRange(
int start, int end, [E? fillValue]) → void -
Overwrites a range of elements with
fillValue.inherited -
findFirstWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Finds the first element satisfying the provided condition, orT> , provided by the MyfindFirstWhereOrNullExt extensionnullif none is found. -
firstWhere(
bool test(E element), {E orElse()?}) → E -
The first element that satisfies the given predicate
test.inherited -
firstWhereOrNull(
bool test(T element)) → T? -
Available on List<
Returns the first element matchingT> , provided by the NullableListQueries extensiontest, ornullwhen not found. -
fold<
T> (T initialValue, T combine(T previousValue, E element)) → T -
Reduces a collection to a single value by iteratively combining each
element of the collection with an existing value
inherited
-
followedBy(
Iterable< E> other) → Iterable<E> -
Creates the lazy concatenation of this iterable and
other.inherited -
forEach(
void action(E element)) → void -
Invokes
actionon each element of this iterable in iteration order.inherited -
getRange(
int start, int end) → Iterable< E> -
Creates an Iterable that iterates over a range of elements.
inherited
-
groupBy<
K> (K keyOf(T element)) → Map< K, List< T> > -
Available on List<
Groups elements by the value returned byT> , provided by the ListGroupByExtension extensionkeyOf. -
hasProperty(
Object property) → bool -
Returns
trueif the JavaScript object contains the specified property either directly or though its prototype chain.inherited -
indexOf(
E element, [int start = 0]) → int -
The first index of
elementin this list.inherited -
indexWhere(
bool test(E element), [int start = 0]) → int -
The first index in the list that satisfies the provided
test.inherited -
inj(
{bool autoDisposeWhenNotUsed = true}) → ReactiveModel< List< T> > -
Available on List<
create a ReactiveModel stateT> , provided by the ListX extension -
insert(
int index, E element) → void -
Inserts
elementat positionindexin this list.override -
insertAll(
int index, Iterable< E> iterable) → void -
Inserts all objects of
iterableat positionindexin this list.inherited -
instanceof(
JsFunction type) → bool -
Returns
trueif the JavaScript object hastypein its prototype chain.inherited -
join(
[String separator = ""]) → String -
Converts each element to a String and concatenates the strings.
inherited
-
lastIndexOf(
E element, [int? start]) → int -
The last index of
elementin this list.inherited -
lastIndexWhere(
bool test(E element), [int? start]) → int -
The last index in the list that satisfies the provided
test.inherited -
lastWhere(
bool test(E element), {E orElse()?}) → E -
The last element that satisfies the given predicate
test.inherited -
lastWhereOrNull(
bool test(T element)) → T? -
Available on List<
Returns the last element matchingT> , provided by the NullableListQueries extensiontest, ornullwhen not found. -
map<
T> (T toElement(E e)) → Iterable< T> -
The current elements of this iterable modified by
toElement.inherited -
none(
bool test(T element)) → bool -
Available on Iterable<
Returns true when no element satisfiesT> , provided by the IterableQueryExtensions extensiontest. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
{String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
observe<
R> ({Key? key, required R combine(List), required Widget builder(R), void onInit(R value)?, Function? onValueUpdated, void onAfterBuild(R value)?, void onDispose(R value)?, bool shouldRebuild(R newValue, R oldValue)?, bool shouldNotify(R newValue, R oldValue)?, bool equals(R a, R b)?, Duration? debounce, Duration? throttle, void onError(Object error, StackTrace stack)?, Widget errorBuilder(Object error)?, Widget loadingBuilder()?, String? debugLabel, bool debugPrint = false}) → SignalsWatch< R> -
Available on List<
Observe multiple signals and rebuild when any changes.ReadonlySignal> , provided by the SignalListObserveExtension extension -
reduce(
E combine(E value, E element)) → E -
Reduces a collection to a single value by iteratively combining elements
of the collection using the provided function.
inherited
-
remove(
Object? value) → bool -
Removes the first occurrence of
valuefrom this list.inherited -
removeAt(
int index) → E -
Removes the object at position
indexfrom this list.override -
removeLast(
) → E -
Removes and returns the last object in this list.
override
-
removeRange(
int start, int end) → void -
Removes a range of elements from the list.
override
-
removeWhere(
bool test(E element)) → void -
Removes all objects from this list that satisfy
test.inherited -
replaceRange(
int start, int end, Iterable< E> replacements) → void -
Replaces a range of elements with the elements of
replacements.inherited -
retainWhere(
bool test(E element)) → void -
Removes all objects from this list that fail to satisfy
test.inherited -
setAll(
int index, Iterable< E> iterable) → void -
Overwrites elements with the objects of
iterable.inherited -
setRange(
int start, int end, Iterable< E> iterable, [int skipCount = 0]) → void -
Writes some elements of
iterableinto a range of this list.override -
shuffle(
[Random? random]) → void -
Shuffles the elements of this list randomly.
inherited
-
singleWhere(
bool test(E element), {E orElse()?}) → E -
The single element that satisfies
test.inherited -
singleWhereOrNull(
bool test(T element)) → T? -
Available on Iterable<
Returns the single matching element, orT> , provided by the IterableQueryExtensions extensionnullif zero or multiple match. -
skip(
int count) → Iterable< E> -
Creates an Iterable that provides all but the first
countelements.inherited -
skipWhile(
bool test(E value)) → Iterable< E> -
Creates an
Iterablethat skips leading elements whiletestis satisfied.inherited -
sort(
[int compare(E a, E b)?]) → void -
Sorts this list according to the order specified by the
comparefunction.override -
sortChronologically(
) → List< TimeOfDay> -
Available on List<
Sort TimeOfDay list chronologicallyTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
sortedBy<
K extends Comparable< (Object?> >K keyOf(T element), {bool descending = false}) → List< T> -
Available on Iterable<
Returns a sorted copy by comparableT> , provided by the IterableQueryExtensions extensionkeyOf. -
sortInAlphaNumericalOrder(
) → List< String> -
Available on List<
String> , provided by the AlphaNumericSortingListOfString extension -
splitInChunks(
int chunkSize) → List< List< T> > -
sublist(
int start, [int? end]) → List< E> -
Returns a new list containing the elements between
startandend.inherited -
take(
int count) → Iterable< E> -
Creates a lazy iterable of the
countfirst elements of this iterable.inherited -
takeWhile(
bool test(E value)) → Iterable< E> -
Creates a lazy iterable of the leading elements satisfying
test.inherited -
to(
String routeName, {Object? arguments, Map< String, String> queryParams = const {}, bool isStrictMode = false}) → List<PageSettings> -
Available on List<
Add the page of routeName to PageSettingsPageSettings> , provided by the PageSettingsX extension -
toAndRemoveUntil(
String routeName, String untilRouteName) → List< PageSettings> -
Available on List<
Add the page with the givenPageSettings> , provided by the PageSettingsX extensionrouteNameand remove all pages until the page withuntilRouteNamename. -
toDateTimeList(
DateTime date, {bool isUtc = true}) → List< DateTime> -
Available on List<
Convert all TimeOfDay to DateTime on a specific dateTimeOfDay> , provided by the ListOfTimeOfDayExtensions extension -
toList(
{bool growable = true}) → List< E> -
Creates a List containing the elements of this Iterable.
inherited
-
toReplacement(
String routeName) → List< PageSettings> -
Available on List<
Add the page with the givenPageSettings> , provided by the PageSettingsX extensionrouteNameand remove the last page. -
toSet(
) → Set< E> -
Creates a Set containing the same elements as this iterable.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update<
R> (dynamic mutator(R state), {int index = 0, bool shouldNotify = true, String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
updateAll<
R> (dynamic mutator(R state), {bool shouldNotify = true, String? tag}) → void -
Available on List<
Injected> , provided by the MultipleStateRebuilderExtension extension -
where(
bool test(E element)) → Iterable< E> -
Creates a new lazy Iterable with all elements that satisfy the
predicate
test.inherited -
whereType<
T> () → Iterable< T> -
Creates a new lazy Iterable with all elements that have type
T.inherited -
windowed(
int size, {int step = 1, bool partialWindows = false}) → List< List< T> > -
Available on Iterable<
Returns sliding windows ofT> , provided by the IterableQueryExtensions extensionsize.
Operators
-
operator +(
List< E> other) → List<E> -
Returns the concatenation of this list and
other.inherited -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
dynamic index) → E -
Returns the value associated with
propertyfrom the proxied JavaScript object.override -
operator []=(
dynamic index, dynamic value) → void -
Sets the value associated with
propertyon the proxied JavaScript object.override