SLoadingIndicator class
********************** **************************** */
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SLoadingIndicator
- Available extensions
Constructors
-
SLoadingIndicator({Indicator indicatorType = Indicator.circleStrokeSpin, List<
Color> ? colors, Color? backgroundColor, double? strokeWidth, Color? pathBackgroundColor, bool pause = false, double? scale, double? scaleX, double? scaleY, Offset? origin, AlignmentGeometry alignment = AlignmentDirectional.center, bool transformHitTests = true, FilterQuality? filterQuality, Key? key}) -
const
Properties
- alignment → AlignmentGeometry
-
final
- backgroundColor → Color?
-
final
-
colors
→ List<
Color> ? -
final
- filterQuality → FilterQuality?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indicatorType → Indicator
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- origin → Offset?
-
final
- pathBackgroundColor → Color?
-
final
- pause → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale → double?
-
final
- scaleX → double?
-
final
- scaleY → double?
-
final
- strokeWidth → double?
-
final
- transformHitTests → bool
-
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited