EdgeInsetsBuilder class
Internal builder class to support chaining syntax like 12.left.bottom
- Available extensions
Constructors
Properties
- bottomPad → EdgeInsetsBuilder
-
no setter
- geometry → EdgeInsetsGeometry
-
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Allows implicit conversion to EdgeInsetsGeometryno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- insets → EdgeInsets
-
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Converts builder to EdgeInsetsno setter - leftPad → EdgeInsetsBuilder
-
Chainable getters with new naming
no setter
- rightPad → EdgeInsetsBuilder
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- topPad → EdgeInsetsBuilder
-
no setter
Methods
-
bottomPadWith(
double value) → EdgeInsetsBuilder -
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Allows chaining with new value for bottom padding -
call(
) → EdgeInsets - Call operator to make builder callable and return EdgeInsets
-
leftPadWith(
double value) → EdgeInsetsBuilder -
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Allows chaining with new value for left padding -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rightPadWith(
double value) → EdgeInsetsBuilder -
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Allows chaining with new value for right padding -
toEdgeInsets(
) → EdgeInsets - Implicit conversion to EdgeInsets
-
topPadWith(
double value) → EdgeInsetsBuilder -
Available on EdgeInsetsBuilder, provided by the EdgeInsetsBuilderConversion extension
Allows chaining with new value for top padding -
toString(
) → String -
A string representation of this object.
inherited
-
withBottom(
double value) → EdgeInsetsBuilder - Adds bottom padding and returns builder for chaining
-
withLeft(
double value) → EdgeInsetsBuilder - Adds left padding and returns builder for chaining
-
withRight(
double value) → EdgeInsetsBuilder - Adds right padding and returns builder for chaining
-
withTop(
double value) → EdgeInsetsBuilder - Adds top padding and returns builder for chaining
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited