ApplicationCache class
- Inheritance
-
- Object
- EventTarget
- ApplicationCache
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- on → Events
-
no setterinherited
-
onCached
→ Stream<
Event> -
no setter
-
onChecking
→ Stream<
Event> -
no setter
-
onDownloading
→ Stream<
Event> -
no setter
-
onError
→ Stream<
Event> -
no setter
-
onNoUpdate
→ Stream<
Event> -
no setter
-
onObsolete
→ Stream<
Event> -
no setter
-
onProgress
→ Stream<
Event> -
no setter
-
onUpdateReady
→ Stream<
Event> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
no setter
Methods
-
abort(
) → void -
addEventListener(
String type, EventListener listener, [bool? useCapture]) → void -
inherited
-
dispatchEvent(
Event event) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeEventListener(
String type, EventListener listener, [bool? useCapture]) → void -
inherited
-
swapCache(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
cachedEvent
→ const EventStreamProvider<
Event> - CHECKING → const int
-
checkingEvent
→ const EventStreamProvider<
Event> - DOWNLOADING → const int
-
downloadingEvent
→ const EventStreamProvider<
Event> -
errorEvent
→ const EventStreamProvider<
Event> - IDLE → const int
-
noUpdateEvent
→ const EventStreamProvider<
Event> - OBSOLETE → const int
-
obsoleteEvent
→ const EventStreamProvider<
Event> -
progressEvent
→ const EventStreamProvider<
Event> - UNCACHED → const int
- UPDATEREADY → const int
-
updateReadyEvent
→ const EventStreamProvider<
Event>