width property
The width of this rectangle.
This is equivalent to the width function in jQuery and the calculated
width CSS value, converted to a dimensionless num in pixels. Unlike
getBoundingClientRect, width will return the same numerical width if
the element is hidden or not.
Implementation
@override
num get width;
set
width
(dynamic newWidth)
Set the current computed width in pixels of this element.
newWidth can be either a num representing the width in pixels or a
Dimension object. This is equivalent to the width function in jQuery
and the calculated
width CSS value, converted to a dimensionless num in pixels.
Note that only the content width can be set via this method.
Implementation
set width(dynamic newWidth) {
throw UnsupportedError('Can only set width for content rect.');
}