DomImplementation class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createDocument(
String? namespaceURI, String qualifiedName, InternalDocumentType? doctype) → XmlDocument -
createDocumentType(
String qualifiedName, String publicId, String systemId) → InternalDocumentType -
createHtmlDocument(
[String? title]) → HtmlDocument -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited