offset property
The coordinates of the mouse pointer in target node coordinates.
This value may vary between platforms if the target node moves after the event has fired or if the element has CSS transforms affecting it.
Implementation
Point get offset {
final target = this.target as Element;
var point = (client - target.getBoundingClientRect().topLeft);
return Point(point.x.toInt(), point.y.toInt());
}