PointerEvent class
- Inheritance
-
- Object
- Event
- UIEvent
- MouseEvent
- PointerEvent
Constructors
- PointerEvent(String type, [Map? dict])
-
factory
- PointerEvent.constructor({required String type, num? height, bool? isPrimary, int? pointerId, String? pointerType, num? pressure, num? tangentialPressure, int? tiltX, int? tiltY, int? twist, num? width, bool altKey = false, int button = 0, bool canBubble = true, bool cancelable = true, bool ctrlKey = false, int detail = 0, bool metaKey = false, bool shiftKey = false, Object? view})
Properties
- altKey → bool?
-
finalinherited
- bubbles → bool?
-
finalinherited
-
finalinherited
-
finalinherited
- cancelable → bool?
-
finalinherited
-
client
→ Point<
num> -
no setterinherited
- composed → bool?
-
finalinherited
- ctrlKey → bool?
-
finalinherited
- currentTarget → EventTarget?
-
no setterinherited
- dataTransfer → DataTransfer
-
no setterinherited
- defaultPrevented → bool
-
no setterinherited
- detail → int?
-
finalinherited
- eventPhase → int
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → num?
-
final
- isPrimary → bool?
-
final
- isTrusted → bool?
-
no setterinherited
-
layer
→ Point<
num> -
no setterinherited
- matchingTarget → Element
-
A pointer to the element whose CSS selector matched within which an event
was fired. If this Event was not associated with any Event delegation,
accessing this value will throw an UnsupportedError.
no setterinherited
- metaKey → bool?
-
finalinherited
-
movement
→ Point<
num> -
no setterinherited
-
offset
→ Point<
num> -
The coordinates of the mouse pointer in target node coordinates.
no setterinherited
-
page
→ Point<
num> -
no setterinherited
-
path
→ List<
EventTarget> -
no setterinherited
- pointerId → int?
-
final
- pointerType → String?
-
final
- pressure → num?
-
final
- region → String?
-
finalinherited
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screen
→ Point<
num> -
no setterinherited
- shiftKey → bool?
-
finalinherited
- sourceCapabilities → InputDeviceCapabilities?
-
finalinherited
- tangentialPressure → num?
-
final
- target → EventTarget?
-
no setterinherited
- tiltX → int?
-
final
- tiltY → int?
-
final
- timeStamp → num?
-
finalinherited
- twist → int?
-
final
- type → String
-
finalinherited
- view → Object?
-
finalinherited
- width → num?
-
final
Methods
-
composedPath(
) → List< EventTarget> -
inherited
-
getModifierState(
String keyArg) → bool -
inherited
-
internalSetTarget(
EventTarget? target) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preventDefault(
) → void -
inherited
-
stopImmediatePropagation(
) → void -
inherited
-
stopPropagation(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited