Request class
Constructors
- Request()
-
factory
Properties
- bodyUsed → bool?
-
no setterinherited
- cache → String?
-
no setter
- credentials → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → Headers?
-
no setter
- integrity → String?
-
no setter
- mode → String?
-
no setter
- redirect → String?
-
no setter
- referrer → String?
-
no setter
- referrerPolicy → String?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
no setter
Methods
-
arrayBuffer(
) → Future -
inherited
-
blob(
) → Future< Blob> -
inherited
-
clone(
) → Request -
formData(
) → Future< FormData> -
inherited
-
json(
) → Future -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
text(
) → Future< String> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited