Screen class
Constructors
- Screen.constructor({int colorDepth = 24, int height = 800, bool keepAwake = false, int width = 600})
Properties
-
available
→ Rectangle<
num> -
no setter
- colorDepth → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int
-
final
- keepAwake ↔ bool
-
getter/setter pair
- orientation → ScreenOrientation
-
final
- pixelDepth → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited