WindowBase mixin
- Implemented types
- Mixin applications
Properties
- closed → bool?
-
Indicates whether this window has been closed.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- history → HistoryBase
-
The current session history for this window.
no setter
- location → LocationBase
-
The current location of this window.
no setter
- on → Events
-
no setterinherited
- opener → WindowBase?
-
A reference to the window that opened this one.
no setter
- parent → WindowBase?
-
A reference to the parent of this window.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → WindowBase?
-
A reference to the topmost window in the window hierarchy.
no setter
Methods
-
addEventListener(
String type, EventListener listener, [bool? useCapture]) → void -
inherited
-
close(
) → void - Closes the window.
-
dispatchEvent(
Event event) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postMessage(
dynamic message, String targetOrigin, [List< MessagePort> ? messagePorts]) → void - Sends a cross-origin message.
-
removeEventListener(
String type, EventListener listener, [bool? useCapture]) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited