WeekCalendar class
A horizontally scrollable weekly calendar widget with multiple visual styles
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- WeekCalendar
- Available extensions
Constructors
-
WeekCalendar({Key? key, required DateTime initialDate, required DateTime selectedDate, required ValueChanged<
DateTime> onDateSelected, VoidCallback? onNextMonth, VoidCallback? onPreviousMonth, VoidCallback? onPreviousWeek, VoidCallback? onNextWeek, WeekCalendarType calendarType = WeekCalendarType.standard, WeekCalendarStyle calendarStyle = const WeekCalendarStyle(), Duration? animationDuration, Curve? animationCurve, bool showMonthHeader = true, IconData? previousMonthIcon = Icons.chevron_left, IconData? nextMonthIcon = Icons.chevron_right, Color? iconColor, Weekday? startingDay, bool enableAnimations = true, dynamic onHeaderDateTapped(Offset widgetPosition)?, dynamic onHeaderTodayDate(Offset widgetPosition)?, bool isUtc = true, bool showCalendarPopupOnHeaderTap = true, DateTime? minDate, DateTime? maxDate, Set<DateTime> ? eventIndicatorDates, Color? eventIndicatorColor}) -
Default constructor for standard calendar
const
-
WeekCalendar.minimal({Key? key, required DateTime initialDate, required DateTime selectedDate, required ValueChanged<
DateTime> onDateSelected, VoidCallback? onNextMonth, VoidCallback? onPreviousMonth, VoidCallback? onPreviousWeek, VoidCallback? onNextWeek, WeekCalendarStyle calendarStyle = const WeekCalendarStyle(dayIndicatorSize: 32, monthHeaderStyle: TextStyle(fontSize: 14), selectedDayTextStyle: TextStyle(fontWeight: FontWeight.bold)), Duration? animationDuration, Curve? animationCurve, bool showMonthHeader = true, IconData? previousMonthIcon = Icons.chevron_left, IconData? nextMonthIcon = Icons.chevron_right, Color? iconColor, Weekday? startingDay, bool enableAnimations = true, dynamic onHeaderDateTapped(Offset widgetPosition)?, dynamic onHeaderTodayDate(Offset widgetPosition)?, bool isUtc = true, bool showCalendarPopupOnHeaderTap = true, DateTime? minDate, DateTime? maxDate, Set<DateTime> ? eventIndicatorDates, Color? eventIndicatorColor}) -
Preconfigured constructor for minimal variant
const
-
WeekCalendar.outlined({Key? key, required DateTime initialDate, required DateTime selectedDate, required ValueChanged<
DateTime> onDateSelected, VoidCallback? onNextMonth, VoidCallback? onPreviousMonth, VoidCallback? onPreviousWeek, VoidCallback? onNextWeek, WeekCalendarStyle calendarStyle = const WeekCalendarStyle(), Duration? animationDuration, Curve? animationCurve, bool showMonthHeader = true, IconData? previousMonthIcon = Icons.chevron_left, IconData? nextMonthIcon = Icons.chevron_right, Color? iconColor, Weekday? startingDay, bool enableAnimations = true, dynamic onHeaderDateTapped(Offset widgetPosition)?, dynamic onHeaderTodayDate(Offset widgetPosition)?, bool isUtc = true, bool showCalendarPopupOnHeaderTap = true, DateTime? minDate, DateTime? maxDate, Set<DateTime> ? eventIndicatorDates, Color? eventIndicatorColor}) -
Preconfigured constructor for outlined variant
const
Properties
- animationCurve → Curve?
-
Custom curve for month transition animations
final
- animationDuration → Duration?
-
Custom duration for month transition animations
final
- calendarStyle → WeekCalendarStyle
-
Complete styling configuration
final
- calendarType → WeekCalendarType
-
Visual variant of the calendar
final
- enableAnimations → bool
-
Global toggle for all animations
final
- eventIndicatorColor → Color?
-
Color of the event indicator dot. Defaults to the theme's primary color.
final
-
eventIndicatorDates
→ Set<
DateTime> ? -
Set of dates that should display an event indicator dot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconColor → Color?
-
Color for navigation icons
final
- initialDate → DateTime
-
Initial displayed month
final
- isUtc → bool
-
Indicates if the calendar is in UTC mode
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxDate → DateTime?
-
Latest selectable date. Days after this are disabled.
final
- minDate → DateTime?
-
Earliest selectable date. Days before this are disabled.
final
- nextMonthIcon → IconData?
-
Custom icon for next month navigation
final
-
onDateSelected
→ ValueChanged<
DateTime> -
Callback when user selects a date
final
- onHeaderDateTapped → dynamic Function(Offset widgetPosition)?
-
Callback when the header date is tapped
final
- onHeaderTodayDate → dynamic Function(Offset widgetPosition)?
-
Callback when the header today's date is tapped
final
- onNextMonth → VoidCallback?
-
Callback when calendar advances to next month
final
- onNextWeek → VoidCallback?
-
Callback when calendar advances to next week
final
- onPreviousMonth → VoidCallback?
-
Callback when calendar returns to previous month
final
- onPreviousWeek → VoidCallback?
-
Callback when calendar returns to previous week
final
- previousMonthIcon → IconData?
-
Custom icon for previous month navigation
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedDate → DateTime
-
Currently selected date
final
- showCalendarPopupOnHeaderTap → bool
-
Toggles the display of the calendar popup on header tap
final
- showMonthHeader → bool
-
Toggles month header visibility
final
- startingDay → Weekday?
-
Override default week starting day
final
Methods
-
addMaterialWidget(
) → Material -
Available on Widget, provided by the GenericExtensions extension
-
addTooltipWidget(
String toolTip) → Tooltip -
Available on Widget, provided by the GenericExtensions extension
-
animate(
{Key? key, List< Effect> ? effects, AnimateCallback? onInit, AnimateCallback? onPlay, AnimateCallback? onComplete, bool? autoPlay, Duration? delay, AnimationController? controller, Adapter? adapter, double? target, double? value}) → Animate -
Available on Widget, provided by the AnimateWidgetExtensions extension
Wraps the target Widget in anAnimateinstance, and returns the instance for chaining calls. Ex.myWidget.animate()is equivalent toAnimate(child: myWidget). -
borderRadius(
[BorderRadiusGeometry? borderRadius]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
boxDecoration(
[BoxDecoration? boxDecoration]) → Widget -
Available on Widget, provided by the GenericExtensions extension
-
colorFilter(
[ColorFilter? colorFilter]) → Widget -
Available on Widget, provided by the GenericExtensions extension
set parent widget in center -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< WeekCalendar> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited